package com.hzya.frame.plugin.lets.util;

import cn.hutool.core.lang.Assert;
import com.hzya.frame.beanutil.BeanUtil;
import com.hzya.frame.plugin.lets.constant.ProfilesActiveConstant;
import com.hzya.frame.plugin.lets.dao.IBdInvbasdocDao;
import com.hzya.frame.plugin.lets.dao.IBdInvmandocDao;
import com.hzya.frame.plugin.lets.dao.IBdTaxitemsDao;
import com.hzya.frame.plugin.lets.entity.BdInvbasdocEntity;
import com.hzya.frame.plugin.lets.entity.BdInvmandocEntity;
import com.hzya.frame.plugin.lets.entity.BdTaxitemsEntity;
import com.hzya.frame.plugin.lets.plugin.sales.PassiveWarehouseReceiptToC;
import com.hzya.frame.plugin.lets.u8cdto.ArapDjzbVO;
import com.hzya.frame.plugin.lets.u8cdto.SaleorderRequestChildrenDto;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import java.math.BigDecimal;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;

/**
 * @Author：liuyang
 * @Package：com.hzya.frame.plugin.lets.util
 * @Project：kangarooDataCenterV3
 * @name：QueryAdditionUtil
 * @Date：2024/12/4 15:12
 * @Filename：QueryAdditionUtil
 */
@Component
public class QueryAdditionUtil {

    Logger logger = LoggerFactory.getLogger(QueryAdditionUtil.class);

    @Autowired
    private IBdInvbasdocDao iBdInvbasdocDao;

    @Autowired
    private IBdTaxitemsDao iBdTaxitemsDao;

    @Autowired
    private IBdInvmandocDao iBdInvmandocDao;

    /**
     * 2024年8月7日 10:25:29
     * 查询存货基础档案档案
     *
     * @author liuyang
     */
    public List<BdInvbasdocEntity> queryStockBasicArchives() throws Exception {
        String invcodes = "'FY05','FY02','FY04','FY01'";
        BdInvbasdocEntity bdInvbasdocEntity = new BdInvbasdocEntity();
        bdInvbasdocEntity.setInvcodes(invcodes);
        bdInvbasdocEntity.setDataSourceCode(ProfilesActiveConstant.LETS_DATE_SOURCE);
        List<BdInvbasdocEntity> bdInvbasdocEntities = iBdInvbasdocDao.query(bdInvbasdocEntity);
        if (bdInvbasdocEntities == null || bdInvbasdocEntities.size() == 0) {
            Assert.state(false, "根据存货编码：{}，无法匹配到U8C存货基本档案", invcodes);
        }
        if (bdInvbasdocEntities.size() != 4) {
            Assert.state(false, "没有满足符合条数的存货数量，请检查《平台运费-FY05》、《平台优惠-FY01》、《达人优惠-FY02》、《支付优惠-FY04》是否在U8C全部都配置完毕！");
        }
        return bdInvbasdocEntities;
    }

    /**
     * 2024年8月7日 14:58:34
     * 查询存货对应的税目档案
     *
     * @author liuyang
     */
    public Map<String, BdTaxitemsEntity> queryBatchBdTaxitems(String invcode) throws Exception {
        Assert.notNull(invcode, "存货编码不能为空");

        BdTaxitemsEntity bdTaxitemsEntity = new BdTaxitemsEntity();
        bdTaxitemsEntity.setInvcodes(invcode);
        List<BdTaxitemsEntity> bdTaxitemsEntityList = iBdTaxitemsDao.queryBdInvbasdocByInvcodeV2(bdTaxitemsEntity);
        if (bdTaxitemsEntityList.size() == 0) {
            Assert.state(false, "根据存货编码{}没有查询到U8C税目档案", invcode);
        }
        if (bdTaxitemsEntityList.size() != 4) {
            Assert.state(false, "根据存货编码{}没有查询到足够的U8C税目档案", invcode);
        }
        return bdTaxitemsEntityList.stream().collect(Collectors.toMap(BdTaxitemsEntity::getInvcode, entity -> entity));
    }


    /**
     * 查询存货管理档案，key为公司id、value为存货管理档案对象
     *
     * @param bdInvbasdocEntities 存货基本档案
     * @author liuyang
     */
    public Map<String, BdInvmandocEntity> queryInventoryMan(List<BdInvbasdocEntity> bdInvbasdocEntities) throws Exception {
        Assert.notNull(bdInvbasdocEntities, "pk_invbasdoc不能为空！");

        Map<String, BdInvmandocEntity> stringBdInvmandocEntityMap = new HashMap<>();
        for (int i = 0; i < bdInvbasdocEntities.size(); i++) {
            BdInvbasdocEntity bdInvbasdocEntity = bdInvbasdocEntities.get(i);

            BdInvmandocEntity bdInvmandocEntity = new BdInvmandocEntity();
            bdInvmandocEntity.setPkInvbasdoc(bdInvbasdocEntity.getPkInvbasdoc());
            bdInvmandocEntity.setDataSourceCode(ProfilesActiveConstant.LETS_DATE_SOURCE);
            List<BdInvmandocEntity> bdInvmandocEntity2 = iBdInvmandocDao.query(bdInvmandocEntity);
            if (bdInvmandocEntity2 != null && bdInvmandocEntity2.size() > 0) {
                for (int j = 0; j < bdInvmandocEntity2.size(); j++) {
                    BdInvmandocEntity bdInvmandocEntity1 = bdInvmandocEntity2.get(j);
                    stringBdInvmandocEntityMap.put(bdInvbasdocEntity.getInvcode() + bdInvmandocEntity1.getPkCorp(), bdInvmandocEntity1);
                }
            }
        }
        return stringBdInvmandocEntityMap;
    }

    /**
     * 增加平台运费，优惠金额这些存货一起保存进U8C销售订单,TOC业务
     *
     * @param bdInvmandocEntity1              存货管理档案
     * @param bdInvbasdocEntity1              存货基本档案
     * @param saleorderRequestChildrenDtoList 需要推送给U8C销售订单明细行表体
     * @param noriginalcursummny              价税合计，只能传金额
     * @param nnumber                         数量
     * @author liuyang
     */
    public void additional(List<SaleorderRequestChildrenDto> saleorderRequestChildrenDtoList, BdInvmandocEntity bdInvmandocEntity1, BdInvbasdocEntity bdInvbasdocEntity1, BigDecimal noriginalcursummny, String nnumber, BdTaxitemsEntity bdTaxitemsEntity) throws Exception {
        Assert.notNull(saleorderRequestChildrenDtoList, "saleorderRequestChildrenDtoList不能为空！");
        Assert.notNull(bdInvmandocEntity1, "bdInvmandocEntity1不能为空");
        Assert.notNull(bdInvbasdocEntity1, "bdInvbasdocEntity1不能为空");
        Assert.notNull(noriginalcursummny, "noriginalcursummny不能为空");
        Assert.notNull(nnumber, "nnumber不能为空！");

        //如果size=0则不正常
        if (saleorderRequestChildrenDtoList.size() > 0) {
            SaleorderRequestChildrenDto saleorderRequestChildrenDto = saleorderRequestChildrenDtoList.get(0);

            //拷贝SaleorderRequestChildrenDto对象
            SaleorderRequestChildrenDto saleorderRequestChildrenDto1 = new SaleorderRequestChildrenDto();
            BeanUtil.copyPropertiesV2(saleorderRequestChildrenDto, saleorderRequestChildrenDto1);

            //修改存货、数量、税率、价税合计、优惠金额设置为0
            //存货id、存货编码
            saleorderRequestChildrenDto1.setCinventoryid(bdInvmandocEntity1.getPkInvmandoc());
            saleorderRequestChildrenDto1.setCinventorycode(bdInvbasdocEntity1.getInvcode());

            //价税合计
            BigDecimal noriginalcursummnyRounding2 = noriginalcursummny.setScale(2, BigDecimal.ROUND_HALF_UP);
            String noriginalcursummnyStr = noriginalcursummnyRounding2.stripTrailingZeros().toPlainString();
            saleorderRequestChildrenDto1.setNoriginalcursummny(noriginalcursummnyStr);

            //数量
            saleorderRequestChildrenDto1.setNnumber(nnumber);

            //税率
            saleorderRequestChildrenDto1.setNtaxrate(new BigDecimal(bdTaxitemsEntity.getTaxratio()).stripTrailingZeros().toPlainString());

            //优惠字段
            saleorderRequestChildrenDto1.setVdef4("0");
            saleorderRequestChildrenDto1.setVdef5("0");
            saleorderRequestChildrenDto1.setVdef6("0");
            saleorderRequestChildrenDto1.setVdef7("0");

            //是否赠品
            saleorderRequestChildrenDto1.setBlargessflag(false);

            //2025年2月17日 10:37:37 如果四舍五入保留2位后，如果为0，则不推送U8C，处理0.0033保留2位为0的问题
            //和李佳妮、还有丽知-山海沟通确定的
            if (!"0".equals(noriginalcursummnyStr)) {
                saleorderRequestChildrenDtoList.add(saleorderRequestChildrenDto1);
            }
        }
    }

    /**
     * 增加平台运费，优惠金额这些存货一起保存进U8C销售订单
     *
     * @param bdInvmandocEntity1 存货管理档案
     * @param bdInvbasdocEntity1 存货基本档案
     * @param pushScenarioType   需要推送给U8C红字应收单明细行表体
     * @param noriginalcursummny 价税合计(只能传金额)
     * @param bdTaxitemsEntity   存货对应的税率
     * @author liuyang
     */
    public void additionalV2(List<ArapDjzbVO.Childrenn> pushScenarioType, BdInvmandocEntity bdInvmandocEntity1, BdInvbasdocEntity bdInvbasdocEntity1, BigDecimal noriginalcursummny, BdTaxitemsEntity bdTaxitemsEntity) {
        Assert.notNull(pushScenarioType, "pushScenarioType不能为空！");
        Assert.notNull(bdInvmandocEntity1, "bdInvmandocEntity1不能为空");
        Assert.notNull(bdInvbasdocEntity1, "bdInvbasdocEntity1不能为空");
        Assert.notNull(noriginalcursummny, "noriginalcursummny不能为空");

        //2025年2月17日 10:37:37 如果四舍五入保留2位后，如果为0，则不推送U8C，处理0.0033保留2位为0的问题
        //和李佳妮、还有丽知-山海沟通确定的
        if ("0".equals(noriginalcursummny.setScale(2, BigDecimal.ROUND_HALF_UP).stripTrailingZeros().toPlainString())) {
            return;
        } else {
            noriginalcursummny = noriginalcursummny.setScale(2, BigDecimal.ROUND_HALF_UP);
        }

        //拷贝SaleorderRequestChildrenDto对象
        ArapDjzbVO.Childrenn arapDjzbVOChildrenn = new ArapDjzbVO.Childrenn();

        //修改存货、数量、税率、价税合计、优惠金额设置为0
        //存货id、存货编码
        arapDjzbVOChildrenn.setCinventoryid(bdInvbasdocEntity1.getInvcode());

//        String tax = null;//税率
//        BigDecimal noriginalcurmny = null;//无税金额
//        BigDecimal noriginalcurtaxmny = null;//税额
//        try {
//            tax = new BigDecimal(bdTaxitemsEntity.getTaxratio()).divide(new BigDecimal(100), 20, BigDecimal.ROUND_HALF_UP).setScale(2, BigDecimal.ROUND_HALF_UP).stripTrailingZeros().toPlainString();
//            noriginalcurmny = noriginalcursummny.divide(new BigDecimal(1).add(new BigDecimal(tax)), 20, BigDecimal.ROUND_HALF_UP).setScale(2, BigDecimal.ROUND_HALF_UP);
//            noriginalcurtaxmny = noriginalcursummny.subtract(noriginalcurmny).setScale(2, BigDecimal.ROUND_HALF_UP);
//        } catch (Exception e) {
//            logger.error("金额计算失败", e);
//            Assert.state(false, "金额计算失败 异常：{}", e.getMessage());
//        }

        //金额计算
        arapDjzbVOChildrenn.setJfbbje(noriginalcursummny.stripTrailingZeros().toPlainString());//借方本币金额
        arapDjzbVOChildrenn.setJfybje(noriginalcursummny.stripTrailingZeros().toPlainString());//借方原币金额
        //⚠️解决0.03 优惠金额 / (1+0.06 税率) = 0.03，已经和妮姐确认，通过传递应收单到U8C，税额和无税金额U8C会自动算出来，所以这里就不传了
//        arapDjzbVOChildrenn.setJfbbsj(noriginalcurmny.stripTrailingZeros().toPlainString());//借方本币税金
//        arapDjzbVOChildrenn.setJfybsj(noriginalcurmny.stripTrailingZeros().toPlainString());//借方原币税金
//        arapDjzbVOChildrenn.setWbfbbje(noriginalcurtaxmny.stripTrailingZeros().toPlainString());//借方本币无税金额
//        arapDjzbVOChildrenn.setJfybwsje(noriginalcurtaxmny.stripTrailingZeros().toPlainString());//借方原币无税金额
        pushScenarioType.add(arapDjzbVOChildrenn);
    }

    /**
     * 增加平台运费，优惠金额这些存货一起保存进U8C销售订单
     *
     * @param bdInvmandocEntity1 存货管理档案
     * @param bdInvbasdocEntity1 存货基本档案
     * @param pushScenarioType   需要推送给U8C红字应收单明细行表体
     * @param noriginalcursummny 价税合计(只能传金额)
     * @param bdTaxitemsEntity   存货对应的税率
     * @author liuyang
     */
    public void additionalV3(List<ArapDjzbVO.Childrenn> pushScenarioType, BdInvmandocEntity bdInvmandocEntity1, BdInvbasdocEntity bdInvbasdocEntity1, BigDecimal noriginalcursummny, BdTaxitemsEntity bdTaxitemsEntity) {
        Assert.notNull(pushScenarioType, "pushScenarioType不能为空！");
        Assert.notNull(bdInvmandocEntity1, "bdInvmandocEntity1不能为空");
        Assert.notNull(bdInvbasdocEntity1, "bdInvbasdocEntity1不能为空");
        Assert.notNull(noriginalcursummny, "noriginalcursummny不能为空");

        //2025年2月17日 10:37:37 如果四舍五入保留2位后，如果为0，则不推送U8C，处理0.0033保留2位为0的问题
        //和李佳妮、还有丽知-山海沟通确定的
        if ("0".equals(noriginalcursummny.setScale(2, BigDecimal.ROUND_HALF_UP).stripTrailingZeros().toPlainString())) {
            return;
        } else {
            noriginalcursummny = noriginalcursummny.setScale(2, BigDecimal.ROUND_HALF_UP);
        }

        //拷贝SaleorderRequestChildrenDto对象
        ArapDjzbVO.Childrenn arapDjzbVOChildrenn = new ArapDjzbVO.Childrenn();
        //修改存货、数量、税率、价税合计、优惠金额设置为0
        //存货id、存货编码
        arapDjzbVOChildrenn.setCinventoryid(bdInvbasdocEntity1.getInvcode());
        //金额计算
        arapDjzbVOChildrenn.setJfbbje(noriginalcursummny.stripTrailingZeros().toPlainString());//借方本币金额
        arapDjzbVOChildrenn.setJfybje(noriginalcursummny.stripTrailingZeros().toPlainString());//借方原币金额
//        arapDjzbVOChildrenn.setJfbbsj(noriginalcurmny.stripTrailingZeros().toPlainString());//借方本币税金
//        arapDjzbVOChildrenn.setJfybsj(noriginalcurmny.stripTrailingZeros().toPlainString());//借方原币税金
//        arapDjzbVOChildrenn.setWbfbbje(noriginalcurtaxmny.stripTrailingZeros().toPlainString());//借方本币无税金额
//        arapDjzbVOChildrenn.setJfybwsje(noriginalcurtaxmny.stripTrailingZeros().toPlainString());//借方原币无税金额
        pushScenarioType.add(arapDjzbVOChildrenn);
    }
}
