package com.hzya.frame.webapp.entrance.util;

import javax.servlet.http.HttpServletResponse;
import java.io.BufferedInputStream;
import java.io.File;
import java.io.FileInputStream;
import java.io.OutputStream;
import java.net.URL;

/**
 * 文件下载处理方法
 *
 * @Author：liuyang
 * @Package：com.hzya.frame.webapp.entrance.util
 * @Project：kangarooDataCenter
 * @name：FileDownloadUtil
 * @Date：2024/7/19 17:08
 * @Filename：FileDownloadUtil
 */
public class FileDownloadUtil {
    /**
     * 加载打开文件
     *
     * @param filePath 文件地址
     * @param response 响应对象
     * @param isOnLine 是否在线打开
     */
    public static void downLoad(String filePath, HttpServletResponse response, boolean isOnLine, String filename) throws Exception {
        File f = new File(filePath);
        if (!f.exists()) {
            response.sendError(404, "File not found!");
            return;
        }
        BufferedInputStream br = new BufferedInputStream(new FileInputStream(f));
        byte[] buf = new byte[1024];
        int len = 0;

        response.reset(); //非常重要
        if (isOnLine) { //在线打开方式
            URL u = new URL("file:///" + filePath);
            response.setContentType(u.openConnection().getContentType());
            response.setHeader("Content-Disposition", "inline; filename=" + new String((filename).getBytes("UTF-8"), "ISO8859-1"));
            //文件名应该编码成UTF-8
        } else { //纯下载方式
            response.setContentType("application/x-msdownload");
            response.setHeader("Content-Disposition", "attachment; filename=" + new String(filename.getBytes("UTF-8"), "ISO8859-1"));
        }
        OutputStream out = response.getOutputStream();
        while ((len = br.read(buf)) > 0) {
            out.write(buf, 0, len);
        }
        br.close();
        out.close();
    }
}