package com.hzya.frame.plugin.lets.plugin.sales;

import cn.hutool.core.date.DateTime;
import cn.hutool.core.date.DateUtil;
import cn.hutool.core.lang.Assert;
import cn.hutool.core.util.StrUtil;
import cn.hutool.http.HttpRequest;
import cn.hutool.json.JSONUtil;
import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONObject;
import com.google.common.collect.Lists;
import com.hzya.frame.base.PluginBaseEntity;
import com.hzya.frame.beanutil.BeanUtil;
import com.hzya.frame.plugin.lets.constant.OverallConstant;
import com.hzya.frame.plugin.lets.constant.ProfilesActiveConstant;
import com.hzya.frame.plugin.lets.dao.IOnlyAfterSalesBDao;
import com.hzya.frame.plugin.lets.dao.IOnlyAfterSalesHDao;
import com.hzya.frame.plugin.lets.entity.*;
import com.hzya.frame.plugin.lets.ofs.dao.IOfsPassiveorderDetailDao;
import com.hzya.frame.plugin.lets.ofs.dao.IOfsPassiveorderHeaderDao;
import com.hzya.frame.plugin.lets.ofs.dao.ITocofsReturngoodsDao;
import com.hzya.frame.plugin.lets.ofs.dao.ITocofsReturngoodsDetailedDao;
import com.hzya.frame.plugin.lets.ofs.entity.OfsPassiveorderDetailEntity;
import com.hzya.frame.plugin.lets.ofs.entity.OfsPassiveorderHeaderEntity;
import com.hzya.frame.plugin.lets.ofs.entity.TocofsReturngoodsDetailedEntity;
import com.hzya.frame.plugin.lets.ofs.entity.TocofsReturngoodsEntity;
import com.hzya.frame.plugin.lets.ofs.service.IOfsPassiveorderDetailService;
import com.hzya.frame.plugin.lets.ofsvo.QueryOfsSoSaleOutVo;
import com.hzya.frame.plugin.lets.queryvo.StartAndEndVo;
import com.hzya.frame.plugin.lets.resultvo.CacheTocMapVoV2;
import com.hzya.frame.plugin.lets.u8cdto.*;
import com.hzya.frame.plugin.lets.util.*;
import com.hzya.frame.split.SplitListByCountUtil;
import com.hzya.frame.ttxofs.dto.ofssalesordersearch.DetailsDto;
import com.hzya.frame.ttxofs.dto.ofssalesordersearch.HeaderDetailsDto;
import com.hzya.frame.ttxofs.dto.ofssalesordersearch.HeaderDto;
import com.hzya.frame.ttxofs.dto.passivestorage.PassiveStorageResponse;
import com.hzya.frame.ttxofs.dto.returngoodordersearch.RerturnGoodsOrderSearchData;
import com.hzya.frame.ttxofs.dto.returngoodordersearch.RerturnGoodsOrderSearchDetails;
import com.hzya.frame.ttxofs.dto.returngoodordersearch.RerturnGoodsOrderSearchHeader;
import com.hzya.frame.ttxofs.dto.stock.StockinOrderSearchResponse;
import com.hzya.frame.ttxofs.service.OfsUnifiedService;
import com.hzya.frame.web.entity.BaseResult;
import com.hzya.frame.web.entity.JsonResultEntity;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;

import java.math.BigDecimal;
import java.text.SimpleDateFormat;
import java.time.LocalDate;
import java.time.LocalDateTime;
import java.time.format.DateTimeFormatter;
import java.util.*;
import java.util.concurrent.locks.ReentrantLock;
import java.util.function.Predicate;
import java.util.stream.Collectors;

/**
 * 2025-03-06 17:33:44
 * TOC业务，无源入库单(TOC) -> 推送U8C 红字销售订单、交易成功部分生成红字应收单
 *
 * @Author：liuyang
 * @Package：com.hzya.frame.plugin.lets.plugin.sales
 * @Project：kangarooDataCenterV3
 * @name：PassiveWarehouseReceipt
 * @Date：2025/3/6 17:33
 * @Filename：PassiveWarehouseReceipt
 */
public class PassiveWarehouseReceiptToC extends PluginBaseEntity {

    Logger logger = LoggerFactory.getLogger(PassiveWarehouseReceiptToC.class);

    //增加公平锁推送性能会比较差，但目标 U8C 端不支持并发，这样也能确保数据的准确性，避免数据重复推送，基本满足业务需求
    private static final ReentrantLock LOCK1 = new ReentrantLock(true);

    private static final ReentrantLock LOCK2 = new ReentrantLock(true);

    private static final String STOCK = "stock";

    private static final String TRAN = "tran";

    private static final String PROD_FILED = "prod";

    @Autowired
    private BalanceUnitPriceUtil balanceUnitPriceUtil;

    @Autowired
    private QueryU8CEntityUtil queryU8CEntityUtil;

    @Autowired
    private QueryAdditionUtil queryAdditionUtil;

    @Autowired
    private IOfsPassiveorderHeaderDao iOfsPassiveorderHeaderDao;

    @Autowired
    private IOfsPassiveorderDetailDao iOfsPassiveorderDetailDao;

    @Autowired
    private OfsUnifiedService ofsUnifiedService;

    @Autowired
    private QueryBdBusitypeUtil queryBdBusitypeUtil;

    private static final String NOTHING = "无";

    private static final String ADD = "&";

    @Autowired
    private PassiveComponentsArchivesCacheUtil passiveComponentsArchivesCacheUtil;

    @Autowired
    private PassiveComponentsArchivesCacheUtilV2 passiveComponentsArchivesCacheUtilV2;

    @Autowired
    private ITocofsReturngoodsDao iTocofsReturngoodsDao;

//    @Autowired
//    private ITocofsReturngoodsDetailedDao iTocofsReturngoodsDetailedDao;

//    @Autowired
//    private TocReturnBasicArchivesCacheUtil tocReturnBasicArchivesCacheUtil;

    @Autowired
    private ShopTobOrToCUtil shopTobOrToCUtil;

    @Autowired
    private OfsStandardUtil ofsStandardUtil;

    @Autowired
    private AfterSalesOrderUtil afterSalesOrderUtil;

    @Autowired
    private IOnlyAfterSalesHDao iOnlyAfterSalesHDao;

    @Autowired
    private RdclUtil rdclUtil;

    @Autowired
    private OfsOrderAfterSalesAmountAllocationUtil ofsOrderAfterSalesAmountAllocationUtil;

    @Autowired
    private IOnlyAfterSalesBDao iOnlyAfterSalesBDao;

    @Override
    public void initialize() {
        logger.info(getPluginLabel() + "執行初始化方法initialize()");
    }

    @Override
    public void destroy() {
        logger.info(getPluginLabel() + "執行銷毀方法destroy()");
    }

    @Override
    public String getPluginId() {
        return "sales.PassiveWarehouseReceiptToC";
    }

    @Override
    public String getPluginName() {
        return "OFS无源入库单生成U8C红字销售订单或红字应收单";
    }

    @Override
    public String getPluginLabel() {
        return "OFS无源入库单生成U8C红字销售订单或红字应收单";
    }

    @Override
    public String getPluginType() {
        return "3";
    }

    private static final String BUSINESS_TYPE = "passiveSalesService";

    @Override
    public JsonResultEntity executeBusiness(JSONObject requestJson) throws Exception {
        logger.info("触发调用：{}" + getPluginName());
        try {
            String requestJsonParam = String.valueOf(requestJson.get("param"));

            Thread thread = new Thread(new Runnable() {
                @Override
                public void run() {
                    long startMillis = System.currentTimeMillis();
                    logger.info("executeBusiness方法调用开始：" + getPluginName() + "-插件");

                    try {
                        String param = String.valueOf(requestJson.get("param"));
                        String sceneType = String.valueOf(requestJson.get("sceneType"));//sceneType：stock、tran
//                        String pushScenarioType = String.valueOf(requestJson.get("pushScenarioType"));
                        if (ProfilesActiveConstant.TYPE_VBILLCODE.equals(requestJson.get("type"))) {
                            //按单号
                            if (param != null && !"".equals(param)) {
                                startImplementByCode(param, sceneType);
                            }
                        } else if (ProfilesActiveConstant.TYPE_TIME_FRAME.equals(requestJson.get("type"))) {
                            //前台页面功能日期推送，或者接口调用也行
                            String craeteDateStr = computingTime(param);
                            if (craeteDateStr != null && !"".equals(craeteDateStr)) {
                                splitDateAndPush(craeteDateStr, sceneType);
                            }
                        } else {
                            if (ProfilesActiveConstant.LETS_PROFILES_ACTIVE.equals(PROD_FILED)) {
                                //默认被定时器执行，每天晚上凌晨0点5分
                                //暂定先同步TOC销售库存、再推送TOC销售确认收入
                                List<StartAndEndVo> startAndEndVos = calculateCalculateEntireDayPeriod(null);
                                //TODO 1号上线注释掉
//                                startImplementStockByTime(startAndEndVos.get(0).getStart_time(), startAndEndVos.get(0).getEnd_time(), "0");
//                                startImplementByTradeTime(startAndEndVos.get(0).getStart_time(), startAndEndVos.get(0).getEnd_time(), "0");
                            }
                        }
                    } catch (Exception e) {
                        logger.error("executeBusiness方法异常", e);
                    }
                    long endMillis = System.currentTimeMillis();
                    logger.info("executeBusiness方法调用结束：" + getPluginName() + "-插件 执行耗时：{}", (endMillis - startMillis));
//                return null;
                }
            }, "执行插件：" + getPluginName() + " " + requestJsonParam);
            thread.start();

            if (requestJson != null && requestJson.get("type") != null && ProfilesActiveConstant.TYPE_DETAIL_ERROR.equals(requestJson.get("type"))) {
                try {
                    thread.join();
                } catch (Exception e) {
                    logger.error("thread.join();抛出异常", e);
                }
            }
        } catch (Exception e) {
            logger.error("executeBusiness方法抛出异常", e);
        }
        return BaseResult.getSuccessMessageEntity("插件执行成功");
    }

    /**
     * 无源件库存同步，根据时间范围拉取
     *
     * @author liuyang
     */
    public void startImplementStockByTime(String startTime, String endTime) throws Exception {
        try {
            long startMillis = System.currentTimeMillis();
            String threadNameStrStart = StrUtil.format("开始-TOC无源入库单同步U8C红字销售订单 关联开始时间：{} 关联结束时间：{}", startTime, endTime);
            logger.info(threadNameStrStart);

            Assert.notNull(startTime, "开始时间不能为空");
            Assert.notNull(endTime, "结束时间不能为空");
            List<PassiveStorageResponse.Data> passiveStorageResponseDataList = new ArrayList<>();

            String tocShop = shopTobOrToCUtil.getCommaShop("TOC");
            QueryOfsSoSaleOutVo queryOfsSoSaleOutVo = new QueryOfsSoSaleOutVo();
            queryOfsSoSaleOutVo.setRelatedAt_start(startTime);
            queryOfsSoSaleOutVo.setRelatedAt_end(endTime);
            queryOfsSoSaleOutVo.setClientCode("LETS");
            queryOfsSoSaleOutVo.setPageNo(1L);
            queryOfsSoSaleOutVo.setPageSize(50L);
            queryOfsSoSaleOutVo.setStoreCode(tocShop);
            ofsStandardUtil.queryOfsPassiveComponents(queryOfsSoSaleOutVo, passiveStorageResponseDataList, 1L, "ofs.passive.order.search");

            logger.info("TOC退货数据返回行数：{}", passiveStorageResponseDataList.size());
            if (passiveStorageResponseDataList.size() > 0) {
                String filter_company = queryU8CEntityUtil.queryBdDefDocByListPk();
                passiveStorageResponseDataList.removeIf(new Predicate<PassiveStorageResponse.Data>() {
                    @Override
                    public boolean test(PassiveStorageResponse.Data headerDetailsDto) {
                        PassiveStorageResponse.Header header = headerDetailsDto.getHeader();
                        if (header != null && header.getCompanyCode() != null) {
                            if (filter_company.contains(header.getCompanyCode().trim())) {
                                return true;
                            }
                        }
                        return false;
                    }
                });
                getSetStock(passiveStorageResponseDataList);
            } else {
                logger.info("没有查询到任何数据！不需要同步");
            }
            long endMillis = System.currentTimeMillis();
            String threadNameStrEnd = StrUtil.format("结束-TOC无源入库单同步U8C红字销售订单 关联开始时间：{} 关联结束时间：{} 耗时：{}", startTime, endTime, (endMillis - startMillis));
            logger.info(threadNameStrEnd);
        } catch (Exception e) {
            logger.error("startImplementStockByTime方法抛出异常", e);
        }
    }

    /**
     * 根据编码、场景类型拉取
     *
     * @param code      无源入库单
     * @param sceneType 场景类型
     * @author liuyang
     */
    public void startImplementByCode(String code, String sceneType) throws Exception {
        long startMillis = System.currentTimeMillis();
        String threadNameStrStart = StrUtil.format("开始-OFS销售出库(TOC)同步U8C销售订单 同步单据号：{} 业务场景：{}", code, sceneType);
        logger.info(threadNameStrStart);

        Assert.notNull(code, "code不能为空");
        Assert.notNull(sceneType, "sceneType不能为空");

        List<PassiveStorageResponse.Data> passiveStorageResponseDataList = new ArrayList<>();

        QueryOfsSoSaleOutVo queryOfsSoSaleOutVo = new QueryOfsSoSaleOutVo();
        queryOfsSoSaleOutVo.setReceiptCode(code);
        queryOfsSoSaleOutVo.setClientCode("LETS");
        queryOfsSoSaleOutVo.setPageNo(1L);
        queryOfsSoSaleOutVo.setPageSize(50L);
        ofsStandardUtil.queryOfsPassiveComponents(queryOfsSoSaleOutVo, passiveStorageResponseDataList, 1L, "ofs.passive.order.search");

        logger.info("数据返回行数：{}", passiveStorageResponseDataList.size());
        if (passiveStorageResponseDataList.size() > 0) {
            String filter_company = queryU8CEntityUtil.queryBdDefDocByListPk();
            passiveStorageResponseDataList.removeIf(new Predicate<PassiveStorageResponse.Data>() {
                @Override
                public boolean test(PassiveStorageResponse.Data headerDetailsDto) {
                    PassiveStorageResponse.Header header = headerDetailsDto.getHeader();
                    if (header != null && header.getCompanyCode() != null) {
                        //过滤掉业务上不需要的公司
                        if (filter_company.contains(header.getCompanyCode().trim())) {
                            return true;
                        }
                    }
                    return false;
                }
            });
            if (sceneType.equals("stock")) {
                getSetStock(passiveStorageResponseDataList);
            } else if (sceneType.equals("tran")) {
                getSetTran(passiveStorageResponseDataList);
            }
        } else {
            logger.info("没有查询到任何数据！不需要同步");
        }

        long endMillis = System.currentTimeMillis();
        String threadNameStrEnd = StrUtil.format("结束-OFS销售出库(TOC)同步U8C销售订单 同步单据号：{} 业务场景：{} 耗时：{}", code, sceneType, (endMillis - startMillis));
        logger.info(threadNameStrEnd);
    }

    /**
     * 交易采购，按指定时间拉取
     *
     * @author liuyang
     */
    public void startImplementByTradeTime(String startTime, String endTime) throws Exception {
        try {
            long startMillis = System.currentTimeMillis();
            String threadNameStrStart = StrUtil.format("OFS售后入库(TOB)同步U8C销售订单(库存同步) 开始时间：{} 结束时间：{}", startTime, endTime);
            logger.info(threadNameStrStart);

            Assert.notNull(startTime, "startTime不能为空");
            Assert.notNull(endTime, "endTime不能为空");
            List<PassiveStorageResponse.Data> passiveStorageResponseDataList = new ArrayList<>();

            String tocShop = shopTobOrToCUtil.getCommaShop("TOC");
            QueryOfsSoSaleOutVo queryOfsSoSaleOutVo = new QueryOfsSoSaleOutVo();
            queryOfsSoSaleOutVo.setRelatedAt_start(startTime);
            queryOfsSoSaleOutVo.setRelatedAt_end(endTime);
            queryOfsSoSaleOutVo.setClientCode("LETS");
            queryOfsSoSaleOutVo.setPageNo(1L);
            queryOfsSoSaleOutVo.setPageSize(50L);
            queryOfsSoSaleOutVo.setStoreCode(tocShop);
            ofsStandardUtil.queryOfsPassiveComponents(queryOfsSoSaleOutVo, passiveStorageResponseDataList, 1L, "ofs.passive.order.search");
            logger.info("数据返回行数：{}", passiveStorageResponseDataList.size());

            if (passiveStorageResponseDataList.size() > 0) {
                String filter_company = queryU8CEntityUtil.queryBdDefDocByListPk();
                passiveStorageResponseDataList.removeIf(new Predicate<PassiveStorageResponse.Data>() {
                    @Override
                    public boolean test(PassiveStorageResponse.Data headerDetailsDto) {
                        PassiveStorageResponse.Header header = headerDetailsDto.getHeader();
                        if (header != null && header.getCompanyCode() != null) {
                            //过滤掉不需要的公司
                            if (filter_company.contains(header.getCompanyCode().trim())) {
                                return true;
                            }
                        }
                        return false;
                    }
                });
                getSetTran(passiveStorageResponseDataList);
            } else {
                logger.info("没有查询到任何数据！不需要同步");
            }

            long endMillis = System.currentTimeMillis();
            String threadNameStrEnd = StrUtil.format("OFS售后入库(TOB)同步U8C销售订单(库存同步) 开始时间：{} 结束时间：{} 耗时：{}", startTime, endTime, (endMillis - startMillis));
            logger.info(threadNameStrEnd);
        } catch (Exception e) {
            logger.error("startImplementByTradeTime方法抛出异常", e);
        }
    }

    /**
     * 无源件库存同步getSetStock方法发现逻辑
     *
     * @author liuyang
     */
    private void getSetStock(List<PassiveStorageResponse.Data> returnGoodHeaderDetailsDataDtoArrayList) throws Exception {
        LOCK1.lock();
        try {
            //保存到mysql底表
            batchInsert(returnGoodHeaderDetailsDataDtoArrayList);
            //过滤成功的数据
            List<PassiveStorageResponse.Data> data = filterDataStock(returnGoodHeaderDetailsDataDtoArrayList);
            //执行推送主逻辑
            implementStock(data);
        } catch (Exception e) {
            logger.error("TOC退货-库存：getSetStock方法抛出异常", e);
        } finally {
            LOCK1.unlock();
        }
    }

    /**
     * 确认收入：预备执行逻辑
     *
     * @param passiveStorageResponseDataDtoArrayList O无源入库单
     * @author liuyang
     */
    private void getSetTran(List<PassiveStorageResponse.Data> passiveStorageResponseDataDtoArrayList) throws Exception {
        LOCK2.lock();
        try {
            //过滤成功的数据
//            List<PassiveStorageResponse.Data> data = filterDataTran(passiveStorageResponseDataDtoArrayList);
            //保存到mysql
//            batchInsert(data);
            //执行推送主逻辑
            implementTran(passiveStorageResponseDataDtoArrayList);
        } catch (Exception e) {
            logger.error("TOC退货-确认收入：getSetTran方法抛出异常", e);
        } finally {
            LOCK2.unlock();
        }
    }

    /**
     * 库存同步，过滤掉成功的数据
     *
     * @author liuyang
     */
    private List<PassiveStorageResponse.Data> filterDataStock(List<PassiveStorageResponse.Data> passiveStorageResponseDataDtoArrayList) throws Exception {
        List<OfsPassiveorderDetailEntity> ofsPassiveorderDetailEntitiesList = new ArrayList<>();
        //查询每行无源入库单，对应的推送状态
        if (passiveStorageResponseDataDtoArrayList != null && passiveStorageResponseDataDtoArrayList.size() > 0) {
            List<List<PassiveStorageResponse.Data>> lists = SplitListByCountUtil.splitListByCount(passiveStorageResponseDataDtoArrayList, 1000);
            for (int i = 0; i < lists.size(); i++) {
                List<PassiveStorageResponse.Data> data = lists.get(i);
                String idStr = commaConcatenatedPrimaryKeyStock(data);
                List<OfsPassiveorderDetailEntity> ofsPassiveorderDetailEntities = queryStockTocOutLog(idStr);
                ofsPassiveorderDetailEntitiesList.addAll(ofsPassiveorderDetailEntities);
            }
        }
        return filterDataRowsAsPushOrFailedStock(ofsPassiveorderDetailEntitiesList, passiveStorageResponseDataDtoArrayList);
    }

    /**
     * 确认收入，过滤掉成功的数据
     *
     * @author liuyang
     */
//    private List<PassiveStorageResponse.Data> filterDataTran(List<PassiveStorageResponse.Data> passiveStorageResponseDataDtoArrayList) throws Exception {
//        List<OnlyAfterSalesBEntity> tocofsReturngoodsDetailedEntityList = new ArrayList<>();
//        if (passiveStorageResponseDataDtoArrayList != null && passiveStorageResponseDataDtoArrayList.size() > 0) {
//            List<List<PassiveStorageResponse.Data>> lists = SplitListByCountUtil.splitListByCount(passiveStorageResponseDataDtoArrayList, 100);
//            for (int i = 0; i < lists.size(); i++) {
//                List<PassiveStorageResponse.Data> data = lists.get(i);
//                String idStr = commaConcatenatedPrimaryKeyStock(data);
//                List<OnlyAfterSalesBEntity> onlyAfterSalesBEntityList = queryStockTocOutLog2(idStr);
//                tocofsReturngoodsDetailedEntityList.addAll(onlyAfterSalesBEntityList);
//            }
//        }
//        return filterDataRowsAsPushOrFailedTran(tocofsReturngoodsDetailedEntityList, passiveStorageResponseDataDtoArrayList);
//    }

    /**
     * 逗号拼接字符串主键，作为批处理的一部分，方便下一步的批量查询操作
     * 入库和退款导致完成都可以通用
     *
     * @author liuyang
     */
    private String commaConcatenatedPrimaryKeyStock(List<PassiveStorageResponse.Data> headerDetailsDtoList2) throws Exception {
        StringBuffer idStr = new StringBuffer();
        if (headerDetailsDtoList2 != null && headerDetailsDtoList2.size() > 0) {
            for (int i = 0; i < headerDetailsDtoList2.size(); i++) {
                PassiveStorageResponse.Data data = headerDetailsDtoList2.get(i);
                PassiveStorageResponse.Header header = data.getHeader();
                List<PassiveStorageResponse.Details> details = data.getDetails();
                for (int j = 0; j < details.size(); j++) {
                    PassiveStorageResponse.Details details1 = details.get(j);
                    Assert.notNull(details1.getId(), "O明细主键不能为空！");
                    Assert.state(!"".equals(details1.getId()), "O明细主键不能为空！");

//                    idStr.append("'");
                    idStr.append(details1.getId());
//                    idStr.append("'");
                    idStr.append(",");
                }
            }
        }
        if (idStr.length() > 0) {
            return idStr.substring(0, idStr.length() - 1);
        }
        return null;
    }

    private String commaConcatenatedPrimaryKeyStock2(List<RerturnGoodsOrderSearchData> rerturnGoodsOrderSearchDataList) throws Exception {
        StringBuffer idStr = new StringBuffer();
        if (rerturnGoodsOrderSearchDataList != null && rerturnGoodsOrderSearchDataList.size() > 0) {
            for (int i = 0; i < rerturnGoodsOrderSearchDataList.size(); i++) {
                RerturnGoodsOrderSearchData rerturnGoodsOrderSearchData = rerturnGoodsOrderSearchDataList.get(i);
                RerturnGoodsOrderSearchHeader header = rerturnGoodsOrderSearchData.getHeader();
                List<RerturnGoodsOrderSearchDetails> details = rerturnGoodsOrderSearchData.getDetails();

                for (int j = 0; j < details.size(); j++) {
                    RerturnGoodsOrderSearchDetails rerturnGoodsOrderSearchDetails = details.get(j);
                    Assert.notNull(rerturnGoodsOrderSearchDetails.getId(), "O明细主键不能为空！");
                    Assert.state(!"".equals(rerturnGoodsOrderSearchDetails.getId()), "O明细主键不能为空！");

                    idStr.append(rerturnGoodsOrderSearchDetails.getId());
                    idStr.append(",");
                }
            }
        }
        if (idStr.length() > 0) {
            return idStr.substring(0, idStr.length() - 1);
        }
        return null;
    }

    /**
     * 批查询toc退货入库日志，查询的量由splitListByCount方法控制
     *
     * @author liuyang
     */
    private List<OfsPassiveorderDetailEntity> queryStockTocOutLog(String idStr) throws Exception {
        List<OfsPassiveorderDetailEntity> tocofsReturngoodsDetailedEntities = null;
        if (idStr != null && !"".equals(idStr.trim())) {
            OfsPassiveorderDetailEntity ofsPassiveorderDetailEntity = new OfsPassiveorderDetailEntity();
            ofsPassiveorderDetailEntity.setIds(idStr);
            tocofsReturngoodsDetailedEntities = iOfsPassiveorderDetailDao.query(ofsPassiveorderDetailEntity);
        } else {
            logger.error("idStr为空，无法查询数据！");
        }
        return tocofsReturngoodsDetailedEntities;
    }

    /**
     * 批量查询售后订单推送日志
     *
     * @author liuyang
     */
    private List<OnlyAfterSalesBEntity> queryStockTocOutLog2(String idStr) throws Exception {
        List<OnlyAfterSalesBEntity> onlyAfterSalesBEntityList = null;
        if (idStr != null && !"".equals(idStr.trim())) {
            OnlyAfterSalesBEntity onlyAfterSalesBEntity = new OnlyAfterSalesBEntity();
            onlyAfterSalesBEntity.setOfsids(idStr);
            onlyAfterSalesBEntityList = iOnlyAfterSalesBDao.query(onlyAfterSalesBEntity);
        } else {
            logger.error("idStr为空，无法查询数据！");
        }
        return onlyAfterSalesBEntityList;
    }

    /**
     * 保存抓取到的数据到mysql底表，如果底表里已经存在，则会忽略，并且发生更新
     *
     * @param passiveStorageResponseDataDtoArrayList 需要保存到 Mysql 底表的数据行，采用批量插入的方式
     * @author liuyang
     */
    private void batchInsert(List<PassiveStorageResponse.Data> passiveStorageResponseDataDtoArrayList) throws Exception {
        if (passiveStorageResponseDataDtoArrayList != null && passiveStorageResponseDataDtoArrayList.size() > 0) {
            List<PassiveStorageResponse.Header> headerDetailsDtoList1 = new ArrayList<>();
            List<PassiveStorageResponse.Details> headerDetailsDtoList2 = new ArrayList<>();

            for (PassiveStorageResponse.Data index : passiveStorageResponseDataDtoArrayList) {
                //主表、明细表
                PassiveStorageResponse.Header header = index.getHeader();
                List<PassiveStorageResponse.Details> details = index.getDetails();
                if (details != null && details.size() > 0) {
                    for (PassiveStorageResponse.Details passiveStorageResponseDetails : details) {
                        passiveStorageResponseDetails.setHeader(header);
                    }
                }
                headerDetailsDtoList1.add(header);
                headerDetailsDtoList2.addAll(details);
            }

            //每100作为一个批次插入主表，根据主键（id）判断是否重复，如果重复的，则不进行插入
            List<List<PassiveStorageResponse.Header>> lists = SplitListByCountUtil.splitListByCount(headerDetailsDtoList1, 100);
            for (int i = 0; i < lists.size(); i++) {
                List<PassiveStorageResponse.Header> headers = lists.get(i);

                final Throwable[] childException = {null};
                long startTime = System.currentTimeMillis();
                Thread thread = new Thread(new Runnable() {
                    @Override
                    public void run() {
                        try {
                            List<OfsPassiveorderHeaderEntity> ofsPassiveorderHeaderEntities = copyHeaderDto(headers);
                            if (ofsPassiveorderHeaderEntities.size() > 0) {
                                logger.info("插入底表{}个对象（表头）", ofsPassiveorderHeaderEntities.size());
                                iOfsPassiveorderHeaderDao.entityInsertOrUpdateBatch(ofsPassiveorderHeaderEntities);
                            } else {
                                logger.info("ofsPassiveorderHeaderEntities：没有对象被插入表头底表");
                            }
                        } catch (Exception e) {
                            logger.error("线程保存无源件主表抛出异常", e);
                            childException[0] = e;
                        }
                    }
                });
                thread.start();
                try {
                    thread.join();
                } catch (Exception e) {
                    logger.error("线程保存TOC退货主表抛出异常", e);
                    childException[0] = e;
                }
                long endTime = System.currentTimeMillis();
                logger.info("插入或更新无源入库单表-耗时：{}", (endTime - startTime));

                //如果子线程抛出异常，则反馈到主线程方便排查
                if (childException[0] != null) {
                    Assert.state(false, childException[0].getMessage());
                }
            }

            //插入明细表
            List<List<PassiveStorageResponse.Details>> lists1 = SplitListByCountUtil.splitListByCount(headerDetailsDtoList2, 100);
            for (int i = 0; i < lists1.size(); i++) {
                List<PassiveStorageResponse.Details> details = lists1.get(i);
                List<OfsPassiveorderDetailEntity> ofsPassiveorderDetailEntities = copyDetailsDto(details);

                final Throwable[] childException = {null};
                long startTime = System.currentTimeMillis();
                Thread thread = new Thread(new Runnable() {
                    @Override
                    public void run() {
                        try {
                            if (ofsPassiveorderDetailEntities.size() > 0) {
                                logger.info("插入底表{}个对象（表体）", ofsPassiveorderDetailEntities.size());
                                iOfsPassiveorderDetailDao.entityInsertOrUpdateBatch(ofsPassiveorderDetailEntities);
                            } else {
                                logger.info("ofsPassiveorderDetailEntities：没有对象被插入表头底表");
                            }
                        } catch (Exception e) {
                            logger.error("线程保存TOC退货明细抛出异常", e);
                            childException[0] = e;
                        }
                    }
                });
                thread.start();
                try {
                    thread.join();
                } catch (Exception e) {
                    logger.error("线程保存无源件明细表抛出异常", e);
                    childException[0] = e;
                }
                long endTime = System.currentTimeMillis();
                logger.info("插入或更新TOC退货入库表体-耗时：{}", (endTime - startTime));
                //如果子线程抛出异常，则反馈到主线程方便排查
                if (childException[0] != null) {
                    Assert.state(false, childException[0].getMessage());
                }
            }
        }
    }

    /**
     * 查询OFS售后退货入库单
     *
     * @param queryOfsSoSaleOutVo  查询参数
     * @param headerDetailsDtoList 查询结果集
     * @param pageNo               从第pageNo页开始查询
     */
//    private void queryOfsReturnGoods(QueryOfsSoSaleOutVo queryOfsSoSaleOutVo, List<ReturnGoodHeaderDetailsDataDto> headerDetailsDtoList, Long pageNo) throws Exception {
//
//        Long pageSize = 200L;
//        queryOfsSoSaleOutVo.setPageNo(pageNo);
//        queryOfsSoSaleOutVo.setPageSize(pageSize);
//
//        InterfaceParamDto interfaceParamDto = new InterfaceParamDto();
//        interfaceParamDto.setApi("ofs.receipt.search");
//        interfaceParamDto.setData(JSON.toJSONString(queryOfsSoSaleOutVo));
//        RertunGoodsRootBean rertunGoodsRootBean = (RertunGoodsRootBean) ofsUnifiedService.unified(interfaceParamDto);
//        if (rertunGoodsRootBean != null) {
//            if ("false".equals(rertunGoodsRootBean.getError()) && "0".equals(rertunGoodsRootBean.getCode()) && "Success".equals(rertunGoodsRootBean.getMsg())) {
//                List<ReturnGoodHeaderDetailsDataDto> returnGoodHeaderDetailsDataDtoList = rertunGoodsRootBean.getData();
//                if (returnGoodHeaderDetailsDataDtoList != null && returnGoodHeaderDetailsDataDtoList.size() > 0) {
//                    headerDetailsDtoList.addAll(returnGoodHeaderDetailsDataDtoList);
//
//                    //OFS没有提供分页字段，等待开发
//                }
//            } else {
//                logger.error("查询失败，失败原因:{}", JSON.toJSON(interfaceParamDto));
//            }
//        } else {
//            logger.error("rertunGoodsRootBean为空！interfaceParamDto对象的结果集json：{}", JSON.toJSON(interfaceParamDto));
//        }
//    }

//    public void queryOfsSaleOrder() throws Exception {
//        QueryOfsSoSaleOutVo queryOfsSoSaleOutVo = new QueryOfsSoSaleOutVo();
//        queryOfsSoSaleOutVo.setCreated_start("2024-07-05 16:38:00");
//        queryOfsSoSaleOutVo.setCreated_end("2024-07-05 16:40:30");
//        queryOfsSoSaleOutVo.setClientCode("LETS");
////        queryOfsSoSaleOutVo.setInternalInstructionType("SALES");
//        queryOfsSoSaleOutVo.setCompanyCode("SHLZ");
////        queryOfsSoSaleOutVo.setStatus(900L);
//        queryOfsSoSaleOutVo.setPageNo(1L);
//        queryOfsSoSaleOutVo.setPageSize(50L);
//        queryOfsSoSaleOutVo.setCode("LETS-SH2024070500000003");
//
//        InterfaceParamDto interfaceParamDto = new InterfaceParamDto();
//        interfaceParamDto.setApi("ofs.shipment.search");
//        interfaceParamDto.setData(JSON.toJSONString(queryOfsSoSaleOutVo));
//        SaleOutReturnMessageDto saleOutReturnMessageDto = (SaleOutReturnMessageDto) ofsUnifiedService.unified(interfaceParamDto);
//        System.out.println(saleOutReturnMessageDto);
//    }

    /**
     * 库存同步，代码同步逻辑
     *
     * @param passiveStorageResponseList O无源入库单对象
     * @author liuyang
     */
    private void implementStock(List<PassiveStorageResponse.Data> passiveStorageResponseList) throws Exception {
        Assert.notNull(passiveStorageResponseList, "passiveStorageResponseList不能为空");
        logger.info("TOC无源件退货入库：{} 行需要进行数据转换", passiveStorageResponseList.size());

        if (passiveStorageResponseList.size() > 0) {
            try {
                // 查询基本档案
                String sceneType = "stock";
                List<PassiveStorageSonDetailsDto> passiveStorageSonDetailsDtos = queryBasicArchivesStock(passiveStorageResponseList, sceneType);
                // 分组汇总
                String dimension = null;
//                dimension = "1001&dy-intoyou&B2CHA20240033&6973391733588&SALES&002";
                Map<String, List<PassiveStorageSonDetailsDto>> stringListMap = groupSummary(passiveStorageSonDetailsDtos, dimension);
                // 查询U8C业务流程
                BdBusitypeEntity bdBusitypeEntity = u8cOperationFlow();
                // 查询销售收发类别
//                BdRdclEntity bdRdclEntity = rdclUtil.queryRdClObject("202");
                //初始化所有存货管理档案对应的结存价+采购价
//                List<Map> mapList = initAllBalancePricePurchasePrice();
                //查询「平台运费」、「平台优惠」、「支付优惠」、「达人优惠」存货基本档案（注意没有商家优惠）
                List<BdInvbasdocEntity> bdInvbasdocEntities = queryAdditionUtil.queryStockBasicArchives();
                Map<String, BdInvbasdocEntity> mapBdInvbasdocEntity = bdInvbasdocEntities.stream().collect(Collectors.toMap(BdInvbasdocEntity::getInvcode, entity -> entity));
                String pkInvbasdocStr = bdInvbasdocEntities.stream().map(entity -> "'" + entity.getInvcode() + "'").collect(Collectors.joining(","));
                //查询存货对应的税目
                Map<String, BdTaxitemsEntity> stringBdTaxitemsEntityMap = queryAdditionUtil.queryBatchBdTaxitems(pkInvbasdocStr);
                //查询「平台运费」对应的税率
//                BdTaxitemsEntity bdTaxitemsEntity = queryBdTaxitems(bdInvbasdocEntity1.getInvcode());
                //查询「平台运费」、「平台优惠」、「支付优惠」、「达人优惠」所有公司的存货管理档案
                Map<String, BdInvmandocEntity> stringBdInvmandocEntityMap = queryAdditionUtil.queryInventoryMan(bdInvbasdocEntities);

                if (bdBusitypeEntity != null && stringListMap != null) {
                    Iterator<Map.Entry<String, List<PassiveStorageSonDetailsDto>>> iterator = stringListMap.entrySet().iterator();
                    while (iterator.hasNext()) {
                        Map.Entry<String, List<PassiveStorageSonDetailsDto>> next = iterator.next();
                        String keyGroup = next.getKey();
                        List<PassiveStorageSonDetailsDto> value = next.getValue();

                        PassiveStorageResponse.Header header = value.get(0).getHeader();
                        BdCorpEntity bdCorpEntity = value.get(0).getBdCorpEntity();//表头销售公司
                        BdCorpEntity deliverGoodsCorp = value.get(0).getDeliverGoodsCorp();//发货公司
                        BdCalbodyEntity bdCalbodyEntity = value.get(0).getBdCalbodyEntity();//发货仓库组织
                        BdStordocEntity bdStordocEntity = value.get(0).getBdStordocEntity();//发货仓库
                        BdCalbodyEntity bdCalbodyEntity1 = value.get(0).getBdCalbodyEntity1();//收货库存组织
                        BdStordocEntity bdStordocEntity1 = value.get(0).getBdStordocEntity1();//收货仓库
                        BdSalestruEntity bdSalestruEntity = value.get(0).getBdSalestruEntity();//销售组织
                        BdDeptdocEntity bdDeptdocEntity = value.get(0).getBdDeptdocEntity();//业务部门
                        BdCumandocEntity bdCumandocEntity = value.get(0).getBdCumandocEntity();//客商管理档案
                        BdCubasdocEntity bdCubasdocEntity = value.get(0).getBdCubasdocEntity();//客商基本档案
                        BdDefdocEntity platformArchives = value.get(0).getPlatformArchives();//U8C平台档案
                        BdDefdocEntity shopArchives = value.get(0).getShopArchives();//U8C店铺档案
                        BdRdclEntity bdRdclEntity = value.get(0).getBdRdclEntity();//U8C收发类别

                        try {
//                            checkArchives(oldValue.get(0));
                            //生成业务日期
                            String generateBusinessDate = createGenerateBusinessDate(header);

                            SaleorderRequestDto saleorderRequestDto = new SaleorderRequestDto();
                            SaleorderRequestParentDto saleorderRequestParentDto = new SaleorderRequestParentDto();
                            saleorderRequestParentDto.setDbilldate(generateBusinessDate);//单据日期
                            saleorderRequestParentDto.setBretinvflag("Y");//退货标记
                            saleorderRequestParentDto.setCbiztype(bdBusitypeEntity.getPkBusitype());//业务流程
                            saleorderRequestParentDto.setCcalbodyid(bdCalbodyEntity.getPkCalbody());//库存组织
                            saleorderRequestParentDto.setCcustomerid(bdCumandocEntity.getPkCumandoc());//客户=开票单位=收货单位=表体收货单位=收货单位
                            saleorderRequestParentDto.setCdeptid(bdDeptdocEntity.getPkDeptdoc());//部门
                            saleorderRequestParentDto.setCemployeeid(null);//业务员
                            saleorderRequestParentDto.setCoperatorid(OverallConstant.getOverAllValue("u8cApiZdrPK"));//制单人
                            saleorderRequestParentDto.setCreceiptcorpid(bdCumandocEntity.getPkCumandoc());//开票单位
                            saleorderRequestParentDto.setCreceiptcustomerid(bdCumandocEntity.getPkCumandoc());//收货单位
                            saleorderRequestParentDto.setCsalecorpid(bdSalestruEntity.getCsalestruid());//销售组织
                            saleorderRequestParentDto.setCwarehouseid(bdStordocEntity.getPkStordoc());//仓库
                            saleorderRequestParentDto.setDapprovedate(generateBusinessDate);//审核日期
                            saleorderRequestParentDto.setNdiscountrate("100.000000");//整单折扣
                            saleorderRequestParentDto.setPk_corp(bdCorpEntity.getPkCorp());//公司id
                            //汇总单号=汇总维度
                            saleorderRequestParentDto.setVdef18(keyGroup);
                            //平台
                            saleorderRequestParentDto.setPk_defdoc2(platformArchives.getPkDefdoc());
                            saleorderRequestParentDto.setVdef2(platformArchives.getDocname());
                            saleorderRequestParentDto.setVdef17(ProfilesActiveConstant.sourceSystem1);//来源系统

                            //收发类别
                            saleorderRequestParentDto.setPk_defdoc3(bdRdclEntity.getPkRdcl());
                            saleorderRequestParentDto.setVdef3(bdRdclEntity.getRdname());

                            //2024年8月8日 17:17:58 店铺档案自定义项1，先不传，后续维护好之后再传!
                            //店铺
                            saleorderRequestParentDto.setPk_defdoc1(shopArchives.getPkDefdoc());
                            saleorderRequestParentDto.setVdef1(shopArchives.getDocname());

                            //单据红字标识
                            saleorderRequestParentDto.setPk_defdoc16(OverallConstant.getOverAllValue("u8c自定义项档案-单据红字标识-Y主键"));
                            saleorderRequestParentDto.setVdef16(OverallConstant.getOverAllValue("u8c自定义项档案-单据红字标识-Y名称"));

                            saleorderRequestDto.setParentvo(saleorderRequestParentDto);

                            List<SaleorderRequestChildrenDto> saleorderRequestChildrenDtoList = new ArrayList<>();
                            saleorderRequestDto.setChildrenvo(saleorderRequestChildrenDtoList);

                            //验证是否为指定的店铺，如果为true，则取结存价
                            Boolean isCheckShopChoose = balanceUnitPriceUtil.checkOfsShop(header.getStoreCode());

                            //把汇总好的出库单明细行合并成一行
                            PassiveStorageSonDetailsDto passiveStorageSonDetailsDto = groupMergeDetailedRows(value, isCheckShopChoose);
                            //存货管理档案：取发货公司的存货管理档案
                            BdInvmandocEntity bdInvmandocEntity = value.get(0).getBdInvmandocEntity();
                            //存货基础档案
                            BdInvbasdocEntity bdInvbasdocEntity = value.get(0).getBdInvbasdocEntity();
                            //根据存货基础档案编码，查询当前存货的税率
                            BdTaxitemsEntity bdTaxitemsEntity1 = value.get(0).getBdTaxitemsEntity();

                            //判断是否为赠品
                            Boolean isblargessflag = false;
                            if ("0".equals(passiveStorageSonDetailsDto.getGroupTotalPayAmount().setScale(2, BigDecimal.ROUND_HALF_UP).stripTrailingZeros().toPlainString())) {
                                isblargessflag = true;
                            }

                            SaleorderRequestChildrenDto saleorderRequestChildrenDto = new SaleorderRequestChildrenDto();
                            saleorderRequestChildrenDto.setBlargessflag(isblargessflag);//是否赠品
                            saleorderRequestChildrenDto.setCadvisecalbodyid(bdCalbodyEntity.getPkCalbody());//发货库存组织
                            saleorderRequestChildrenDto.setCbodywarehouseid(bdStordocEntity.getPkStordoc());//发货仓库
                            saleorderRequestChildrenDto.setCconsigncorpid(deliverGoodsCorp.getPkCorp());//发货公司
                            saleorderRequestChildrenDto.setCcurrencytypeid("00010000000000000001");//币种
                            saleorderRequestChildrenDto.setCinventoryid(bdInvmandocEntity.getPkInvmandoc());//存货id
                            saleorderRequestChildrenDto.setCreceiptcorpid(bdCumandocEntity.getPkCumandoc());//收货单位
                            saleorderRequestChildrenDto.setDconsigndate(generateBusinessDate);//计划发货日期
                            saleorderRequestChildrenDto.setDdeliverdate(generateBusinessDate);//	要求收货日期
                            saleorderRequestChildrenDto.setNexchangeotobrate("1.00000000");//折本汇率
                            saleorderRequestChildrenDto.setNitemdiscountrate("100.000000");//单品折扣
                            saleorderRequestChildrenDto.setNnumber("-" + passiveStorageSonDetailsDto.getGroupShipQty().stripTrailingZeros().toPlainString());//数量
                            saleorderRequestChildrenDto.setNoriginalcurdiscountmny("0");//折扣额
//                            saleorderRequestChildrenDto.setNoriginalcurmny("-" + noriginalcurmny.stripTrailingZeros().toPlainString());//无税金额
//                            saleorderRequestChildrenDto.setNoriginalcurnetprice(noriginalcurprice.stripTrailingZeros().toPlainString());//无税净价
//                            saleorderRequestChildrenDto.setNoriginalcurprice(noriginalcurprice.stripTrailingZeros().toPlainString());//无税单价
//                            saleorderRequestChildrenDto.setNoriginalcursummny("-" + noriginalcursummny.stripTrailingZeros().toPlainString());//价税合计
                            if (isblargessflag) {
                                saleorderRequestChildrenDto.setNoriginalcursummny("0");//价税合计 新逻辑
                            } else {
                                saleorderRequestChildrenDto.setNoriginalcursummny("-" + passiveStorageSonDetailsDto.getGroupTotalPayAmount().setScale(2, BigDecimal.ROUND_HALF_UP).stripTrailingZeros().toPlainString());//价税合计 新逻辑
                            }
//                            saleorderRequestChildrenDto.setNoriginalcurtaxmny("-" + noriginalcurtaxmny.stripTrailingZeros().toPlainString());//税额
//                            saleorderRequestChildrenDto.setNoriginalcurtaxnetprice(noriginalcurtaxprice.stripTrailingZeros().toPlainString());//含税净价
//                            saleorderRequestChildrenDto.setNoriginalcurtaxprice(noriginalcurtaxprice.stripTrailingZeros().toPlainString());//含税单价
//                            saleorderRequestChildrenDto.setNtaxrate(new BigDecimal(bdTaxitemsEntity1.getTaxratio()).stripTrailingZeros().toPlainString());//税率
//                            saleorderRequestChildrenDto.setVdef2(bdCostsubjEntity.getCostname());//收支项目
//                            saleorderRequestChildrenDto.setPk_defdoc2(bdCostsubjEntity.getPkCostsubj());
                            //如果优惠金额为0，则传0
                            if (!"0".equals(passiveStorageSonDetailsDto.getVdef4().stripTrailingZeros().toPlainString())) {
                                saleorderRequestChildrenDto.setVdef4("-" + passiveStorageSonDetailsDto.getVdef4().stripTrailingZeros().toPlainString());
                            } else {
                                saleorderRequestChildrenDto.setVdef4("0");
                            }
                            if (!"0".equals(passiveStorageSonDetailsDto.getVdef5().stripTrailingZeros().toPlainString())) {
                                saleorderRequestChildrenDto.setVdef5("-" + passiveStorageSonDetailsDto.getVdef5().stripTrailingZeros().toPlainString());
                            } else {
                                saleorderRequestChildrenDto.setVdef5("0");
                            }
                            if (!"0".equals(passiveStorageSonDetailsDto.getVdef6().stripTrailingZeros().toPlainString())) {
                                saleorderRequestChildrenDto.setVdef6("-" + passiveStorageSonDetailsDto.getVdef6().stripTrailingZeros().toPlainString());
                            } else {
                                saleorderRequestChildrenDto.setVdef6("0");
                            }
                            if (!"0".equals(passiveStorageSonDetailsDto.getVdef7().stripTrailingZeros().toPlainString())) {
                                saleorderRequestChildrenDto.setVdef7("-" + passiveStorageSonDetailsDto.getVdef7().stripTrailingZeros().toPlainString());
                            } else {
                                saleorderRequestChildrenDto.setVdef7("0");
                            }
                            saleorderRequestChildrenDtoList.add(saleorderRequestChildrenDto);

                            //平台优惠
                            if (passiveStorageSonDetailsDto.getVdef4() != null) {
                                BigDecimal vdef4 = passiveStorageSonDetailsDto.getVdef4();
                                if (vdef4.compareTo(BigDecimal.ZERO) > 0) {
                                    //发货运费-存货基本档案
                                    BdInvbasdocEntity bdInvbasdocEntity1 = mapBdInvbasdocEntity.get("FY01");
                                    //存货管理档案
                                    BdInvmandocEntity bdInvmandocEntity1 = stringBdInvmandocEntityMap.get(bdInvbasdocEntity1.getInvcode() + deliverGoodsCorp.getPkCorp());
                                    //存货对应的税率
                                    BdTaxitemsEntity bdTaxitemsEntity = stringBdTaxitemsEntityMap.get("FY01");
                                    //补充：平台优惠-存货
                                    BigDecimal absAccumulatedPostage = vdef4.abs();
                                    BigDecimal negativeValue = absAccumulatedPostage.negate();
                                    queryAdditionUtil.additional(saleorderRequestChildrenDtoList, bdInvmandocEntity1, bdInvbasdocEntity1, negativeValue, "-1", bdTaxitemsEntity);
                                }
                            }
                            //达人优惠
                            if (passiveStorageSonDetailsDto.getVdef6() != null) {
                                BigDecimal vdef6 = passiveStorageSonDetailsDto.getVdef6();
                                if (vdef6.compareTo(BigDecimal.ZERO) > 0) {
                                    //发货运费-存货基本档案
                                    BdInvbasdocEntity bdInvbasdocEntity1 = mapBdInvbasdocEntity.get("FY02");
                                    //存货管理档案
                                    BdInvmandocEntity bdInvmandocEntity1 = stringBdInvmandocEntityMap.get(bdInvbasdocEntity1.getInvcode() + deliverGoodsCorp.getPkCorp());
                                    //存货对应的税率
                                    BdTaxitemsEntity bdTaxitemsEntity = stringBdTaxitemsEntityMap.get("FY02");
                                    //补充：达人优惠-存货
                                    BigDecimal absAccumulatedPostage = vdef6.abs();
                                    BigDecimal negativeValue = absAccumulatedPostage.negate();
                                    queryAdditionUtil.additional(saleorderRequestChildrenDtoList, bdInvmandocEntity1, bdInvbasdocEntity1, negativeValue, "-1", bdTaxitemsEntity);
                                }
                            }
                            //支付优惠
                            if (passiveStorageSonDetailsDto.getVdef5() != null) {
                                BigDecimal vdef5 = passiveStorageSonDetailsDto.getVdef5();
                                if (vdef5.compareTo(BigDecimal.ZERO) > 0) {
                                    //发货运费-存货基本档案
                                    BdInvbasdocEntity bdInvbasdocEntity1 = mapBdInvbasdocEntity.get("FY04");
                                    //存货管理档案
                                    BdInvmandocEntity bdInvmandocEntity1 = stringBdInvmandocEntityMap.get(bdInvbasdocEntity1.getInvcode() + deliverGoodsCorp.getPkCorp());
                                    //存货对应的税率
                                    BdTaxitemsEntity bdTaxitemsEntity = stringBdTaxitemsEntityMap.get("FY04");
                                    //补充：支付优惠-存货
                                    BigDecimal absAccumulatedPostage = vdef5.abs();
                                    BigDecimal negativeValue = absAccumulatedPostage.negate();
                                    queryAdditionUtil.additional(saleorderRequestChildrenDtoList, bdInvmandocEntity1, bdInvbasdocEntity1, negativeValue, "-1", bdTaxitemsEntity);
                                }
                            }
                            //推送u8c
                            List<SaleorderRequestDto> saleorderRequestDtoList = new ArrayList<>();
                            saleorderRequestDtoList.add(saleorderRequestDto);
                            Map<String, List<SaleorderRequestDto>> stringStringMap = new HashMap<>();
                            stringStringMap.put("saleorder", saleorderRequestDtoList);
                            SoSaleResultRootDto soSaleResultRootDto = sendU8CTOCOrder(JSON.toJSONString(stringStringMap));
                            String vreceiptcode = null;
                            String pk_corp = null;
                            String csaleid = null;
                            if (soSaleResultRootDto != null && soSaleResultRootDto.getParentvo() != null) {
                                vreceiptcode = soSaleResultRootDto.getParentvo().getVreceiptcode();
                                pk_corp = soSaleResultRootDto.getParentvo().getPk_corp();
                                csaleid = soSaleResultRootDto.getParentvo().getCsaleid();
                            }
                            logger.info("TOC红字销售订单编号：{} 主键：{} 销售公司：{}", vreceiptcode, csaleid, pk_corp);
                            updateSuccessOrFail1(value, "Y", "success", vreceiptcode, csaleid);
                        } catch (Exception e) {
                            //记录失败
                            logger.error("无源件业务转换成U8C对象过程中、或者单据推送到U8C出现异常！", e);
                            String message = e.getMessage();
                            if (message == null) {
                                message = "未知错误";
                            }
                            updateSuccessOrFail1(value, "N", message, null, null);
                        }
                    }
                } else {
                    //2024年8月6日 11:28:54此处不记录失败，不认为是错误
                    logger.info("summaryDimensionMap变量或者bdBusitypeEntity变量为空，因此主要的推送逻辑不会被执行！");
                }
            } catch (Exception e) {
                logger.error("外层转换逻辑抛出异常", e);
            }
        }
    }

    /**
     * 到账成功：代码同步逻辑
     *
     * @param passiveStorageResponseDataList O无源入库单推送转换
     * @author liuyang
     */
    private void implementTran(List<PassiveStorageResponse.Data> passiveStorageResponseDataList) throws Exception {
        if (passiveStorageResponseDataList != null && passiveStorageResponseDataList.size() > 0) {
            logger.info("TOC无源件业务：{}行需要进行数据转换", passiveStorageResponseDataList.size());

            try {
                // 查询基本档案
//                String sceneType = "tran";
                List<PassiveStorageSonDetailsDto2> passiveStorageSonDetailsDto2s = queryBasicArchivesTran(passiveStorageResponseDataList);

                // 分组汇总
                String dimension = null;
                Map<String, List<PassiveStorageSonDetailsDto2>> stringListMap = groupSummary2(passiveStorageSonDetailsDto2s, dimension);
                // 查询U8C业务流程-红字应收单
                BdBusitypeEntity bdBusitypeEntity = u8cOperationFlowV2();
                //初始化所有存货管理档案对应的结存价+采购价
//                List<Map> mapList = initAllBalancePricePurchasePrice();
                //查询「平台运费」、「平台优惠」、「支付优惠」、「达人优惠」存货基本档案（注意没有商家优惠）
                List<BdInvbasdocEntity> bdInvbasdocEntities = queryAdditionUtil.queryStockBasicArchives();
                Map<String, BdInvbasdocEntity> mapBdInvbasdocEntity = bdInvbasdocEntities.stream().collect(Collectors.toMap(BdInvbasdocEntity::getInvcode, entity -> entity));
                String pkInvbasdocStr = bdInvbasdocEntities.stream().map(entity -> "'" + entity.getInvcode() + "'").collect(Collectors.joining(","));
                //查询存货对应的税目
                Map<String, BdTaxitemsEntity> stringBdTaxitemsEntityMap = queryAdditionUtil.queryBatchBdTaxitems(pkInvbasdocStr);
                //查询「平台运费」对应的税率
//                BdTaxitemsEntity bdTaxitemsEntity = queryBdTaxitems(bdInvbasdocEntity1.getInvcode());
                //查询「平台运费」、「平台优惠」、「支付优惠」、「达人优惠」所有公司的存货管理档案
                Map<String, BdInvmandocEntity> stringBdInvmandocEntityMap = queryAdditionUtil.queryInventoryMan(bdInvbasdocEntities);

                if (bdBusitypeEntity != null && stringListMap != null) {
                    Iterator<Map.Entry<String, List<PassiveStorageSonDetailsDto2>>> iterator = stringListMap.entrySet().iterator();
                    while (iterator.hasNext()) {
                        Map.Entry<String, List<PassiveStorageSonDetailsDto2>> next = iterator.next();
                        String key = next.getKey();
                        List<PassiveStorageSonDetailsDto2> value = next.getValue();
                        RerturnGoodsOrderSearchHeader header = value.get(0).getHeader();

                        BdCorpEntity bdCorpEntity = value.get(0).getBdCorpEntity();//表头销售公司
                        BdCorpEntity deliverGoodsCorp = value.get(0).getDeliverGoodsCorp();//发货公司
                        BdCalbodyEntity bdCalbodyEntity = value.get(0).getBdCalbodyEntity();//发货仓库组织
//                        BdStordocEntity bdStordocEntity = value.get(0).getBdStordocEntity();//发货仓库
                        BdCalbodyEntity bdCalbodyEntity1 = value.get(0).getBdCalbodyEntity1();//收货库存组织
//                        BdStordocEntity bdStordocEntity1 = value.get(0).getBdStordocEntity1();//收货仓库
                        BdSalestruEntity bdSalestruEntity = value.get(0).getBdSalestruEntity();//销售组织
                        BdDeptdocEntity bdDeptdocEntity = value.get(0).getBdDeptdocEntity();//业务部门
                        BdCumandocEntity bdCumandocEntity = value.get(0).getBdCumandocEntity();//客商管理档案
                        BdCubasdocEntity bdCubasdocEntity = value.get(0).getBdCubasdocEntity();//客商基本档案
                        BdDefdocEntity platformArchives = value.get(0).getPlatformArchives();//U8C平台档案
                        BdDefdocEntity shopArchives = value.get(0).getShopArchives();//U8C店铺档案
                        BdRdclEntity bdRdclEntity = value.get(0).getBdRdclEntity();//U8C收发类别

                        try {
                            //生成业务日期
//                            String generateBusinessDate = createSuccessFulTradeDate(header);
                            String generateBusinessDate = value.get(0).getTargetBusinessDate().substring(0, 10);

                            //组装应收单表头
                            ArapDjzbVO.Parentt parentVo = new ArapDjzbVO.Parentt();
                            parentVo.setDjrq(generateBusinessDate);//单据日期
                            parentVo.setDwbm(bdCorpEntity.getUnitcode());//公司
                            parentVo.setLrr(OverallConstant.getOverAllValue("u8cApiZdrCode"));//录入人
                            parentVo.setWldx("0");//往来对象标识 固定为：客户
                            parentVo.setDeptid(bdDeptdocEntity.getDeptcode());//部门
                            parentVo.setShr(OverallConstant.getOverAllValue("u8cApiZdrCode"));//审批人
                            parentVo.setShrq(generateBusinessDate);//审核日期
                            parentVo.setDjlxbm("D0");//单据类型编码
                            parentVo.setXslxbm(bdBusitypeEntity.getBusicode());//业务流程
                            parentVo.setFeinvstatus("0");//开票状态
                            parentVo.setHbbm(bdCubasdocEntity.getCustcode());//客商主键
                            //店铺档案
                            parentVo.setZyx1(shopArchives.getDoccode());
//                            parentVo.setDef1(shopArchives.getDocname());
                            //来源平台
                            parentVo.setZyx2(platformArchives.getDoccode());
//                            parentVo.setDef2(platformArchives.getDocname());
                            //收发类别
                            parentVo.setZyx3(bdRdclEntity.getRdcode());
//                            parentVo.setDef3(bdRdclEntity.getRdname());
                            //单据红字标识
                            parentVo.setZyx16("1");
//                            parentVo.setDef16(OverallConstant.getOverAllValue("u8c自定义项档案-单据红字标识-Y名称"));
//                            parentVo.setZyx19();//自定义项19 OFS单号不传，因为是汇总的
                            parentVo.setZyx17(ProfilesActiveConstant.sourceSystem1);//来源系统
                            parentVo.setZyx18(key);

                            //验证是否为指定的店铺，如果为true，则取结存价
                            Boolean isCheckShopChoose = balanceUnitPriceUtil.checkOfsShop(header.getStoreCode());
                            //把汇总好的出库单明细行合并成一行
                            PassiveStorageSonDetailsDto2 passiveStorageSonDetailsDto2 = groupMergeDetailedRows2(value, isCheckShopChoose);
                            //存货管理档案：取发货公司的存货管理档案
                            BdInvmandocEntity bdInvmandocEntity = value.get(0).getBdInvmandocEntity();
                            //存货基础档案
                            BdInvbasdocEntity bdInvbasdocEntity = value.get(0).getBdInvbasdocEntity();
                            //根据存货基础档案编码，查询当前存货的税率
                            BdTaxitemsEntity bdTaxitemsEntity1 = value.get(0).getBdTaxitemsEntity();

                            //如果合并后的金额为0，则不传到U8C
                            Assert.notNull(passiveStorageSonDetailsDto2.getGroupTotalPayAmount(), "passiveStorageSonDetailsDto.getGroupTotalPayAmount()不能为空！");
                            BigDecimal groupTotalPayAmount = passiveStorageSonDetailsDto2.getGroupTotalPayAmount().setScale(2, BigDecimal.ROUND_HALF_UP);
                            if ("0".equals(groupTotalPayAmount.stripTrailingZeros().toPlainString())) {
                                continue;
                            }

//                            String tax = null;//税率
//                            BigDecimal noriginalcurmny = null;//无税金额
//                            BigDecimal noriginalcurtaxmny = null;//税额
//                            try {
//                                tax = new BigDecimal(bdTaxitemsEntity1.getTaxratio()).divide(new BigDecimal(100), 20, BigDecimal.ROUND_HALF_UP).setScale(2, BigDecimal.ROUND_HALF_UP).stripTrailingZeros().toPlainString();
//                                noriginalcurmny = groupTotalPayAmount.divide(new BigDecimal(1).add(new BigDecimal(tax)), 20, BigDecimal.ROUND_HALF_UP).setScale(2, BigDecimal.ROUND_HALF_UP);
//                                noriginalcurtaxmny = groupTotalPayAmount.subtract(noriginalcurmny).setScale(2, BigDecimal.ROUND_HALF_UP);
//                            } catch (Exception e) {
//                                logger.error("金额计算失败", e);
//                                Assert.state(false, "金额计算失败 跑出异常：{}", e.getMessage());
//                            }

                            //组装应收单表体
                            List<ArapDjzbVO.Childrenn> pushScenarioType = new ArrayList<>();
                            ArapDjzbVO.Childrenn arapDjzbVOChildrenn = new ArapDjzbVO.Childrenn();
                            pushScenarioType.add(arapDjzbVOChildrenn);
                            arapDjzbVOChildrenn.setCinventoryid(bdInvbasdocEntity.getInvcode());//存货管理档案
                            arapDjzbVOChildrenn.setJfbbje("-" + groupTotalPayAmount.stripTrailingZeros().toPlainString());//借方本币金额
                            arapDjzbVOChildrenn.setJfybje("-" + groupTotalPayAmount.stripTrailingZeros().toPlainString());//借方原币金额
//                            arapDjzbVOChildrenn.setJfbbsj("-" + noriginalcurmny.stripTrailingZeros().toPlainString());//借方本币税金
//                            arapDjzbVOChildrenn.setJfybsj("-" + noriginalcurmny.stripTrailingZeros().toPlainString());//借方原币税金
//                            arapDjzbVOChildrenn.setWbfbbje("-" + noriginalcurtaxmny.stripTrailingZeros().toPlainString());//借方本币无税金额
//                            arapDjzbVOChildrenn.setJfybwsje("-" + noriginalcurtaxmny.stripTrailingZeros().toPlainString());//借方原币无税金额

                            //退货没有邮费金额，已经向万万确认
                            //平台优惠
                            if (passiveStorageSonDetailsDto2.getVdef4() != null) {
                                BigDecimal vdef4 = passiveStorageSonDetailsDto2.getVdef4();
                                if (vdef4.compareTo(BigDecimal.ZERO) > 0) {
                                    //发货运费-存货基本档案
                                    BdInvbasdocEntity bdInvbasdocEntity1 = mapBdInvbasdocEntity.get("FY01");
                                    //存货管理档案
                                    BdInvmandocEntity bdInvmandocEntity1 = stringBdInvmandocEntityMap.get(bdInvbasdocEntity1.getInvcode() + deliverGoodsCorp.getPkCorp());
                                    //存货对应的税率
                                    BdTaxitemsEntity bdTaxitemsEntity = stringBdTaxitemsEntityMap.get("FY01");
                                    //补充：平台优惠-存货
                                    BigDecimal absAccumulatedPostage = vdef4.abs();
                                    BigDecimal negativeValue = absAccumulatedPostage.negate();
                                    queryAdditionUtil.additionalV2(pushScenarioType, bdInvmandocEntity1, bdInvbasdocEntity1, negativeValue, bdTaxitemsEntity);
                                }
                            }
                            //达人优惠
                            if (passiveStorageSonDetailsDto2.getVdef6() != null) {
                                BigDecimal vdef6 = passiveStorageSonDetailsDto2.getVdef6();
                                if (vdef6.compareTo(BigDecimal.ZERO) > 0) {
                                    //发货运费-存货基本档案
                                    BdInvbasdocEntity bdInvbasdocEntity1 = mapBdInvbasdocEntity.get("FY02");
                                    //存货管理档案
                                    BdInvmandocEntity bdInvmandocEntity1 = stringBdInvmandocEntityMap.get(bdInvbasdocEntity1.getInvcode() + deliverGoodsCorp.getPkCorp());
                                    //存货对应的税率
                                    BdTaxitemsEntity bdTaxitemsEntity = stringBdTaxitemsEntityMap.get("FY02");
                                    //补充：达人优惠-存货
                                    BigDecimal absAccumulatedPostage = vdef6.abs();
                                    BigDecimal negativeValue = absAccumulatedPostage.negate();
                                    queryAdditionUtil.additionalV2(pushScenarioType, bdInvmandocEntity1, bdInvbasdocEntity1, negativeValue, bdTaxitemsEntity);
                                }
                            }
                            //支付优惠
                            if (passiveStorageSonDetailsDto2.getVdef5() != null) {
                                BigDecimal vdef5 = passiveStorageSonDetailsDto2.getVdef5();
                                if (vdef5.compareTo(BigDecimal.ZERO) > 0) {
                                    //发货运费-存货基本档案
                                    BdInvbasdocEntity bdInvbasdocEntity1 = mapBdInvbasdocEntity.get("FY04");
                                    //存货管理档案
                                    BdInvmandocEntity bdInvmandocEntity1 = stringBdInvmandocEntityMap.get(bdInvbasdocEntity1.getInvcode() + deliverGoodsCorp.getPkCorp());
                                    //存货对应的税率
                                    BdTaxitemsEntity bdTaxitemsEntity = stringBdTaxitemsEntityMap.get("FY04");
                                    //补充：支付优惠-存货
                                    BigDecimal absAccumulatedPostage = vdef5.abs();
                                    BigDecimal negativeValue = absAccumulatedPostage.negate();
                                    queryAdditionUtil.additionalV2(pushScenarioType, bdInvmandocEntity1, bdInvbasdocEntity1, negativeValue, bdTaxitemsEntity);
                                }
                            }

                            //推送U8C
                            List<ArapDjzbVO> arapDjzbVOList = new ArrayList<>();
                            ArapDjzbVO arapDjzbVO = new ArapDjzbVO();
                            arapDjzbVO.setParentvo(parentVo);
                            arapDjzbVO.setChildren(pushScenarioType);
                            arapDjzbVOList.add(arapDjzbVO);

                            Map<String, List<ArapDjzbVO>> listMap = new HashMap<>();
                            listMap.put("djzbvo", arapDjzbVOList);
                            ArapDjzb arapDjzb = sendU8cRedReceivable(JSON.toJSONString(listMap));
                            String djbh = null;
                            String dwbm = null;
                            String vouchid = null;
                            if (arapDjzb != null && arapDjzb.getParentvo() != null) {
                                djbh = arapDjzb.getParentvo().getDjbh();
                                dwbm = arapDjzb.getParentvo().getDwbm();
                                vouchid = arapDjzb.getParentvo().getVouchid();
                            }
                            logger.info("TOC红字应收单：{} 应收单主键：{} 销售公司：{}", djbh, vouchid, dwbm);
                            updateSuccessOrFail3(value, "Y", "success", djbh, vouchid);
                        } catch (Exception e) {
                            logger.error("TOC红字应收单转换成U8C对象过程中、或者单据推送到U8C出现异常！", e);
                            //记录失败
                            String message = e.getMessage();
                            if (message == null) {
                                message = "未知错误";
                            }
                            updateSuccessOrFail3(value, "N", message, null, null);
                        }
                    }
                } else {
                    //2024年8月6日 11:28:54此处不记录失败，不认为是错误
                    logger.info("summaryDimensionMap变量或者bdBusitypeEntity变量为空，因此主要的推送逻辑不会被执行！");
                }
            } catch (Exception e) {
                logger.error("外层转换逻辑抛出异常", e);
            }
        }
    }

    /**
     * 2025 年 3 月 12 日 15:53:27
     * 生成业务日期：取「关联时间」,只能取关联时间，否则会存在跨月问题
     *
     * @author liuyang
     */
    private String createGenerateBusinessDate(PassiveStorageResponse.Header header) {
        String code = null;
        if (header != null && header.getReceiptCode() != null) {
            code = header.getReceiptCode();
        }
        if (header != null && header.getRelatedAt() != null) {
            String closedAt = header.getRelatedAt();
            String businessFormat = null;
            try {
                Date dbill = DateUtil.parse(closedAt);
                businessFormat = DateUtil.format(dbill, "yyyy-MM-dd");
            } catch (Exception e) {
                logger.error("业务日期生成失败relatedAt(O 关联时间)解析异常：{} O 无源入库单号：{}", e.getMessage(), code);
                Assert.state(false, "业务日期生成失败closedAt(O 关联时间)解析异常：{} O 无源入库单号：{}", e.getMessage(), code);
            }
            return businessFormat;
        } else {
            logger.error("业务日期生成失败relatedAt(O 关联时间)不能为空 O 无源入库单号:{}", code);
            Assert.state(false, "业务日期生成失败relatedAt(O 关联时间)不能为空 O 无源入库单号:{}", code);
            return null;
        }
    }

    /**
     * 2025 年 3 月 13 日 11:09:20
     * 无源件退款完成部分，取关联时间、作为 U8C 的退款时间、已经和万万、还有财务确认过这块逻辑
     *
     * @author liuyang
     */
    private String createSuccessFulTradeDate(PassiveStorageResponse.Header stockinH) {
        String code = null;
        if (stockinH != null && stockinH.getReceiptCode() != null) {
            code = stockinH.getReceiptCode();
        }
        if (stockinH != null && stockinH.getRelatedAt() != null) {
            String relatedAt = stockinH.getRelatedAt();
            HeaderDetailsDto headerDetailsDto = stockinH.getHeaderDetailsDto();
            HeaderDto header = headerDetailsDto.getHeader();

            String businessFormat = null;
            try {
                Date relatedAtDate = DateUtil.parse(relatedAt);
                Date tradeSuccessAtDate = DateUtil.parse(header.getTradeSuccessAt());
                Date effectiveDate = relatedAtDate.compareTo(tradeSuccessAtDate) > 0 ? relatedAtDate : tradeSuccessAtDate;

                businessFormat = DateUtil.format(effectiveDate, "yyyy-MM-dd");
            } catch (Exception e) {
                logger.error("生成退款业务日期失败(O关联时间)解析异常：{} 无源入库单编码：{}", e.getMessage(), code);
                Assert.state(false, "生成退款业务日期失败(O关联时间)解析异常：{} 无源入库单编码：{}", e.getMessage(), code);
            }
            return businessFormat;
        } else {
            logger.error("生成退款业务日期失败O关联时间不能为空! 无源件单据编码：{}", code);
            Assert.state(false, "生成退款业务日期失败O关联时间不能为空! 无源件单据编码：{}", code);
            return null;
        }
    }

    /**
     * 先退款后退货场景时间判断
     */
//    public String timeJudgment(StockinOrderSearchResponse.StockinOrder.StockinH stockinH) throws Exception {
//        Assert.notNull(stockinH, "stockinH不能为空!");
//        Assert.notNull(stockinH.getRefundedAt(), "退款完成时间不能为空 O售后入库单号：{}", stockinH.getCode());
//        Assert.notNull(stockinH.getClosedAt(), "入库完成时间(关单时间)不能为空 O售后入库单号：{}", stockinH.getCode());
//        //退款完成时间
//        SimpleDateFormat sdf = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss");
//        Date refundedAtDate = sdf.parse(stockinH.getRefundedAt());
//
//        //入库完成时间
//        SimpleDateFormat sdf2 = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss");
//        Date closedAtDate = sdf2.parse(stockinH.getClosedAt());
//
//        if (refundedAtDate.before(closedAtDate)) {
//            logger.info("O售后入库单：{} 入库时间：{} 退款完成时间：{} 「先退款」后退货", stockinH.getCode(), stockinH.getClosedAt(), stockinH.getRefundedAt());
//            return stockinH.getClosedAt();
//        } else {
//            logger.info("O售后入库单：{} 入库时间：{} 退款完成时间：{} 「先退货」后退款", stockinH.getCode(), stockinH.getClosedAt(), stockinH.getRefundedAt());
//            return stockinH.getRefundedAt();
//        }
//    }

    /**
     * 档案转换(OFS->U8C)
     *
     * @param passiveStorageResponseDataList OFS无源入库单
     * @param sceneType                      推送场景
     * @author liuyang
     */
    private List<PassiveStorageSonDetailsDto> queryBasicArchivesStock(List<PassiveStorageResponse.Data> passiveStorageResponseDataList, String sceneType) {
        Assert.notNull(passiveStorageResponseDataList, "passiveStorageResponseDataList不能为空");
        Assert.notNull(sceneType, "sceneType不能为空");

        List<PassiveStorageSonDetailsDto> sonDetailsDtoList = new ArrayList<>();
        List<ErrorHeaderDetailsDtoDtoV3> errorHeaderDetailsDtoDtoList = new ArrayList<>();

        if (passiveStorageResponseDataList != null && passiveStorageResponseDataList.size() > 0) {
            try {
                //查询OFS无源入库单对应的售后订单，并关联无源无源入库单对象
                List<RerturnGoodsOrderSearchData> rerturnGoodsOrderSearchData = queryBatchAfterSalesOrder(passiveStorageResponseDataList);
                findAfterSalesOrder(rerturnGoodsOrderSearchData, passiveStorageResponseDataList);
                if ("tran".equals(sceneType)) {
                    passiveStorageResponseDataList = filterAfterSalesOrder(passiveStorageResponseDataList);
                    passiveStorageResponseDataList = filterForSale(passiveStorageResponseDataList);
                }

                //查询OFS售后订单对应的OFS销售订单
                List<com.hzya.frame.ttxofs.dto.ofssalesordersearch.HeaderDetailsDto> headerDetailsDtos = queryBatchOfsOrder(passiveStorageResponseDataList);
                findOfsOrder(headerDetailsDtos, passiveStorageResponseDataList);

                //初始化档案缓存
                CacheTocMapVoV2 cacheTocMapVoV2 = passiveComponentsArchivesCacheUtil.initCache(passiveStorageResponseDataList);

                //初始化公司档案对照关系
//                Map<String, String> comparisonCompanyArchives = queryU8CEntityUtil.queryBdDefDocByPkDefDocAll();

                for (int i = 0; i < passiveStorageResponseDataList.size(); i++) {
                    PassiveStorageResponse.Data data = passiveStorageResponseDataList.get(i);
                    PassiveStorageResponse.Header header = data.getHeader();
                    List<PassiveStorageResponse.Details> details = data.getDetails();

//                    String transactionDate = null;
                    try {
                        //OFS售后订单
                        RerturnGoodsOrderSearchData rerturnGoodsOrderSearchData1 = header.getRerturnGoodsOrderSearchData();
                        Assert.notNull(rerturnGoodsOrderSearchData1, "无法关联到OFS售后订单 售后无源入库单：{}", header.getReceiptCode().trim());
                        RerturnGoodsOrderSearchHeader header2 = rerturnGoodsOrderSearchData1.getHeader();
                        List<RerturnGoodsOrderSearchDetails> details2 = rerturnGoodsOrderSearchData1.getDetails();

                        //测试3个要传给u8c的优惠金额
//                        details2.get(0).setPlatformDiscounts("1.12");
//                        details2.get(0).setExpertDiscounts("0.543");
//                        details2.get(0).setMerchantDiscounts("4.54");
                        //用于抛出异常时，记录交易成功时间
//                        transactionDate = header2.getRefundedAt();

                        //OFS销售订单
                        com.hzya.frame.ttxofs.dto.ofssalesordersearch.HeaderDetailsDto headerDetailsDto = header.getHeaderDetailsDto();
                        Assert.notNull(headerDetailsDto, "无法关联到OFS销售订单 售后无源入库单：{}", header.getReceiptCode().trim());
                        com.hzya.frame.ttxofs.dto.ofssalesordersearch.HeaderDto header1 = headerDetailsDto.getHeader();
                        List<DetailsDto> details1 = headerDetailsDto.getDetails();

                        //如果不存在，则默认收发类别
                        if (header1.getSubOrderType() == null || "".equals(header1.getSubOrderType())) {
                            header1.setSubOrderType("SALES");
                        }
                        BdRdclEntity bdRdclEntity = cacheTocMapVoV2.getStringBdRdclEntityMap().get(header1.getSubOrderType().trim());
                        Assert.notNull(bdRdclEntity, "根据业务类型({})没有匹配到U8C业务类型", header1.getSubOrderType().trim());

                        String companyCode = header.getCompanyCode();
                        Assert.notNull(companyCode, "O货主编码不能为空");
                        //查找是否替换公司
//                        String targetCorp = comparisonCompanyArchives.get(companyCode);
//                        if (targetCorp != null) {
//                            companyCode = targetCorp;
//                        }
                        BdCorpEntity bdCorpEntity = cacheTocMapVoV2.getStringBdCorpEntityMap().get(companyCode.trim());
                        Assert.notNull(bdCorpEntity, "根据O公司编码(货主编码)({})没有匹配到U8C公司档案", header.getCompanyCode());

                        //发货库存组织
                        BdCalbodyEntity bdCalbodyEntity = cacheTocMapVoV2.getStringBdCalbodyEntityMap().get(bdCorpEntity.getPkCorp());
                        Assert.notNull(bdCalbodyEntity, "根据公司主键没有查询到发货库存组织 公司主键：{}", bdCorpEntity.getPkCorp());

                        //发货公司，暂时把O表头公司作为发货公司，正常情况下需要把O库存地点对于的公司作为发货公司

                        //发货仓库
                        //2024年8月5日 15:06:38 仓库O与U两边仓库编码是一致的，和妮姐确认过了
                        String facilityCode = header.getFacilityCode();
                        Assert.notNull(facilityCode, "O仓库编码不能为空");
                        BdStordocEntity bdStordocEntity = cacheTocMapVoV2.getStringBdStordocEntityMap().get(facilityCode.trim() + bdCalbodyEntity.getPkCalbody());
                        Assert.notNull(bdStordocEntity, "没有匹配到发货仓库 O库存地点编码：{} 发货库存组织主键：{} ", facilityCode, bdCalbodyEntity.getPkCalbody());

                        //2024年8月5日 15:25:07 收货库存组织、收货仓库、默认和发货库存组织、发货仓库一致，已经和佳妮确认
                        //收货库存组织：速网来看收货库存组织对应表头工具
                        //收货仓库：通过收货库存组织+仓库编码，确定收货仓库

                        //销售组织2024年8月5日 15:33:40 和妮姐确认，销售组织和表头公司，作为一对一的关系，
                        BdSalestruEntity bdSalestruEntity = cacheTocMapVoV2.getStringBdSalestruEntityMap().get(bdCorpEntity.getUnitname());
                        Assert.notNull(bdSalestruEntity, "无匹配到销售组织 表头公司名称：{}", bdCorpEntity.getUnitname());

                        //业务部门：暂定的部门名称：其他，2024年8月5日 15:39:42 已经和妮姐确认
                        BdDeptdocEntity bdDeptdocEntity = null;
                        if (header1.getDepartmentType() == null || "".equals(header1.getDepartmentType().trim())) {
                            //默认业务部门
                            logger.info("OFS销售订单号：{} 不存在部门字段！", header1.getCode());
                            bdDeptdocEntity = cacheTocMapVoV2.getStringBdDeptdocEntityMap().get(bdCorpEntity.getPkCorp());
                            Assert.notNull(bdDeptdocEntity, "无法匹配到业务部门 部门名称：其他 对应公司名称：{}", bdCorpEntity.getPkCorp());
                        } else {
                            logger.info("OFS销售订单号：{} 存在部门字段：{}！", header1.getCode(), header1.getDepartmentType());
                            String deptCode = header1.getDepartmentType().trim();
                            bdDeptdocEntity = cacheTocMapVoV2.getStringBdDeptdocEntityMapByDeptCode().get(deptCode);
                        }

                        //客商基本档案
                        //2024年8月8日 12:05:10 O店铺的业务编码=U8C客商自定义项1，O没有店铺信息查询接口，因此无法通过出库单的店铺编码，查询到O店铺档案对应的业务编码，接口上线之后需要补充这一部分逻辑
//                    String custName = "天猫intoyou旗舰店-自营";
                        String storeCode = header.getStoreCode();
                        Assert.notNull(storeCode, "O店铺编码不能为空，没有办法完成业务逻辑！");
                        Assert.state(!"".equals(storeCode.trim()), "O店铺编码不能为空，没有办法完成业务逻辑！");
                        BdCubasdocEntity bdCubasdocEntity = cacheTocMapVoV2.getStringBdCubasdocEntityMap().get(storeCode.trim());
                        Assert.notNull(bdCubasdocEntity, "无法匹配到客户档案 客商名称：{}", storeCode);

                        //客商管理档案：2024年8月5日 15:41:54 TOC店铺名称查询U8C客商档案，已经和妮姐确认
                        //2024年8月5日 15:49:49 先根据O店铺编码，得到店铺档案信息，取到名称，通过U8C接口查询出来
                        //目前O店铺信息查询接口还没有，等待开发，所以我这里先写所一个名字
                        BdCumandocEntity bdCumandocEntity = cacheTocMapVoV2.getStringBdCumandocEntityMap().get(bdCubasdocEntity.getPkCubasdoc() + bdCorpEntity.getPkCorp());
                        Assert.notNull(bdCumandocEntity, "无法匹配到客商档案 店铺名称：{}", "天猫intoyou旗舰店-自营");

                        //查找平台
                        String sourcePlatformCode = header2.getSourcePlatformCode();
                        Assert.notNull(sourcePlatformCode, "O平台编码不能为空！");
                        BdDefdocEntity bdDefdocEntity = cacheTocMapVoV2.getStringBdDefdocEntityMap().get(sourcePlatformCode.trim());
                        Assert.notNull(bdDefdocEntity, "根据O平台编码({})无法匹配到U8C平台档案", header2.getSourcePlatformCode());

                        //查找店铺
//                    String storeCode2 = header.getStoreCode();
//                    Assert.notNull(storeCode2, "O店铺编码不能为空！");
                        BdDefdocEntity bdDefdocEntity1 = cacheTocMapVoV2.getStringBdDefdocEntityMap1().get(storeCode.trim());
                        Assert.notNull(bdDefdocEntity1, "根据O店铺编码({})无法匹配到U8C店铺档案", storeCode.trim());

                        //字段拷贝
                        for (int j = 0; j < details.size(); j++) {
                            PassiveStorageResponse.Details details3 = details.get(j);

                            //存货管理档案，是发货公司的存货档案
                            Assert.notNull(details3.getSkuCode(), "skucode不能为空");
                            BdInvmandocEntity bdInvmandocEntity = cacheTocMapVoV2.getStringBdInvmandocEntityMap().get(details3.getSkuCode().trim() + bdCorpEntity.getPkCorp());
                            Assert.notNull(bdInvmandocEntity, "无法匹配到存货管理档案 货品sku：{} 公司：{}", details3.getSkuCode().trim(), bdCorpEntity.getPkCorp());
                            //存货基本档案
                            BdInvbasdocEntity bdInvbasdocEntity = cacheTocMapVoV2.getStringBdInvbasdocEntityMap().get(details3.getSkuCode().trim());
                            Assert.notNull(bdInvbasdocEntity, "无法匹配到存货基本档案 存货编码：{}", details3.getSkuCode().trim());
                            //存货税率
                            BdTaxitemsEntity bdTaxitemsEntity = cacheTocMapVoV2.getStringBdTaxitemsEntityMap().get(bdInvmandocEntity.getInvcode());
                            Assert.notNull(bdTaxitemsEntity, "无法匹配到存货税率 存货编码：{}", bdInvmandocEntity.getInvcode());

                            //2024年8月6日 10:16:22 通过O出库单的表头，查询得出U8C档案，放在表体的原因是方便分组汇总
                            //下一个步骤的分组汇总，是通过表体明细完成的
                            PassiveStorageSonDetailsDto goodsRertunSonDetailsDto = new PassiveStorageSonDetailsDto();
                            goodsRertunSonDetailsDto.setHeader(header);
                            goodsRertunSonDetailsDto.setBdCorpEntity(bdCorpEntity);
                            goodsRertunSonDetailsDto.setDeliverGoodsCorp(bdCorpEntity);
                            goodsRertunSonDetailsDto.setBdCalbodyEntity(bdCalbodyEntity);
                            goodsRertunSonDetailsDto.setBdStordocEntity(bdStordocEntity);
                            goodsRertunSonDetailsDto.setBdCalbodyEntity1(bdCalbodyEntity);
                            goodsRertunSonDetailsDto.setBdStordocEntity1(bdStordocEntity);
                            goodsRertunSonDetailsDto.setBdSalestruEntity(bdSalestruEntity);
                            goodsRertunSonDetailsDto.setBdDeptdocEntity(bdDeptdocEntity);
                            goodsRertunSonDetailsDto.setBdCumandocEntity(bdCumandocEntity);
                            goodsRertunSonDetailsDto.setBdCubasdocEntity(bdCubasdocEntity);
                            goodsRertunSonDetailsDto.setPlatformArchives(bdDefdocEntity);
                            goodsRertunSonDetailsDto.setBdRdclEntity(bdRdclEntity);
                            goodsRertunSonDetailsDto.setShopArchives(bdDefdocEntity1);
                            goodsRertunSonDetailsDto.setBdInvmandocEntity(bdInvmandocEntity);
                            goodsRertunSonDetailsDto.setBdInvbasdocEntity(bdInvbasdocEntity);
                            goodsRertunSonDetailsDto.setBdTaxitemsEntity(bdTaxitemsEntity);

                            BeanUtil.copyPropertiesV2(details3, goodsRertunSonDetailsDto);
                            sonDetailsDtoList.add(goodsRertunSonDetailsDto);
                            //成功收集进入到集合
                        }
                    } catch (Exception e) {
                        //失败部分处理
                        logger.error("档案转换抛出异常", e);
                        String message = e.getMessage();
                        if (message == null) {
                            message = "未知错误";
                        }
                        ErrorHeaderDetailsDtoDtoV3 errorHeaderDetailsDtoDto = new ErrorHeaderDetailsDtoDtoV3();
                        errorHeaderDetailsDtoDto.setNewPushDate(getNewDateStr());
                        errorHeaderDetailsDtoDto.setNewTransmitInfo(message);
                        errorHeaderDetailsDtoDto.setNewstate("N");
                        errorHeaderDetailsDtoDto.setHeader(header);
                        errorHeaderDetailsDtoDto.setDetails(details);
//                        errorHeaderDetailsDtoDto.setTransactionDate(transactionDate);
                        errorHeaderDetailsDtoDtoList.add(errorHeaderDetailsDtoDto);
                    }
                }
            } catch (Exception e) {
                logger.error("OFS无源入库单关联查询U8C档案失败", e);
            }
        } else {
            logger.info("queryBasicArchives方法passiveStorageResponseDataList.size为0");
        }
        //错误日志同步到数据
        if (errorHeaderDetailsDtoDtoList.size() > 0) {
            updateFailOrSuccessTocofsSaleoutDetailedArchiveInquiry(errorHeaderDetailsDtoDtoList, sceneType);
        }
        return sonDetailsDtoList;
    }


    /**
     * 档案转换(OFS->U8C)
     *
     * @param passiveStorageResponseDataList OFS无源入库单
     * @author liuyang
     */
    private List<PassiveStorageSonDetailsDto2> queryBasicArchivesTran(List<PassiveStorageResponse.Data> passiveStorageResponseDataList) {
        Assert.notNull(passiveStorageResponseDataList, "passiveStorageResponseDataList不能为空");

        List<PassiveStorageSonDetailsDto2> sonDetailsDtoList = new ArrayList<>();
        List<ErrorHeaderDetailsDtoDtoV4> errorHeaderDetailsDtoDtoList = new ArrayList<>();

        if (passiveStorageResponseDataList != null && passiveStorageResponseDataList.size() > 0) {
            try {
                //查询OFS无源入库单对应的售后订单，并关联无源无源入库单对象
                List<RerturnGoodsOrderSearchData> rerturnGoodsOrderSearchData = queryBatchAfterSalesOrder(passiveStorageResponseDataList);
                findAfterSalesOrder(rerturnGoodsOrderSearchData, passiveStorageResponseDataList);
                //过滤掉没有退款时间的无源件明细行
                passiveStorageResponseDataList = filterAfterSalesOrder(passiveStorageResponseDataList);
                //查询OFS售后订单对应的OFS销售订单
                List<com.hzya.frame.ttxofs.dto.ofssalesordersearch.HeaderDetailsDto> headerDetailsDtos = queryBatchOfsOrder(passiveStorageResponseDataList);
                findOfsOrder(headerDetailsDtos, passiveStorageResponseDataList);
                //过滤售中节点
                passiveStorageResponseDataList = filterForSale(passiveStorageResponseDataList);

//                RerturnGoodsOrderSearchData rerturnGoodsOrderSearchData3 = rerturnGoodsOrderSearchData.get(0);
//                List<RerturnGoodsOrderSearchDetails> details1 = rerturnGoodsOrderSearchData3.getDetails();
//                for (int i = 0; i < details1.size(); i++) {
//                    RerturnGoodsOrderSearchDetails rerturnGoodsOrderSearchDetails = details1.get(i);
//                    if (i == 0) {
//                        rerturnGoodsOrderSearchDetails.setPlatformDiscounts("1.22");
//                        rerturnGoodsOrderSearchDetails.setMerchantDiscounts("0.55");
//                        rerturnGoodsOrderSearchDetails.setExpertDiscounts("0.23");
//                        rerturnGoodsOrderSearchDetails.setPayDiscounts("0.44");
//                    } else {
//                        rerturnGoodsOrderSearchDetails.setPlatformDiscounts("2.22");
//                        rerturnGoodsOrderSearchDetails.setMerchantDiscounts("0.33");
//                        rerturnGoodsOrderSearchDetails.setExpertDiscounts("0.99");
//                        rerturnGoodsOrderSearchDetails.setPayDiscounts("1.44");
//                    }
//                }


                //从已经完成各类过滤的无源入库单中提取售后订单
                List<RerturnGoodsOrderSearchData> rerturnGoodsOrderSearchDataList = new ArrayList<>();
                for (PassiveStorageResponse.Data index : passiveStorageResponseDataList) {
                    PassiveStorageResponse.Header header = index.getHeader();
                    RerturnGoodsOrderSearchData rerturnGoodsOrderSearchData1 = header.getRerturnGoodsOrderSearchData();
                    rerturnGoodsOrderSearchDataList.add(rerturnGoodsOrderSearchData1);
                }

                //把售后订单保存到底表
                //把无源入库单对应的销售订单提取出来，和售后订单比较时间早与晚
                //key O销售订单编码、O销售订单对象
                Map<String, HeaderDetailsDto> stringHeaderDetailsDtoMap = new HashMap<>();
                for (PassiveStorageResponse.Data index : passiveStorageResponseDataList) {
                    PassiveStorageResponse.Header header = index.getHeader();
                    //售后订单
//                    RerturnGoodsOrderSearchData rerturnGoodsOrderSearchData1 = header.getRerturnGoodsOrderSearchData();
                    //销售订单
                    HeaderDetailsDto headerDetailsDto = header.getHeaderDetailsDto();
                    if (headerDetailsDto != null) {
                        HeaderDto header1 = headerDetailsDto.getHeader();
                        stringHeaderDetailsDtoMap.put(header1.getCode(), headerDetailsDto);
                    }
                }
                batchInsertTran(rerturnGoodsOrderSearchDataList, passiveStorageResponseDataList, stringHeaderDetailsDtoMap);

                //过滤已经推送成功的售后订单
                List<RerturnGoodsOrderSearchData> rerturnGoodsOrderSearchDataList1 = filterSuccessAfterSalesOrder(rerturnGoodsOrderSearchDataList);

                //初始化档案缓存
                CacheTocMapVoV2 cacheTocMapVoV2 = passiveComponentsArchivesCacheUtilV2.initCache(rerturnGoodsOrderSearchDataList1);

                //初始化公司档案对照关系
//                Map<String, String> comparisonCompanyArchives = queryU8CEntityUtil.queryBdDefDocByPkDefDocAll();

                for (int i = 0; i < rerturnGoodsOrderSearchDataList1.size(); i++) {
                    RerturnGoodsOrderSearchData rerturnGoodsOrderSearchData2 = rerturnGoodsOrderSearchDataList1.get(i);
                    RerturnGoodsOrderSearchHeader header = rerturnGoodsOrderSearchData2.getHeader();
                    List<RerturnGoodsOrderSearchDetails> details = rerturnGoodsOrderSearchData2.getDetails();

//                    String transactionDate = null;
                    try {
                        //OFS售后订单
//                        RerturnGoodsOrderSearchData rerturnGoodsOrderSearchData1 = header.getRerturnGoodsOrderSearchData();
//                        Assert.notNull(rerturnGoodsOrderSearchData1, "无法关联到OFS售后订单 售后无源入库单：{}", header.getReceiptCode().trim());
//                        RerturnGoodsOrderSearchHeader header2 = rerturnGoodsOrderSearchData1.getHeader();
//                        List<RerturnGoodsOrderSearchDetails> details2 = rerturnGoodsOrderSearchData1.getDetails();

                        //测试3个要传给u8c的优惠金额
//                        details2.get(0).setPlatformDiscounts("1.12");
//                        details2.get(0).setExpertDiscounts("0.543");
//                        details2.get(0).setMerchantDiscounts("4.54");
                        //用于抛出异常时，记录交易成功时间
//                        transactionDate = header2.getRefundedAt();

                        //OFS销售订单
//                        com.hzya.frame.ttxofs.dto.ofssalesordersearch.HeaderDetailsDto headerDetailsDto = header.getHeaderDetailsDto();
//                        Assert.notNull(headerDetailsDto, "无法关联到OFS销售订单 售后无源入库单：{}", header.getReceiptCode().trim());
//                        com.hzya.frame.ttxofs.dto.ofssalesordersearch.HeaderDto header1 = headerDetailsDto.getHeader();
//                        List<DetailsDto> details1 = headerDetailsDto.getDetails();
                        //O售后订单对应的O销售订单
                        HeaderDetailsDto headerDetailsDto = stringHeaderDetailsDtoMap.get(header.getRefOrderCode());
                        HeaderDto header1 = headerDetailsDto.getHeader();

                        //如果不存在，则默认收发类别
                        if (header1.getSubOrderType() == null || "".equals(header1.getSubOrderType())) {
                            header1.setSubOrderType("SALES");
                        }
                        BdRdclEntity bdRdclEntity = cacheTocMapVoV2.getStringBdRdclEntityMap().get(header1.getSubOrderType().trim());
                        Assert.notNull(bdRdclEntity, "根据业务类型({})没有匹配到U8C业务类型", header1.getSubOrderType().trim());

                        String companyCode = header.getCompanyCode();
                        Assert.notNull(companyCode, "O货主编码不能为空");
                        //查找是否替换公司
//                        String targetCorp = comparisonCompanyArchives.get(companyCode);
//                        if (targetCorp != null) {
//                            companyCode = targetCorp;
//                        }
                        BdCorpEntity bdCorpEntity = cacheTocMapVoV2.getStringBdCorpEntityMap().get(companyCode.trim());
                        Assert.notNull(bdCorpEntity, "根据O公司编码(货主编码)({})没有匹配到U8C公司档案", header.getCompanyCode());

                        //发货库存组织
                        BdCalbodyEntity bdCalbodyEntity = cacheTocMapVoV2.getStringBdCalbodyEntityMap().get(bdCorpEntity.getPkCorp());
                        Assert.notNull(bdCalbodyEntity, "根据公司主键没有查询到发货库存组织 公司主键：{}", bdCorpEntity.getPkCorp());

                        //发货公司，暂时把O表头公司作为发货公司，正常情况下需要把O库存地点对于的公司作为发货公司

                        //发货仓库
                        //2024年8月5日 15:06:38 仓库O与U两边仓库编码是一致的，和妮姐确认过了
//                        String facilityCode = header.getFacilityCode();
//                        Assert.notNull(facilityCode, "O仓库编码不能为空");
//                        BdStordocEntity bdStordocEntity = cacheTocMapVoV2.getStringBdStordocEntityMap().get(facilityCode.trim() + bdCalbodyEntity.getPkCalbody());
//                        Assert.notNull(bdStordocEntity, "没有匹配到发货仓库 O库存地点编码：{} 发货库存组织主键：{} ", facilityCode, bdCalbodyEntity.getPkCalbody());

                        //2024年8月5日 15:25:07 收货库存组织、收货仓库、默认和发货库存组织、发货仓库一致，已经和佳妮确认
                        //收货库存组织：速网来看收货库存组织对应表头工具
                        //收货仓库：通过收货库存组织+仓库编码，确定收货仓库

                        //销售组织2024年8月5日 15:33:40 和妮姐确认，销售组织和表头公司，作为一对一的关系
                        BdSalestruEntity bdSalestruEntity = cacheTocMapVoV2.getStringBdSalestruEntityMap().get(bdCorpEntity.getUnitname());
                        Assert.notNull(bdSalestruEntity, "无匹配到销售组织 表头公司名称：{}", bdCorpEntity.getUnitname());

                        //业务部门：暂定的部门名称：其他，2024年8月5日 15:39:42 已经和妮姐确认
                        BdDeptdocEntity bdDeptdocEntity = null;
                        if (header1.getDepartmentType() == null || "".equals(header1.getDepartmentType().trim())) {
                            //默认业务部门
                            logger.info("OFS销售订单号：{} 不存在部门字段！", header1.getCode());
                            bdDeptdocEntity = cacheTocMapVoV2.getStringBdDeptdocEntityMap().get(bdCorpEntity.getPkCorp());
                            Assert.notNull(bdDeptdocEntity, "无法匹配到业务部门 部门名称：其他 对应公司名称：{}", bdCorpEntity.getPkCorp());
                        } else {
                            logger.info("OFS销售订单号：{} 存在部门字段：{}！", header1.getCode(), header1.getDepartmentType());
                            String deptCode = header1.getDepartmentType().trim();
                            bdDeptdocEntity = cacheTocMapVoV2.getStringBdDeptdocEntityMapByDeptCode().get(deptCode);
                        }

                        //客商基本档案
                        //2024年8月8日 12:05:10 O店铺的业务编码=U8C客商自定义项1，O没有店铺信息查询接口，因此无法通过出库单的店铺编码，查询到O店铺档案对应的业务编码，接口上线之后需要补充这一部分逻辑
//                    String custName = "天猫intoyou旗舰店-自营";
                        String storeCode = header.getStoreCode();
                        Assert.notNull(storeCode, "O店铺编码不能为空，没有办法完成业务逻辑！");
                        Assert.state(!"".equals(storeCode.trim()), "O店铺编码不能为空，没有办法完成业务逻辑！");
                        BdCubasdocEntity bdCubasdocEntity = cacheTocMapVoV2.getStringBdCubasdocEntityMap().get(storeCode.trim());
                        Assert.notNull(bdCubasdocEntity, "无法匹配到客户档案 客商名称：{}", storeCode);

                        //客商管理档案：2024年8月5日 15:41:54 TOC店铺名称查询U8C客商档案，已经和妮姐确认
                        //2024年8月5日 15:49:49 先根据O店铺编码，得到店铺档案信息，取到名称，通过U8C接口查询出来
                        //目前O店铺信息查询接口还没有，等待开发，所以我这里先写所一个名字
                        BdCumandocEntity bdCumandocEntity = cacheTocMapVoV2.getStringBdCumandocEntityMap().get(bdCubasdocEntity.getPkCubasdoc() + bdCorpEntity.getPkCorp());
                        Assert.notNull(bdCumandocEntity, "无法匹配到客商档案 店铺名称：{}", "天猫intoyou旗舰店-自营");

                        //查找平台
                        String sourcePlatformCode = header.getSourcePlatformCode();
                        Assert.notNull(sourcePlatformCode, "O平台编码不能为空！");
                        BdDefdocEntity bdDefdocEntity = cacheTocMapVoV2.getStringBdDefdocEntityMap().get(sourcePlatformCode.trim());
                        Assert.notNull(bdDefdocEntity, "根据O平台编码({})无法匹配到U8C平台档案", header.getSourcePlatformCode());

                        //查找店铺
//                    String storeCode2 = header.getStoreCode();
//                    Assert.notNull(storeCode2, "O店铺编码不能为空！");
                        BdDefdocEntity bdDefdocEntity1 = cacheTocMapVoV2.getStringBdDefdocEntityMap1().get(storeCode.trim());
                        Assert.notNull(bdDefdocEntity1, "根据O店铺编码({})无法匹配到U8C店铺档案", storeCode.trim());

                        //字段拷贝
                        for (int j = 0; j < details.size(); j++) {
                            RerturnGoodsOrderSearchDetails rerturnGoodsOrderSearchDetails = details.get(j);

                            //存货管理档案，是发货公司的存货档案
                            Assert.notNull(rerturnGoodsOrderSearchDetails.getSkuCode(), "skucode不能为空");
                            BdInvmandocEntity bdInvmandocEntity = cacheTocMapVoV2.getStringBdInvmandocEntityMap().get(rerturnGoodsOrderSearchDetails.getSkuCode().trim() + bdCorpEntity.getPkCorp());
                            Assert.notNull(bdInvmandocEntity, "无法匹配到存货管理档案 货品sku：{} 公司：{}", rerturnGoodsOrderSearchDetails.getSkuCode().trim(), bdCorpEntity.getPkCorp());
                            //存货基本档案
                            BdInvbasdocEntity bdInvbasdocEntity = cacheTocMapVoV2.getStringBdInvbasdocEntityMap().get(rerturnGoodsOrderSearchDetails.getSkuCode().trim());
                            Assert.notNull(bdInvbasdocEntity, "无法匹配到存货基本档案 存货编码：{}", rerturnGoodsOrderSearchDetails.getSkuCode().trim());
                            //存货税率
                            BdTaxitemsEntity bdTaxitemsEntity = cacheTocMapVoV2.getStringBdTaxitemsEntityMap().get(bdInvmandocEntity.getInvcode());
                            Assert.notNull(bdTaxitemsEntity, "无法匹配到存货税率 存货编码：{}", bdInvmandocEntity.getInvcode());

                            //2024年8月6日 10:16:22 通过O出库单的表头，查询得出U8C档案，放在表体的原因是方便分组汇总
                            //下一个步骤的分组汇总，是通过表体明细完成的
                            PassiveStorageSonDetailsDto2 goodsRertunSonDetailsDto = new PassiveStorageSonDetailsDto2();
                            goodsRertunSonDetailsDto.setHeader(header);
                            goodsRertunSonDetailsDto.setBdCorpEntity(bdCorpEntity);
                            goodsRertunSonDetailsDto.setDeliverGoodsCorp(bdCorpEntity);
                            goodsRertunSonDetailsDto.setBdCalbodyEntity(bdCalbodyEntity);
//                            goodsRertunSonDetailsDto.setBdStordocEntity(bdStordocEntity);
                            goodsRertunSonDetailsDto.setBdCalbodyEntity1(bdCalbodyEntity);
//                            goodsRertunSonDetailsDto.setBdStordocEntity1(bdStordocEntity);
                            goodsRertunSonDetailsDto.setBdSalestruEntity(bdSalestruEntity);
                            goodsRertunSonDetailsDto.setBdDeptdocEntity(bdDeptdocEntity);
                            goodsRertunSonDetailsDto.setBdCumandocEntity(bdCumandocEntity);
                            goodsRertunSonDetailsDto.setBdCubasdocEntity(bdCubasdocEntity);
                            goodsRertunSonDetailsDto.setPlatformArchives(bdDefdocEntity);
                            goodsRertunSonDetailsDto.setBdRdclEntity(bdRdclEntity);
                            goodsRertunSonDetailsDto.setShopArchives(bdDefdocEntity1);
                            goodsRertunSonDetailsDto.setBdInvmandocEntity(bdInvmandocEntity);
                            goodsRertunSonDetailsDto.setBdInvbasdocEntity(bdInvbasdocEntity);
                            goodsRertunSonDetailsDto.setBdTaxitemsEntity(bdTaxitemsEntity);

                            BeanUtil.copyPropertiesV2(rerturnGoodsOrderSearchDetails, goodsRertunSonDetailsDto);
                            sonDetailsDtoList.add(goodsRertunSonDetailsDto);
                            //成功收集进入到集合
                        }
                    } catch (Exception e) {
                        //失败部分处理
                        logger.error("档案转换抛出异常", e);
                        String message = e.getMessage();
                        if (message == null) {
                            message = "未知错误";
                        }
                        ErrorHeaderDetailsDtoDtoV4 errorHeaderDetailsDtoDto = new ErrorHeaderDetailsDtoDtoV4();
                        errorHeaderDetailsDtoDto.setNewPushDate(getNewDateStr());
                        errorHeaderDetailsDtoDto.setNewTransmitInfo(message);
                        errorHeaderDetailsDtoDto.setNewstate("N");
                        errorHeaderDetailsDtoDto.setHeader(header);
                        errorHeaderDetailsDtoDto.setDetails(details);
//                        errorHeaderDetailsDtoDto.setTransactionDate(transactionDate);
                        errorHeaderDetailsDtoDtoList.add(errorHeaderDetailsDtoDto);
                    }
                }
            } catch (Exception e) {
                logger.error("OFS无源入库单关联查询U8C档案失败", e);
            }
        } else {
            logger.info("queryBasicArchives方法passiveStorageResponseDataList.size为0");
        }
        //错误日志同步到数据
        if (errorHeaderDetailsDtoDtoList.size() > 0) {
            updateFailOrSuccessTocofsSaleoutDetailedArchiveInquiry2(errorHeaderDetailsDtoDtoList);
        }
        return sonDetailsDtoList;
    }

    /**
     * 对象拷贝 bean copy
     * 2024年8月9日 11:23:57
     */
    private List<OfsPassiveorderHeaderEntity> copyHeaderDto(List<PassiveStorageResponse.Header> stockinHS) {
        List<OfsPassiveorderHeaderEntity> ofsPassiveorderHeaderEntityArrayList = new ArrayList<>();
        if (stockinHS != null && stockinHS.size() > 0) {
            for (int i = 0; i < stockinHS.size(); i++) {
                PassiveStorageResponse.Header header = stockinHS.get(i);

                OfsPassiveorderHeaderEntity ofsPassiveorderHeaderEntity = new OfsPassiveorderHeaderEntity();
                BeanUtil.copyPropertiesV2(header, ofsPassiveorderHeaderEntity);
                ofsPassiveorderHeaderEntityArrayList.add(ofsPassiveorderHeaderEntity);
            }
        } else {
            logger.info("需要复制{}个bean对象(O表头)", stockinHS.size());
        }
        return ofsPassiveorderHeaderEntityArrayList;
    }

    /**
     * 对象拷贝 bean copy
     * 2024年8月9日 11:23:57
     */
    private List<OnlyAfterSalesHEntity> copyHeaderDtoByTran(List<RerturnGoodsOrderSearchHeader> stockinHS) {
        List<OnlyAfterSalesHEntity> onlyAfterSalesHEntityArrayList = new ArrayList<>();
        if (stockinHS != null && stockinHS.size() > 0) {
            for (int i = 0; i < stockinHS.size(); i++) {
                RerturnGoodsOrderSearchHeader rerturnGoodsOrderSearchHeader = stockinHS.get(i);

                OnlyAfterSalesHEntity ofsPassiveorderHeaderEntity = new OnlyAfterSalesHEntity();
                BeanUtil.copyPropertiesV2(rerturnGoodsOrderSearchHeader, ofsPassiveorderHeaderEntity);

                ofsPassiveorderHeaderEntity.setOfsid(rerturnGoodsOrderSearchHeader.getId());
                onlyAfterSalesHEntityArrayList.add(ofsPassiveorderHeaderEntity);
            }
        } else {
            logger.info("需要复制{}个bean对象(O表头)", 0);
        }
        return onlyAfterSalesHEntityArrayList;
    }

    /**
     * 对象拷贝 bean copy
     *
     * @author liuyang
     */
    private List<OfsPassiveorderDetailEntity> copyDetailsDto(List<PassiveStorageResponse.Details> stockinBS) {
        List<OfsPassiveorderDetailEntity> ofsPassiveorderDetailEntityArrayList = new ArrayList<>();
        if (stockinBS != null && stockinBS.size() > 0) {
            for (int i = 0; i < stockinBS.size(); i++) {
                PassiveStorageResponse.Details details = stockinBS.get(i);
                //表头
                PassiveStorageResponse.Header header = details.getHeader();
                //拷贝对象
                OfsPassiveorderDetailEntity tocofsReturngoodsDetailedEntity = new OfsPassiveorderDetailEntity();
                BeanUtil.copyPropertiesV2(details, tocofsReturngoodsDetailedEntity);
                //补充额外的字段信息
                createPrimaryKeyAndBusinessDateAndBusinessType(tocofsReturngoodsDetailedEntity, header);
                ofsPassiveorderDetailEntityArrayList.add(tocofsReturngoodsDetailedEntity);
            }
        } else {
            logger.info("需要复制{}个bean对象(O表体)", ofsPassiveorderDetailEntityArrayList.size());
        }
        return ofsPassiveorderDetailEntityArrayList;
    }

    /**
     * 对象拷贝 bean copy
     *
     * @param stockinBS                      售后订单明细行
     * @param passiveStorageResponseDataList 无源入库单集合
     * @author liuyang
     */
    private List<OnlyAfterSalesBEntity> copyDetailsDtoTran(List<RerturnGoodsOrderSearchDetails> stockinBS, List<PassiveStorageResponse.Data> passiveStorageResponseDataList, Map<String, HeaderDetailsDto> stringHeaderDetailsDtoMap) {
        List<OnlyAfterSalesBEntity> ofsPassiveorderDetailEntityArrayList = new ArrayList<>();
        if (stockinBS != null && stockinBS.size() > 0) {
            for (int i = 0; i < stockinBS.size(); i++) {
                RerturnGoodsOrderSearchDetails rerturnGoodsOrderSearchDetails = stockinBS.get(i);
                //表头
                RerturnGoodsOrderSearchHeader rerturnGoodsOrderSearchHeader = rerturnGoodsOrderSearchDetails.getRerturnGoodsOrderSearchHeader();
                //拷贝对象
                OnlyAfterSalesBEntity onlyAfterSalesBEntity = new OnlyAfterSalesBEntity();
                BeanUtil.copyPropertiesV2(rerturnGoodsOrderSearchDetails, onlyAfterSalesBEntity);
                //补充额外的字段信息
                createPrimaryKeyAndBusinessDateAndBusinessTypeTran(onlyAfterSalesBEntity, rerturnGoodsOrderSearchHeader, rerturnGoodsOrderSearchDetails, stringHeaderDetailsDtoMap);
                ofsPassiveorderDetailEntityArrayList.add(onlyAfterSalesBEntity);
            }
        } else {
            logger.info("需要复制{}个bean对象(O表体)", stockinBS.size());
        }
        return ofsPassiveorderDetailEntityArrayList;
    }

    /**
     * 分组汇总：公司+店铺+仓库+SKU+出库类型，数量合并相加
     * 修改为：公司+店铺+仓库+SKU+收发类别+部门，数量合并相加
     *
     * @author liuyang
     */
    private Map<String, List<PassiveStorageSonDetailsDto>> groupSummary(List<PassiveStorageSonDetailsDto> goodsRertunSonDetailsDtos, String dimension) {
        if (goodsRertunSonDetailsDtos != null && goodsRertunSonDetailsDtos.size() > 0) {
            for (int i = 0; i < goodsRertunSonDetailsDtos.size(); i++) {
                PassiveStorageSonDetailsDto passiveStorageSonDetailsDto = goodsRertunSonDetailsDtos.get(i);
                //2024年8月6日 10:35:25表头对象用于带出表头相关的分组汇总信息
                PassiveStorageResponse.Header header = passiveStorageSonDetailsDto.getHeader();
                RerturnGoodsOrderSearchData rerturnGoodsOrderSearchData = header.getRerturnGoodsOrderSearchData();//OFS售后订单
                com.hzya.frame.ttxofs.dto.ofssalesordersearch.HeaderDetailsDto headerDetailsDto = header.getHeaderDetailsDto();//OFS销售订单

                //公司
                BdCorpEntity bdCorpEntity = passiveStorageSonDetailsDto.getBdCorpEntity();
                //店铺（主要是店铺编码）
                String storeCode = header.getStoreCode();
                //仓库
                String facilityCode = header.getFacilityCode();
                //SKU
                String skuCode = passiveStorageSonDetailsDto.getSkuCode();
                //出库类型
//                String refOrderType = header.getRefOrderType();
                //收发类别
                BdRdclEntity bdRdclEntity = passiveStorageSonDetailsDto.getBdRdclEntity();
                //部门
                BdDeptdocEntity bdDeptdocEntity = passiveStorageSonDetailsDto.getBdDeptdocEntity();

                StringBuffer summaryDimensionStr = new StringBuffer();
                if (bdCorpEntity != null && bdCorpEntity.getPkCorp() != null) {
                    summaryDimensionStr.append(bdCorpEntity.getPkCorp());
                } else {
                    summaryDimensionStr.append(NOTHING);
                }
                summaryDimensionStr.append(ADD);

                if (storeCode != null && !"".equals(storeCode)) {
                    summaryDimensionStr.append(storeCode);
                } else {
                    summaryDimensionStr.append(NOTHING);
                }
                summaryDimensionStr.append(ADD);

                if (facilityCode != null && !"".equals(facilityCode)) {
                    summaryDimensionStr.append(facilityCode);
                } else {
                    summaryDimensionStr.append(NOTHING);
                }
                summaryDimensionStr.append(ADD);

                if (skuCode != null && !"".equals(skuCode)) {
                    summaryDimensionStr.append(skuCode);
                } else {
                    summaryDimensionStr.append(NOTHING);
                }
                summaryDimensionStr.append(ADD);

                if (bdRdclEntity != null && bdRdclEntity.getRdcode() != null) {
                    summaryDimensionStr.append(bdRdclEntity.getRdcode());
                } else {
                    summaryDimensionStr.append(NOTHING);
                }
                summaryDimensionStr.append(ADD);

                if (bdDeptdocEntity != null && bdDeptdocEntity.getDeptcode() != null) {
                    summaryDimensionStr.append(bdDeptdocEntity.getDeptcode());
                } else {
                    summaryDimensionStr.append(NOTHING);
                }

                passiveStorageSonDetailsDto.setSummaryDimensionStr(summaryDimensionStr.toString());
            }
            logger.info("无源件：{} 个出库单对象需要汇总", goodsRertunSonDetailsDtos.size());
            if (dimension == null) {
                return goodsRertunSonDetailsDtos.stream().collect(Collectors.groupingBy(PassiveStorageSonDetailsDto::getSummaryDimensionStr));
            } else {
                Map<String, List<PassiveStorageSonDetailsDto>> collect = goodsRertunSonDetailsDtos.stream().collect(Collectors.groupingBy(PassiveStorageSonDetailsDto::getSummaryDimensionStr));
                keepOnlyNeededKeys(collect, dimension);
                return collect;
            }
        }
        logger.info("无源件：0个对象需要汇总");
        return null;
    }

    /**
     * 无源件交易成功汇总
     *
     * @author liuyang
     */
    private Map<String, List<PassiveStorageSonDetailsDto2>> groupSummary2(List<PassiveStorageSonDetailsDto2> goodsRertunSonDetailsDtos, String dimension) {
        if (goodsRertunSonDetailsDtos != null && goodsRertunSonDetailsDtos.size() > 0) {
            for (int i = 0; i < goodsRertunSonDetailsDtos.size(); i++) {
                PassiveStorageSonDetailsDto2 passiveStorageSonDetailsDto2 = goodsRertunSonDetailsDtos.get(i);
                //2024年8月6日 10:35:25表头对象用于带出表头相关的分组汇总信息
                RerturnGoodsOrderSearchHeader header = passiveStorageSonDetailsDto2.getHeader();
//                RerturnGoodsOrderSearchData rerturnGoodsOrderSearchData = header.getRerturnGoodsOrderSearchData();//OFS售后订单
//                com.hzya.frame.ttxofs.dto.ofssalesordersearch.HeaderDetailsDto headerDetailsDto = header.getHeaderDetailsDto();//OFS销售订单

                //公司
                BdCorpEntity bdCorpEntity = passiveStorageSonDetailsDto2.getBdCorpEntity();
                //店铺（主要是店铺编码）
                String storeCode = header.getStoreCode();
                //仓库
                String facilityCode = header.getFacilityCode();
                //SKU
                String skuCode = passiveStorageSonDetailsDto2.getSkuCode();
                //出库类型
//                String refOrderType = header.getRefOrderType();
                //收发类别
                BdRdclEntity bdRdclEntity = passiveStorageSonDetailsDto2.getBdRdclEntity();
                //部门
                BdDeptdocEntity bdDeptdocEntity = passiveStorageSonDetailsDto2.getBdDeptdocEntity();

                StringBuffer summaryDimensionStr = new StringBuffer();

                if (passiveStorageSonDetailsDto2.getTargetBusinessDate() != null) {
                    //2025-04-11 18:11:27 我想截取2025-04-11
                    String targetBusinessDate = passiveStorageSonDetailsDto2.getTargetBusinessDate();
                    String targetDate = targetBusinessDate.substring(0, 10);
                    summaryDimensionStr.append(targetDate);
                } else {
                    summaryDimensionStr.append(NOTHING);
                }
                summaryDimensionStr.append(ADD);

                if (bdCorpEntity != null && bdCorpEntity.getPkCorp() != null) {
                    summaryDimensionStr.append(bdCorpEntity.getPkCorp());
                } else {
                    summaryDimensionStr.append(NOTHING);
                }
                summaryDimensionStr.append(ADD);

                if (storeCode != null && !"".equals(storeCode)) {
                    summaryDimensionStr.append(storeCode);
                } else {
                    summaryDimensionStr.append(NOTHING);
                }
                summaryDimensionStr.append(ADD);

                if (facilityCode != null && !"".equals(facilityCode)) {
                    summaryDimensionStr.append(facilityCode);
                } else {
                    summaryDimensionStr.append(NOTHING);
                }
                summaryDimensionStr.append(ADD);

                if (skuCode != null && !"".equals(skuCode)) {
                    summaryDimensionStr.append(skuCode);
                } else {
                    summaryDimensionStr.append(NOTHING);
                }
                summaryDimensionStr.append(ADD);

                if (bdRdclEntity != null && bdRdclEntity.getRdcode() != null) {
                    summaryDimensionStr.append(bdRdclEntity.getRdcode());
                } else {
                    summaryDimensionStr.append(NOTHING);
                }
                summaryDimensionStr.append(ADD);

                if (bdDeptdocEntity != null && bdDeptdocEntity.getDeptcode() != null) {
                    summaryDimensionStr.append(bdDeptdocEntity.getDeptcode());
                } else {
                    summaryDimensionStr.append(NOTHING);
                }

                passiveStorageSonDetailsDto2.setSummaryDimensionStr(summaryDimensionStr.toString());
            }
            logger.info("无源件-售后订单：{} 个出库单对象需要汇总", goodsRertunSonDetailsDtos.size());
            if (dimension == null) {
                return goodsRertunSonDetailsDtos.stream().collect(Collectors.groupingBy(PassiveStorageSonDetailsDto2::getSummaryDimensionStr));
            } else {
                Map<String, List<PassiveStorageSonDetailsDto2>> collect = goodsRertunSonDetailsDtos.stream().collect(Collectors.groupingBy(PassiveStorageSonDetailsDto2::getSummaryDimensionStr));
                keepOnlyNeededKeys2(collect, dimension);
                return collect;
            }
        }
        logger.info("无源件-售后订单：0个对象需要汇总");
        return null;
    }

    /**
     * 移除不需要的键
     *
     * @author liuyang
     */
    private static void keepOnlyNeededKeys(Map<String, List<PassiveStorageSonDetailsDto>> map, String... neededKeys) {
        Iterator<Map.Entry<String, List<PassiveStorageSonDetailsDto>>> iterator = map.entrySet().iterator();
        while (iterator.hasNext()) {
            Map.Entry<String, List<PassiveStorageSonDetailsDto>> entry = iterator.next();
            // 如果不是需要的键，则移除
            if (!contains(neededKeys, entry.getKey())) {
                iterator.remove();
            }
        }
    }

    private static void keepOnlyNeededKeys2(Map<String, List<PassiveStorageSonDetailsDto2>> map, String... neededKeys) {
        Iterator<Map.Entry<String, List<PassiveStorageSonDetailsDto2>>> iterator = map.entrySet().iterator();
        while (iterator.hasNext()) {
            Map.Entry<String, List<PassiveStorageSonDetailsDto2>> entry = iterator.next();
            // 如果不是需要的键，则移除
            if (!contains(neededKeys, entry.getKey())) {
                iterator.remove();
            }
        }
    }

    private static boolean contains(String[] array, String targetValue) {
        for (String value : array) {
            if (value.equals(targetValue)) {
                return true;
            }
        }
        return false;
    }

    /**
     * 2024年8月6日 10:59:03 查询U8C业务流程
     *
     * @author liuyang
     */
    public BdBusitypeEntity u8cOperationFlow() throws Exception {
        //查询业务流程
        //2024年8月6日 11:33:07 具体的业务流程名称，还需要实施提供
        String processName = "TOC无源件退货入库";
        BdBusitypeEntity bdBusitypeEntity = queryBdBusitypeUtil.queryBdBusitype(processName);
        Assert.notNull(bdBusitypeEntity, "根据业务流程名称({})没有查询到业务流程", processName);
        return bdBusitypeEntity;
    }

    /**
     * 2024年8月6日 10:59:03 查询U8C业务流程
     *
     * @author liuyang
     */
    private BdBusitypeEntity u8cOperationFlowV2() throws Exception {
        //查询业务流程
        //2024年8月6日 11:33:07 具体的业务流程名称，还需要实施提供
        String processName = "TOC无源件退款";
        BdBusitypeEntity bdBusitypeEntity = queryBdBusitypeUtil.queryBdBusitype(processName);
        Assert.notNull(bdBusitypeEntity, "根据业务流程名称({})没有查询到业务流程", processName);
        return bdBusitypeEntity;
    }

    /**
     * 检查参数是否为空
     * 2024年8月6日 11:40:19 保险的做法，最好还是验证一下
     *
     * @author liuyang
     */
//    private void checkArchives(GoodsRertunSonDetailsDto sonDetailsDto) {
//        Assert.notNull(sonDetailsDto, "sonDetailsDto不能为空 对象json：{}", JSON.toJSONString(sonDetailsDto));
//        Assert.notNull(sonDetailsDto.getHeader(), "header对象不能为空 对象json：{}", JSON.toJSONString(sonDetailsDto));
//        Assert.notNull(sonDetailsDto.getBdCorpEntity(), "表头公司不能为空 对象json：{}", JSON.toJSONString(sonDetailsDto));
//        Assert.notNull(sonDetailsDto.getBdCalbodyEntity(), "发货库存组织不能为空 对象json：{}", JSON.toJSONString(sonDetailsDto));
//        Assert.notNull(sonDetailsDto.getBdStordocEntity(), "发货仓库不能为空 对象json：{}", JSON.toJSONString(sonDetailsDto));
//        Assert.notNull(sonDetailsDto.getBdCalbodyEntity1(), "收货库存组织不能为空 对象json：{}", JSON.toJSONString(sonDetailsDto));
//        Assert.notNull(sonDetailsDto.getBdStordocEntity1(), "收货库存不能为空 对象json：{}", JSON.toJSONString(sonDetailsDto));
//        Assert.notNull(sonDetailsDto.getBdSalestruEntity(), "销售组织不能为空 对象json：{}", JSON.toJSONString(sonDetailsDto));
//        Assert.notNull(sonDetailsDto.getBdDeptdocEntity(), "业务部门不能为空 对象json：{}", JSON.toJSONString(sonDetailsDto));
//        Assert.notNull(sonDetailsDto.getBdCumandocEntity(), "客商档案不能为空 对象json：{}", JSON.toJSONString(sonDetailsDto));
//    }

    /**
     * 查询存货管理档案
     *
     * @param pkCorp                   发货公司主键
     * @param goodsRertunSonDetailsDto 出库单存货明细行
     * @author liuyang
     */
//    private BdInvmandocEntity queryInventoryMan(GoodsRertunSonDetailsDto goodsRertunSonDetailsDto, String pkCorp) {
//        Assert.notNull(goodsRertunSonDetailsDto, "sonDetailsDto不能为空");
//        Assert.notNull(goodsRertunSonDetailsDto.getSkuCode(), "O存货商家编码不能为空");
//        Assert.notNull(pkCorp, "发货公司主键不能为空");
//
//        BdInvmandocEntity bdInvmandocEntity = TocReturnBasicArchivesCacheUtil.stringBdInvmandocEntityMap.get(goodsRertunSonDetailsDto.getSkuCode() + pkCorp);
//        Assert.notNull(bdInvmandocEntity, "无法匹配到存货管理档案 存货商家编码：{} 存货发货公司：{}", goodsRertunSonDetailsDto.getSkuCode(), pkCorp);
//        return bdInvmandocEntity;
//    }

    /**
     * 合并明细行
     * 单价计算公式：sum(实付金额/实发数量) 最后除以条数
     *
     * @param sonDetailsDtoList 汇总过后的售后入库单明细
     * @param isCheckShopChoose true取建议零售价、false取实付金额
     * @author liuyang
     */
    private PassiveStorageSonDetailsDto groupMergeDetailedRows(List<PassiveStorageSonDetailsDto> sonDetailsDtoList, Boolean isCheckShopChoose) throws Exception {
        Assert.notNull(sonDetailsDtoList, "sonDetailsDtoList不能为空");
        Assert.notNull(isCheckShopChoose, "isCheckShopChoose不能为空");

        if (sonDetailsDtoList != null && sonDetailsDtoList.size() > 0) {
            BigDecimal groupTotalPayAmount = new BigDecimal("0");
            BigDecimal groupShipQty = new BigDecimal("0");

            for (int i = 0; i < sonDetailsDtoList.size(); i++) {
                PassiveStorageSonDetailsDto passiveStorageSonDetailsDto = sonDetailsDtoList.get(i);
                PassiveStorageResponse.Header header = passiveStorageSonDetailsDto.getHeader();

                RerturnGoodsOrderSearchData rerturnGoodsOrderSearchData = header.getRerturnGoodsOrderSearchData();//OFS售后订单
                RerturnGoodsOrderSearchHeader header1 = rerturnGoodsOrderSearchData.getHeader();//OFS售后订单表头对象
                List<RerturnGoodsOrderSearchDetails> details = rerturnGoodsOrderSearchData.getDetails();//OFS售后订单表体对象

//                BdInvmandocEntity bdInvmandocEntity1 = goodsRertunSonDetailsDto.getBdInvmandocEntity();//存货管理档案
                BdInvbasdocEntity bdInvbasdocEntity = passiveStorageSonDetailsDto.getBdInvbasdocEntity();//存货基本档案
                BdInvmandocEntity bdInvmandocEntity = passiveStorageSonDetailsDto.getBdInvmandocEntity();//存货管理档案

                String totalAmount = null;
                StringBuffer calculationFormulaStr = new StringBuffer();
                if (isCheckShopChoose) {
                    //取《U8C存货基本档案-参考售价》
                    totalAmount = getRefsaleprice(bdInvmandocEntity, bdInvbasdocEntity, calculationFormulaStr, passiveStorageSonDetailsDto, null);
                } else {
                    //取《O实退》
                    totalAmount = accumulatedDiscounts(passiveStorageSonDetailsDto, rerturnGoodsOrderSearchData, calculationFormulaStr);
                }

                Assert.notNull(totalAmount, "计算出来的实退金额不能为空");
                Assert.notNull(passiveStorageSonDetailsDto.getQuantity(), "实收数量不能为空");

                BigDecimal totalPayAmountBigDecimal = new BigDecimal(totalAmount);
                BigDecimal quantityBigDecimal = new BigDecimal(passiveStorageSonDetailsDto.getQuantity());

                groupTotalPayAmount = groupTotalPayAmount.add(totalPayAmountBigDecimal);
                groupShipQty = groupShipQty.add(quantityBigDecimal);

                passiveStorageSonDetailsDto.setCalculateAccountsReceivable(totalAmount);
                passiveStorageSonDetailsDto.setCalculationFormula(calculationFormulaStr.toString());

//                if ("6973391732529".equals(passiveStorageSonDetailsDto.getSkuCode())) {
//                    ofsOrderDetail.setPlatformDiscounts("1.02");
//                    ofsOrderDetail.setMerchantDiscounts("4.88");
//                    ofsOrderDetail.setExpertDiscounts("3.13");
//                    ofsOrderDetail.setPayDiscounts("7.88");
//                } else {
//                    ofsOrderDetail.setPlatformDiscounts("6.68");
//                    ofsOrderDetail.setMerchantDiscounts("5.47");
//                    ofsOrderDetail.setExpertDiscounts("4.31");
//                    ofsOrderDetail.setPayDiscounts("3.09");
//                }

                //把无源入库单明细行关联对应的售后订单明细行的优惠金额，带入到无源入库单明细行
                //根据OFS售后入库单明细行，查找匹配OFS售后订单明细行
                //2025年4月18日11:03:56 如果无源入库明细行无法匹配售后订单明细行，则入库时的优惠金额全部为0
                RerturnGoodsOrderSearchDetails ofsOrderDetail = findOfsOrderDetail(details, passiveStorageSonDetailsDto);
                if (ofsOrderDetail != null) {
                    passiveStorageSonDetailsDto.setPlatformDiscounts(ofsOrderDetail.getPlatformDiscounts());
                    passiveStorageSonDetailsDto.setMerchantDiscounts(ofsOrderDetail.getMerchantDiscounts());
                    passiveStorageSonDetailsDto.setExpertDiscounts(ofsOrderDetail.getExpertDiscounts());
                    passiveStorageSonDetailsDto.setPayDiscounts(ofsOrderDetail.getPayDiscounts());
                } else {
                    passiveStorageSonDetailsDto.setPlatformDiscounts("0");
                    passiveStorageSonDetailsDto.setMerchantDiscounts("0");
                    passiveStorageSonDetailsDto.setExpertDiscounts("0");
                    passiveStorageSonDetailsDto.setPayDiscounts("0");
                }
            }

            PassiveStorageSonDetailsDto passiveStorageSonDetailsDto = sonDetailsDtoList.get(0);
            passiveStorageSonDetailsDto.setGroupShipQty(groupShipQty);
            passiveStorageSonDetailsDto.setGroupTotalPayAmount(groupTotalPayAmount);

            //相同的O无源入库单sku累加优惠金额
            accumulatedDiscountAmountDef(sonDetailsDtoList);

            return passiveStorageSonDetailsDto;
        } else {
            logger.info("sonDetailsDtoList集合是空的！");
        }
        return null;
    }

    /**
     * 处理交易成功部分的明细合并
     *
     * @param sonDetailsDtoList 售后订单明细行
     * @param isCheckShopChoose true取建议零售价、false取实退金额
     * @author liuyang
     */
    private PassiveStorageSonDetailsDto2 groupMergeDetailedRows2(List<PassiveStorageSonDetailsDto2> sonDetailsDtoList, Boolean isCheckShopChoose) throws Exception {
        Assert.notNull(sonDetailsDtoList, "sonDetailsDtoList不能为空");
        Assert.notNull(isCheckShopChoose, "isCheckShopChoose不能为空");

        if (sonDetailsDtoList != null && sonDetailsDtoList.size() > 0) {
            BigDecimal groupTotalPayAmount = new BigDecimal("0");
            BigDecimal groupShipQty = new BigDecimal("0");

            for (int i = 0; i < sonDetailsDtoList.size(); i++) {
                PassiveStorageSonDetailsDto2 passiveStorageSonDetailsDto2 = sonDetailsDtoList.get(i);
//                RerturnGoodsOrderSearchHeader header = passiveStorageSonDetailsDto2.getHeader();

//                RerturnGoodsOrderSearchData rerturnGoodsOrderSearchData = header.getRerturnGoodsOrderSearchData();//OFS售后订单
//                RerturnGoodsOrderSearchHeader header1 = rerturnGoodsOrderSearchData.getHeader();//OFS售后订单表头对象
//                List<RerturnGoodsOrderSearchDetails> details = rerturnGoodsOrderSearchData.getDetails();//OFS售后订单表体对象

//                BdInvmandocEntity bdInvmandocEntity1 = goodsRertunSonDetailsDto.getBdInvmandocEntity();//存货管理档案
                BdInvbasdocEntity bdInvbasdocEntity = passiveStorageSonDetailsDto2.getBdInvbasdocEntity();//存货基本档案
                BdInvmandocEntity bdInvmandocEntity = passiveStorageSonDetailsDto2.getBdInvmandocEntity();//存货管理档案

                //根据OFS售后入库单明细行，查找匹配OFS售后订单明细行
//                RerturnGoodsOrderSearchDetails ofsOrderDetail = findOfsOrderDetail(details, passiveStorageSonDetailsDto);

                String totalAmount = null;
                StringBuffer calculationFormulaStr = new StringBuffer();
                if (isCheckShopChoose) {
                    //取《U8C存货基本档案-参考售价》
                    totalAmount = getRefsaleprice(bdInvmandocEntity, bdInvbasdocEntity, calculationFormulaStr, null, passiveStorageSonDetailsDto2);
                } else {
                    //取《O实退金额》
                    totalAmount = passiveStorageSonDetailsDto2.getTotalAmount();
                    calculationFormulaStr.append(passiveStorageSonDetailsDto2.getTotalAmount());
                }

                Assert.notNull(totalAmount, "计算出来的实退金额不能为空");
                Assert.notNull(passiveStorageSonDetailsDto2.getRequestQty(), "请求数量不能为空");

                BigDecimal totalPayAmountBigDecimal = new BigDecimal(totalAmount);
                BigDecimal quantityBigDecimal = new BigDecimal(passiveStorageSonDetailsDto2.getRequestQty());

                groupTotalPayAmount = groupTotalPayAmount.add(totalPayAmountBigDecimal);
                groupShipQty = groupShipQty.add(quantityBigDecimal);

                passiveStorageSonDetailsDto2.setCalculateAccountsReceivable(totalAmount);
                passiveStorageSonDetailsDto2.setCalculationFormula(calculationFormulaStr.toString());

//                if ("6973391732529".equals(passiveStorageSonDetailsDto.getSkuCode())) {
//                    ofsOrderDetail.setPlatformDiscounts("1.02");
//                    ofsOrderDetail.setMerchantDiscounts("4.88");
//                    ofsOrderDetail.setExpertDiscounts("3.13");
//                    ofsOrderDetail.setPayDiscounts("7.88");
//                } else {
//                    ofsOrderDetail.setPlatformDiscounts("6.68");
//                    ofsOrderDetail.setMerchantDiscounts("5.47");
//                    ofsOrderDetail.setExpertDiscounts("4.31");
//                    ofsOrderDetail.setPayDiscounts("3.09");
//                }

                //把无源入库单明细行关联对应的售后订单明细行的优惠金额，带入到无源入库单明细行
//                passiveStorageSonDetailsDto2.setPlatformDiscounts(passiveStorageSonDetailsDto2.getPlatformDiscounts());
//                passiveStorageSonDetailsDto2.setMerchantDiscounts(passiveStorageSonDetailsDto2.getMerchantDiscounts());
//                passiveStorageSonDetailsDto2.setExpertDiscounts(passiveStorageSonDetailsDto2.getExpertDiscounts());
//                passiveStorageSonDetailsDto2.setPayDiscounts(passiveStorageSonDetailsDto2.getPayDiscounts());
            }

            PassiveStorageSonDetailsDto2 passiveStorageSonDetailsDto2 = sonDetailsDtoList.get(0);
            passiveStorageSonDetailsDto2.setGroupShipQty(groupShipQty);
            passiveStorageSonDetailsDto2.setGroupTotalPayAmount(groupTotalPayAmount);

            //相同的O售后订单sku累加优惠金额
            accumulatedDiscountAmountDef2(sonDetailsDtoList);

            return passiveStorageSonDetailsDto2;
        } else {
            logger.info("sonDetailsDtoList集合是空的！");
        }
        return null;
    }

    /**
     * 2024年8月7日 10:25:29
     * 查询基础档案，根据公司、管理档案主键查询
     *
     * @author liuyang
     */
//    private BdInvbasdocEntity queryStockBasicArchives(String pkInvmandoc, String pkCorp) {
//        Assert.notNull(pkInvmandoc, "存货管理档案不能为空");
//        Assert.notNull(pkCorp, "公司档案不能为空");
//        BdInvbasdocEntity bdInvbasdocEntity = TocReturnBasicArchivesCacheUtil.stringBdInvbasdocEntityHashMap.get(pkInvmandoc + pkCorp);
//        Assert.notNull(bdInvbasdocEntity, "根据公司主键：{} 和存货管理档案主键：{} 没有查询到存货基本档案", pkCorp, pkInvmandoc);
//        return bdInvbasdocEntity;
//    }

    /**
     * 2024年8月7日 14:58:34
     * 查询税目档案
     *
     * @author liuyang
     */
//    private BdTaxitemsEntity queryBdTaxitems(String invcode) {
//        Assert.notNull(invcode, "存货编码不能为空");
//        BdTaxitemsEntity bdTaxitemsEntity = TocReturnBasicArchivesCacheUtil.stringBdTaxitemsEntityHashMap.get(invcode);
//        Assert.notNull(bdTaxitemsEntity, "根据存货编码({})，无法匹配到税率！", invcode);
//        return bdTaxitemsEntity;
//    }

    /**
     * 2024年8月8日 10:54:48
     * 推送U8C销售订单方法
     *
     * @author liuyang
     */
    public SoSaleResultRootDto sendU8CTOCOrder(String param) {
        long startLong = System.currentTimeMillis();
        logger.info("TOC推送开始，推送参数：" + param + ",U8C_URL:" + OverallConstant.getOverAllValue("u8c_url"));
        String apiCode = "8000370006";
        String result = HttpRequest.post(OverallConstant.getOverAllValue("u8c_url")).header("appId", OverallConstant.getOverAllValue("appId"))//头信息，多个头信息多次调用此方法即可
                .header("usercode", OverallConstant.getOverAllValue("u8cApiUsercodePK")).header("password", OverallConstant.getOverAllValue("u8cApiPasswordPK")).header("system", OverallConstant.getOverAllValue("u8cApiSystemPK")).header("trantype", OverallConstant.getOverAllValue("u8cApiTrantypePK")).header("apiCode", apiCode)//头信息，多个头信息多次调用此方法即可
                .header("publicKey", OverallConstant.getOverAllValue("publicKey"))//头信息，多个头信息多次调用此方法即可
                .header("secretKey", OverallConstant.getOverAllValue("secretKey"))//头信息，多个头信息多次调用此方法即可
                .body(param)//表单内容
                .timeout(600000)//超时，毫秒
                .execute().body();
        logger.info("TOC推送结束，返回参数：" + result);
        long endLong = System.currentTimeMillis();
        logger.info("TOC接口请求耗时：" + (endLong - startLong));

        JSONObject jsonObject = JSON.parseObject(result);
        result = String.valueOf(jsonObject.get("attribute"));

        boolean isSuccess = false;
        SoSaleResultRootDto soSaleResultRootDto = null;
        if (result != null && !"".equals(result)) {
            ReusltStrDto reusltStrDto = JSON.parseObject(result, ReusltStrDto.class);
            if ("success".equals(reusltStrDto.getStatus())) {
                soSaleResultRootDto = resultDataHandle(reusltStrDto.getData());
                isSuccess = true;
            }
        }
        if (!isSuccess) {
            Assert.state(false, "TOC业务O出库单推送U8C销售订单失败 接口返回结果：{}", result);
        }
        return soSaleResultRootDto;
    }

    /**
     * 2025 年 3 月 13 日 14:08:20
     * 推送U8红字应收单方法
     *
     * @author liuyang
     */
    public ArapDjzb sendU8cRedReceivable(String param) {
        long startLong = System.currentTimeMillis();
        logger.info("TOC推送开始，推送参数：" + param + ",U8C_URL:" + OverallConstant.getOverAllValue("u8c_url"));
        String apiCode = "8000370069";
        String result = HttpRequest.post(OverallConstant.getOverAllValue("u8c_url")).header("appId", OverallConstant.getOverAllValue("appId"))//头信息，多个头信息多次调用此方法即可
                .header("usercode", OverallConstant.getOverAllValue("u8cApiUsercodeCode")).header("password", OverallConstant.getOverAllValue("u8cApiPasswordCode")).header("system", OverallConstant.getOverAllValue("u8cApiSystemCode")).header("trantype", OverallConstant.getOverAllValue("u8cApiTrantypeCode")).header("apiCode", apiCode)//头信息，多个头信息多次调用此方法即可
                .header("publicKey", OverallConstant.getOverAllValue("publicKey"))//头信息，多个头信息多次调用此方法即可
                .header("secretKey", OverallConstant.getOverAllValue("secretKey"))//头信息，多个头信息多次调用此方法即可
                .body(param)//表单内容
                .timeout(600000)//超时，毫秒
                .execute().body();
        logger.info("TOC推送结束，返回参数：" + result);
        long endLong = System.currentTimeMillis();
        logger.info("TOC接口请求耗时：" + (endLong - startLong));

        JSONObject jsonObject = JSON.parseObject(result);
        result = String.valueOf(jsonObject.get("attribute"));

        boolean isSuccess = false;
        ArapDjzb arapDjzb = null;
        if (result != null && !"".equals(result)) {
            ReusltStrDto reusltStrDto = JSON.parseObject(result, ReusltStrDto.class);
            if ("success".equals(reusltStrDto.getStatus())) {
                arapDjzb = resultDataHandle2(reusltStrDto.getData());
                isSuccess = true;
            }
        }
        if (!isSuccess) {
            Assert.state(false, "TOC无源入库单生成红字应收单失败 接口返回结果：{}", result);
        }
        return arapDjzb;
    }

    /**
     * 返回结果解析处理，在确认了success后调用
     *
     * @author liuyang
     */
    private SoSaleResultRootDto resultDataHandle(String resultData) {
        try {
            if (resultData != null && !"".equals(resultData)) {
                if (resultData.contains("[")) {
                    resultData = resultData.substring(1, resultData.length() - 1);
                }
                return JSON.parseObject(resultData, SoSaleResultRootDto.class);
            }
        } catch (Exception e) {
            e.printStackTrace();
            logger.error("解析返回参数失败的错误", e);
            //如果解析失败，记录原因，但是不能影响结果的记录
        }
        return null;
    }

    private ArapDjzb resultDataHandle2(String resultData) {
        try {
            if (resultData != null && !"".equals(resultData)) {
                if (resultData.contains("[")) {
                    resultData = resultData.substring(1, resultData.length() - 1);
                }
                return JSON.parseObject(resultData, ArapDjzb.class);
            }
        } catch (Exception e) {
            e.printStackTrace();
            logger.error("解析返回参数失败的错误", e);
            //如果解析失败，记录原因，但是不能影响结果的记录
        }
        return null;
    }

    /**
     * 填充主表主键、业务日期、业务类型
     * 2024年8月15日 17:31:54
     *
     * @param ofsPassiveorderDetailEntity 无源件明细表 dao 对象
     * @param header                      O 无源件明细原始对象
     */
    private void createPrimaryKeyAndBusinessDateAndBusinessType(OfsPassiveorderDetailEntity ofsPassiveorderDetailEntity, PassiveStorageResponse.Header header) {
        if (ofsPassiveorderDetailEntity != null && header != null) {
            //主表主键
            if (header.getId() != null) {
                ofsPassiveorderDetailEntity.setHeaderid(header.getId());
            }
            //业务日期
            if (header.getRelatedAt() != null) {
                ofsPassiveorderDetailEntity.setBusinessdate(header.getRelatedAt());
            }
            //业务类型
            ofsPassiveorderDetailEntity.setBusinesstype("TOC_ORDER");
        }
    }

    /**
     * 填充主表主键、业务日期、业务类型
     * 2024年8月15日 17:31:54
     *
     * @param ofsPassiveorderDetailEntity    售后订单明细行对象
     * @param header                         售后订单表头对象
     * @param rerturnGoodsOrderSearchDetails 售后订单表体对象
     * @param stringHeaderDetailsDtoMap      对应的销售订单Map集合
     */
    private void createPrimaryKeyAndBusinessDateAndBusinessTypeTran(OnlyAfterSalesBEntity ofsPassiveorderDetailEntity, RerturnGoodsOrderSearchHeader header, RerturnGoodsOrderSearchDetails rerturnGoodsOrderSearchDetails, Map<String, HeaderDetailsDto> stringHeaderDetailsDtoMap) {
        if (ofsPassiveorderDetailEntity != null && header != null && stringHeaderDetailsDtoMap != null) {
            //主表主键
            if (header.getId() != null) {
                ofsPassiveorderDetailEntity.setHid(header.getId());
            }
            if (ofsPassiveorderDetailEntity.getId() != null) {
                ofsPassiveorderDetailEntity.setOfsid(ofsPassiveorderDetailEntity.getId());
            }

            //销售订单-交易成功时间
            HeaderDetailsDto headerDetailsDto = stringHeaderDetailsDtoMap.get(header.getRefOrderCode());
            HeaderDto header1 = headerDetailsDto.getHeader();
            String tradeSuccessAt = header1.getTradeSuccessAt();
            DateTime tradeSuccessAtDate = DateUtil.parse(tradeSuccessAt);

            //售后订单-退款时间
            String refundedAt = header.getRefundedAt();
            DateTime refundedAtDate = DateUtil.parse(refundedAt);
            //业务日期,如果正向交易时间比退款时间晚，则取正向交易成功时间
            if (tradeSuccessAtDate.after(refundedAtDate)) {
                ofsPassiveorderDetailEntity.setTransactionDate(tradeSuccessAt);
            } else {
                ofsPassiveorderDetailEntity.setTransactionDate(refundedAt);
            }
            //确定好目标业务时间，方便下游系统获取这个业务时间，用于分组汇总和U8C红字应收单对应的单据日期
            rerturnGoodsOrderSearchDetails.setTargetBusinessDate(ofsPassiveorderDetailEntity.getTransactionDate());
            //业务类型
            ofsPassiveorderDetailEntity.setBusinessType(BUSINESS_TYPE);
        }
    }

    /**
     * 通过OFS销售出库单，联查OFS销售订单
     *
     * @param headerDetailsDtoList OFS销售出库单
     */
//    private List<com.hzya.frame.ttxofs.dto.ofssalesordersearch.HeaderDetailsDto> queryOfsOrder(List<com.hzya.frame.ttxofs.dto.ofssaleorderoutsearch.HeaderDetailsDto> headerDetailsDtoList) throws Exception {
//        List<com.hzya.frame.ttxofs.dto.ofssalesordersearch.HeaderDetailsDto> allHeaderDetailsDtoArrayList = new ArrayList<>();
//        try {
//            if (headerDetailsDtoList != null && headerDetailsDtoList.size() > 0) {
//                List<List<HeaderDetailsDto>> splitListByCount = SplitListByCountUtil.splitListByCount(headerDetailsDtoList, 100);
//                for (int i = 0; i < splitListByCount.size(); i++) {
//                    List<HeaderDetailsDto> headerDetailsDtos = splitListByCount.get(i);
//
//                    StringBuffer stringBuffer = new StringBuffer();
//                    if (headerDetailsDtos != null && headerDetailsDtos.size() > 0) {
//                        for (int j = 0; j < headerDetailsDtos.size(); j++) {
//                            HeaderDetailsDto headerDetailsDto = headerDetailsDtos.get(j);
//                            HeaderDto header = headerDetailsDto.getHeader();
////                List<DetailsDto> details = headerDetailsDto.getDetails();
////                stringBuffer.append("'");
//                            stringBuffer.append(header.getRefOrderCode());
////                stringBuffer.append("'");
//                            stringBuffer.append(",");
//                        }
//                    }
//                    String substring = stringBuffer.substring(0, stringBuffer.length());
//
//                    List<com.hzya.frame.ttxofs.dto.ofssalesordersearch.HeaderDetailsDto> headerDetailsDtoArrayList = new ArrayList<>();
//                    QueryOfsSoSaleOutVo queryOfsSoSaleOutVo = new QueryOfsSoSaleOutVo();
//                    queryOfsSoSaleOutVo.setCode(substring);
//                    ofsStandardUtil.getOfsSaleOrder(queryOfsSoSaleOutVo, headerDetailsDtoArrayList, 1L);
//                    allHeaderDetailsDtoArrayList.addAll(headerDetailsDtoArrayList);
//                }
//            }
//        } catch (Exception e) {
//            logger.error("queryOfsOrder方法抛出异常", e);
//        }
//        return allHeaderDetailsDtoArrayList;
//    }

    /**
     * 批量查询售后订单
     *
     * @param returnGoodHeaderDetailsDataDtoList1 OFS售后入库单
     * @author liuyang
     */
    private List<RerturnGoodsOrderSearchData> queryBatchAfterSalesOrder(List<PassiveStorageResponse.Data> returnGoodHeaderDetailsDataDtoList1) {
        List<RerturnGoodsOrderSearchData> rerturnGoodsOrderSearchDataList = new ArrayList<>();
        if (returnGoodHeaderDetailsDataDtoList1 != null && returnGoodHeaderDetailsDataDtoList1.size() > 0) {
            try {
                //完成去重,已经和万万确认，售后入库单明细行不会有合单的情况
                Set<String> returnOrderCodeSet = new HashSet<>();
                for (int i = 0; i < returnGoodHeaderDetailsDataDtoList1.size(); i++) {
                    PassiveStorageResponse.Data data = returnGoodHeaderDetailsDataDtoList1.get(i);
                    PassiveStorageResponse.Header header = data.getHeader();
                    List<PassiveStorageResponse.Details> details = data.getDetails();

                    String returnOrderCode = header.getReturnOrderCode();
                    if (returnOrderCode != null && !"".equals(returnOrderCode.trim())) {
                        returnOrderCodeSet.add(returnOrderCode.trim());
                    }
                }

                if (returnOrderCodeSet.size() > 0) {
                    List<String> stringList = returnOrderCodeSet.stream().collect(Collectors.toList());
                    List<List<String>> lists = SplitListByCountUtil.splitListByCount(stringList, 100);
                    for (int i = 0; i < lists.size(); i++) {
                        List<String> strings = lists.get(i);
                        String result = strings.stream().map(s -> s.trim()).collect(Collectors.joining(","));
                        if (result != null && result.length() > 0) {
                            QueryOfsSoSaleOutVo queryOfsSoSaleOutVo = new QueryOfsSoSaleOutVo();
                            queryOfsSoSaleOutVo.setCode(result);
                            afterSalesOrderUtil.getBatchOfsRertunOrder(queryOfsSoSaleOutVo, rerturnGoodsOrderSearchDataList, 1L);
                        }
                    }
                }
            } catch (Exception e) {
                logger.error("批量查询关联售后订单抛出异常", e);
                Assert.state(false, "批量查询售后订单跑出异常，异常原因：{}", e.getMessage());
            }
        }
        return rerturnGoodsOrderSearchDataList;
    }

    /**
     * 匹配售后订单
     *
     * @param rerturnGoodsOrderSearchDataList OFS售后订单集合
     * @param passiveStorageResponseList      无源入库单对象
     * @author liuyang
     */
    private void findAfterSalesOrder(List<RerturnGoodsOrderSearchData> rerturnGoodsOrderSearchDataList, List<PassiveStorageResponse.Data> passiveStorageResponseList) throws Exception {
        if (rerturnGoodsOrderSearchDataList != null && rerturnGoodsOrderSearchDataList.size() > 0 && passiveStorageResponseList != null && passiveStorageResponseList.size() > 0) {
            try {
                //key为售后订单主键，如果id为空，则这里会报错，所以把id设置为""
                //使用 stream 完成快速查找
                rerturnGoodsOrderSearchDataList.forEach(dto -> {
                    if (dto.getHeader() != null && dto.getHeader().getId() == null) {
                        dto.getHeader().setId("");
                    }
                });
                Map<String, RerturnGoodsOrderSearchData> collect = rerturnGoodsOrderSearchDataList.stream().collect(Collectors.toMap(dto -> dto.getHeader().getCode(), dto -> dto));

                //O无源入库单关联售后订单
                //O 售后订单表头交易成功时间，导入到无源入库单明细行
                for (int i = 0; i < passiveStorageResponseList.size(); i++) {
                    PassiveStorageResponse.Data data = passiveStorageResponseList.get(i);
                    PassiveStorageResponse.Header header = data.getHeader();
                    List<PassiveStorageResponse.Details> details = data.getDetails();

                    String returnOrderCode = header.getReturnOrderCode();
                    if (returnOrderCode != null && !"".equals(returnOrderCode)) {
                        RerturnGoodsOrderSearchData rerturnGoodsOrderSearchData = collect.get(returnOrderCode);
                        if (rerturnGoodsOrderSearchData != null) {
                            header.setRerturnGoodsOrderSearchData(rerturnGoodsOrderSearchData);

                            RerturnGoodsOrderSearchHeader header1 = rerturnGoodsOrderSearchData.getHeader();
                            List<RerturnGoodsOrderSearchDetails> details1 = rerturnGoodsOrderSearchData.getDetails();

                            String refundedAt = header1.getRefundedAt();
                            if (refundedAt != null) {
                                for (PassiveStorageResponse.Details passiveStorage : details) {
                                    passiveStorage.setRefundedAt(refundedAt);
                                }
                            }
                        }
                    }
                }

                //去死皮
                for (PassiveStorageResponse.Data data : passiveStorageResponseList) {
                    PassiveStorageResponse.Header header = data.getHeader();
                    String returnOrderCode = header.getReturnOrderCode();

                    RerturnGoodsOrderSearchData rerturnGoodsOrderSearchData = header.getRerturnGoodsOrderSearchData();
                    if (rerturnGoodsOrderSearchData == null) {
                        Assert.state(false, "无源入库单{}无法匹配到售后订单号 售后订单号：{}", header.getReceiptCode(), header.getReturnOrderCode());
                    }
                }
            } catch (Exception e) {
                logger.error("findAfterSalesOrder方法抛出异常", e);
            }
        }
    }

    /**
     * 通过售后入库单明细行，查找售后订单明细行
     *
     * @param stockinB       售后订单明细行
     * @param ofsRertunOrder OFS售后订单
     * @author liuyang
     */
//    private RerturnGoodsOrderSearchDetails findAfterSalesOrderV2(StockinOrderSearchResponse.StockinOrder.StockinB stockinB, RerturnGoodsOrderSearchData ofsRertunOrder) {
//        Assert.notNull(stockinB, "stockinB不能为空！");
//        Assert.notNull(ofsRertunOrder, "saleOrderMessageDto不能为空！");
//
//        Assert.notNull(ofsRertunOrder.getHeader(), "售后订表头不能为空！");
//        Assert.notNull(ofsRertunOrder.getDetails(), "售后订单表头");
//        RerturnGoodsOrderSearchHeader header = ofsRertunOrder.getHeader();
//        List<RerturnGoodsOrderSearchDetails> details1 = ofsRertunOrder.getDetails();
//        if (details1 == null || details1.size() == 0) {
//            Assert.state(false, "售后订单明细行不能为空，size不能为0！");
//        }
//        for (int i = 0; i < details1.size(); i++) {
//            RerturnGoodsOrderSearchDetails rerturnGoodsOrderSearchDetails = details1.get(i);
//            if (rerturnGoodsOrderSearchDetails.getId().equals(stockinB.getRefOrderDetailId())) {
//                return rerturnGoodsOrderSearchDetails;
//            }
//        }
//        Assert.state(false, "通过售后入库单号({})无法匹配到售后订单", stockinB.getId());
//        return null;
//    }

    /**
     * 通过售后入库单对应的售后订单，查询OFS销售订单
     *
     * @param returnGoodHeaderDetailsDataDtoList1 OFS售后入库单集合
     * @author liuyang
     */
    private List<com.hzya.frame.ttxofs.dto.ofssalesordersearch.HeaderDetailsDto> queryBatchOfsOrder(List<PassiveStorageResponse.Data> returnGoodHeaderDetailsDataDtoList1) throws Exception {
        List<com.hzya.frame.ttxofs.dto.ofssalesordersearch.HeaderDetailsDto> headerDetailsDtoArrayList = new ArrayList<>();

        if (returnGoodHeaderDetailsDataDtoList1 != null && returnGoodHeaderDetailsDataDtoList1.size() > 0) {
            try {
                Set<String> refOrderCodeSet = new HashSet<>();
                for (int i = 0; i < returnGoodHeaderDetailsDataDtoList1.size(); i++) {
                    PassiveStorageResponse.Data data = returnGoodHeaderDetailsDataDtoList1.get(i);
                    PassiveStorageResponse.Header header = data.getHeader();
                    List<PassiveStorageResponse.Details> details = data.getDetails();

                    if (header.getRerturnGoodsOrderSearchData() != null) {
                        RerturnGoodsOrderSearchData rerturnGoodsOrderSearchData = header.getRerturnGoodsOrderSearchData();//OFS售后入库单对应的「售后订单」
                        RerturnGoodsOrderSearchHeader header1 = rerturnGoodsOrderSearchData.getHeader();
                        List<RerturnGoodsOrderSearchDetails> details1 = rerturnGoodsOrderSearchData.getDetails();
                        //得到「售后订单」关联的销售订单号
                        if (header1.getRefOrderCode() != null && !"".equals(header1.getRefOrderCode())) {
                            refOrderCodeSet.add(header1.getRefOrderCode().trim());
                        }
                    }
                }

                //Set集合转List集合
                if (refOrderCodeSet.size() > 0) {
                    List<String> stringList = refOrderCodeSet.stream().collect(Collectors.toList());
                    List<List<String>> lists = SplitListByCountUtil.splitListByCount(stringList, 100);
                    for (int i = 0; i < lists.size(); i++) {
                        List<String> strings = lists.get(i);
                        String result = strings.stream().map(s -> s.trim()).collect(Collectors.joining(","));
                        if (result != null && result.length() > 0) {
                            QueryOfsSoSaleOutVo queryOfsSoSaleOutVo = new QueryOfsSoSaleOutVo();
                            queryOfsSoSaleOutVo.setCode(result);
                            ofsStandardUtil.getOfsSaleOrder(queryOfsSoSaleOutVo, headerDetailsDtoArrayList, 1L);
                        }
                    }
                }
            } catch (Exception e) {
                logger.error("queryBatchOfsOrder方法抛出异常", e);
            }
        }
        return headerDetailsDtoArrayList;
    }

    /**
     * 匹配OFS销售订单
     *
     * @param headerDetailsDtoList                OFS销售订单
     * @param returnGoodHeaderDetailsDataDtoList1 O无源入库单
     * @author liuyang
     */
    private void findOfsOrder(List<com.hzya.frame.ttxofs.dto.ofssalesordersearch.HeaderDetailsDto> headerDetailsDtoList, List<PassiveStorageResponse.Data> returnGoodHeaderDetailsDataDtoList1) {
        if (headerDetailsDtoList != null && headerDetailsDtoList.size() > 0 && returnGoodHeaderDetailsDataDtoList1 != null && returnGoodHeaderDetailsDataDtoList1.size() > 0) {
            try {
                headerDetailsDtoList.forEach(dto -> {
                    if (dto.getHeader() != null && dto.getHeader().getId() == null) {
                        dto.getHeader().setId("");
                    }
                });
                Map<String, com.hzya.frame.ttxofs.dto.ofssalesordersearch.HeaderDetailsDto> collect = headerDetailsDtoList.stream().collect(Collectors.toMap(dto -> dto.getHeader().getId(), dto -> dto));

                for (int i = 0; i < returnGoodHeaderDetailsDataDtoList1.size(); i++) {
                    PassiveStorageResponse.Data data = returnGoodHeaderDetailsDataDtoList1.get(i);
                    PassiveStorageResponse.Header header = data.getHeader();
                    List<PassiveStorageResponse.Details> details = data.getDetails();

                    //把O无源入库单表头关联O销售订单
                    RerturnGoodsOrderSearchData rerturnGoodsOrderSearchData = header.getRerturnGoodsOrderSearchData();
                    RerturnGoodsOrderSearchHeader header2 = rerturnGoodsOrderSearchData.getHeader();
                    List<RerturnGoodsOrderSearchDetails> details2 = rerturnGoodsOrderSearchData.getDetails();
                    if (header2.getRefOrderId() != null && !"".equals(header2.getRefOrderId().trim())) {
                        com.hzya.frame.ttxofs.dto.ofssalesordersearch.HeaderDetailsDto headerDetailsDto = collect.get(header2.getRefOrderId().trim());
                        if (headerDetailsDto != null) {
                            header.setHeaderDetailsDto(headerDetailsDto);
                        }
                    }
                }
            } catch (Exception e) {
                logger.error("findOfsOrder方法抛出异常", e);
                Assert.state(false, "findOfsOrder方法抛出异常 错误详情：{}", e.getMessage());
            }
        }
    }

    /**
     * 生成当前日期
     *
     * @author liuyang
     */
    private String getNewDateStr() {
        LocalDateTime now = LocalDateTime.now();
        DateTimeFormatter formatter = DateTimeFormatter.ofPattern("yyyy-MM-dd HH:mm:ss");
        return now.format(formatter);
    }

    /**
     * 批量修改成功、或者失败，适合档案查询的部分
     *
     * @param errorHeaderDetailsDtoDtoV3List 错误日志
     * @param sceneType                      场景类型
     * @author liuyang
     */
    private void updateFailOrSuccessTocofsSaleoutDetailedArchiveInquiry(List<ErrorHeaderDetailsDtoDtoV3> errorHeaderDetailsDtoDtoV3List, String sceneType) {
        Assert.notNull(errorHeaderDetailsDtoDtoV3List, "errorHeaderDetailsDtoDtoV3List不能为空！");
        Assert.notNull(sceneType, "sceneType不能为空！");

        Thread thread = new Thread(new Runnable() {
            @Override
            public void run() {
                try {
                    if (errorHeaderDetailsDtoDtoV3List != null && errorHeaderDetailsDtoDtoV3List.size() > 0) {
                        List<OfsPassiveorderDetailEntity> tocofsSaleoutDetailedEntityList = new ArrayList<>();
                        for (int i = 0; i < errorHeaderDetailsDtoDtoV3List.size(); i++) {
                            ErrorHeaderDetailsDtoDtoV3 errorHeaderDetailsDtoDtoV3 = errorHeaderDetailsDtoDtoV3List.get(i);
                            PassiveStorageResponse.Header header = errorHeaderDetailsDtoDtoV3.getHeader();
                            List<PassiveStorageResponse.Details> details = errorHeaderDetailsDtoDtoV3.getDetails();

                            String newstate = errorHeaderDetailsDtoDtoV3.getNewstate();
                            String newPushDate = errorHeaderDetailsDtoDtoV3.getNewPushDate();
                            String newTransmitInfo = errorHeaderDetailsDtoDtoV3.getNewTransmitInfo();
                            String newsystemnumber = errorHeaderDetailsDtoDtoV3.getNewsystemnumber();
                            String newsystemprimary = errorHeaderDetailsDtoDtoV3.getNewsystemprimary();
//                            String transactionDate = errorHeaderDetailsDtoDtoV3.getTransactionDate();

                            //如果报错内容太长了，则仅保留400个长度，维护数据库性能，缓解资源公平使用
                            if (newTransmitInfo != null && !"".equals(newTransmitInfo.trim()) && newTransmitInfo.length() >= 400) {
                                newTransmitInfo = newTransmitInfo.substring(0, 400);
                            }

                            for (int j = 0; j < details.size(); j++) {
                                PassiveStorageResponse.Details details1 = details.get(j);

                                OfsPassiveorderDetailEntity ofsPassiveorderDetailEntity = new OfsPassiveorderDetailEntity();
                                ofsPassiveorderDetailEntity.setId(details1.getId());
                                ofsPassiveorderDetailEntity.setTransactionDate(details1.getRefundedAt());
                                if (sceneType.equals("stock")) {
                                    ofsPassiveorderDetailEntity.setNewpushdate(newPushDate);
                                    ofsPassiveorderDetailEntity.setNewtransmitinfo(newTransmitInfo);
                                    ofsPassiveorderDetailEntity.setNewstate(newstate);
                                    if (!"N".equals(newstate)) {
                                        ofsPassiveorderDetailEntity.setNewsystemnumber(newsystemnumber);
                                        ofsPassiveorderDetailEntity.setNewsystemprimary(newsystemprimary);
                                    }
                                } else if (sceneType.equals("tran")) {
                                    ofsPassiveorderDetailEntity.setNewpushdate2(newPushDate);
                                    ofsPassiveorderDetailEntity.setNewtransmitinfo2(newTransmitInfo);
                                    ofsPassiveorderDetailEntity.setNewstate2(newstate);
                                    if (!"N".equals(newstate)) {
                                        ofsPassiveorderDetailEntity.setNewsystemnumber2(newsystemnumber);
                                        ofsPassiveorderDetailEntity.setNewsystemprimary2(newTransmitInfo);
                                    }
                                }
                                tocofsSaleoutDetailedEntityList.add(ofsPassiveorderDetailEntity);
                            }
                        }

                        //以50行为一个批次更新状态,并且入库和确认收入调用不同的方法
                        if (tocofsSaleoutDetailedEntityList.size() > 0) {
                            List<List<OfsPassiveorderDetailEntity>> lists = SplitListByCountUtil.splitListByCount(tocofsSaleoutDetailedEntityList, 50);
                            for (int i = 0; i < lists.size(); i++) {
                                List<OfsPassiveorderDetailEntity> ofsPassiveorderDetailEntities = lists.get(i);
                                if (sceneType.equals("stock")) {
                                    iOfsPassiveorderDetailDao.entityInsertOrUpdateBatchByStock(ofsPassiveorderDetailEntities);
                                } else if (sceneType.equals("tran")) {
                                    iOfsPassiveorderDetailDao.entityInsertOrUpdateBatchByTran(ofsPassiveorderDetailEntities);
                                }
                            }
                        }
                    }
                } catch (Exception e) {
                    logger.error("无源件业务填充出库明细日志抛出异常", e);
                }
            }
        });
        thread.start();
        try {
            thread.join();
        } catch (Exception e) {
            logger.error("updateFailOrSuccessTocofsSaleoutDetailedArchiveInquiry方法调用join 跑出异常", e);
        }
    }

    /**
     * 批量修改成功、或者失败，适合档案查询的部分
     *
     * @param errorHeaderDetailsDtoDtoV3List 错误日志
     * @author liuyang
     */
    private void updateFailOrSuccessTocofsSaleoutDetailedArchiveInquiry2(List<ErrorHeaderDetailsDtoDtoV4> errorHeaderDetailsDtoDtoV3List) {
        Assert.notNull(errorHeaderDetailsDtoDtoV3List, "errorHeaderDetailsDtoDtoV3List不能为空！");

        Thread thread = new Thread(new Runnable() {
            @Override
            public void run() {
                try {
                    if (errorHeaderDetailsDtoDtoV3List != null && errorHeaderDetailsDtoDtoV3List.size() > 0) {
                        List<OnlyAfterSalesBEntity> onlyAfterSalesBEntityArrayList = new ArrayList<>();
                        for (int i = 0; i < errorHeaderDetailsDtoDtoV3List.size(); i++) {
                            ErrorHeaderDetailsDtoDtoV4 errorHeaderDetailsDtoDtoV4 = errorHeaderDetailsDtoDtoV3List.get(i);
                            RerturnGoodsOrderSearchHeader header = errorHeaderDetailsDtoDtoV4.getHeader();
                            List<RerturnGoodsOrderSearchDetails> details = errorHeaderDetailsDtoDtoV4.getDetails();

                            String newstate = errorHeaderDetailsDtoDtoV4.getNewstate();
                            String newPushDate = errorHeaderDetailsDtoDtoV4.getNewPushDate();
                            String newTransmitInfo = errorHeaderDetailsDtoDtoV4.getNewTransmitInfo();
                            String newsystemnumber = errorHeaderDetailsDtoDtoV4.getNewsystemnumber();
                            String newsystemprimary = errorHeaderDetailsDtoDtoV4.getNewsystemprimary();

                            //如果报错内容太长了，则仅保留400个长度，维护数据库性能，缓解资源公平使用
                            if (newTransmitInfo != null && !"".equals(newTransmitInfo.trim()) && newTransmitInfo.length() >= 400) {
                                newTransmitInfo = newTransmitInfo.substring(0, 400);
                            }

                            for (int j = 0; j < details.size(); j++) {
                                RerturnGoodsOrderSearchDetails rerturnGoodsOrderSearchDetails = details.get(j);

                                OnlyAfterSalesBEntity onlyAfterSalesBEntity = new OnlyAfterSalesBEntity();
                                onlyAfterSalesBEntity.setOfsid(rerturnGoodsOrderSearchDetails.getId());
                                onlyAfterSalesBEntity.setNewPushDate(newPushDate);
                                onlyAfterSalesBEntity.setNewTransmitInfo(newTransmitInfo);
                                onlyAfterSalesBEntity.setNewState(newstate);
                                if (!"N".equals(newstate)) {
                                    onlyAfterSalesBEntity.setNewsystemnumber(newsystemnumber);
                                    onlyAfterSalesBEntity.setNewsystemprimary(newTransmitInfo);
                                }
                                onlyAfterSalesBEntityArrayList.add(onlyAfterSalesBEntity);
                            }
                        }

                        //以50行为一个批次更新状态,并且入库和确认收入调用不同的方法
                        if (onlyAfterSalesBEntityArrayList.size() > 0) {
                            List<List<OnlyAfterSalesBEntity>> lists = SplitListByCountUtil.splitListByCount(onlyAfterSalesBEntityArrayList, 50);
                            for (int i = 0; i < lists.size(); i++) {
                                List<OnlyAfterSalesBEntity> onlyAfterSalesBEntities = lists.get(i);
                                iOnlyAfterSalesBDao.entityInsertOrUpdateBatchBySuccessOrFail(onlyAfterSalesBEntities);
                            }
                        }
                    }
                } catch (Exception e) {
                    logger.error("无源件-售后订单业务填充出库明细日志抛出异常", e);
                }
            }
        });
        thread.start();
        try {
            thread.join();
        } catch (Exception e) {
            logger.error("updateFailOrSuccessTocofsSaleoutDetailedArchiveInquiry方法调用join 跑出异常", e);
        }
    }

    /**
     * 处理TOC-库存同步的成功、失败错误逻辑
     *
     * @author liuyang
     */
    private void updateSuccessOrFail1(List<PassiveStorageSonDetailsDto> sonDetailsDtoList, String newstate, String newTransmitInfo, String newsystemnumber, String newsystemprimary) {
        if (newTransmitInfo != null && !"".equals(newTransmitInfo.trim()) && newTransmitInfo.length() >= 400) {
            newTransmitInfo = newTransmitInfo.substring(0, 400);
        }

        String finalNewTransmitInfo = newTransmitInfo;
        Thread thread = new Thread(new Runnable() {
            @Override
            public void run() {
                try {
                    String successY = "Y";
                    if (sonDetailsDtoList != null && sonDetailsDtoList.size() > 0) {

                        List<OfsPassiveorderDetailEntity> ofsPassiveorderDetailEntityArrayList = new ArrayList<>();

                        for (int i = 0; i < sonDetailsDtoList.size(); i++) {
                            PassiveStorageSonDetailsDto passiveStorageSonDetailsDto = sonDetailsDtoList.get(i);

                            OfsPassiveorderDetailEntity ofsPassiveorderDetailEntity = new OfsPassiveorderDetailEntity();
                            ofsPassiveorderDetailEntity.setId(passiveStorageSonDetailsDto.getId());
                            ofsPassiveorderDetailEntity.setTransactionDate(passiveStorageSonDetailsDto.getRefundedAt());
                            ofsPassiveorderDetailEntity.setNewpushdate(getNewDateStr());
                            ofsPassiveorderDetailEntity.setNewtransmitinfo(finalNewTransmitInfo);
                            ofsPassiveorderDetailEntity.setNewstate(newstate);
                            if (successY.equals(newstate)) {
                                ofsPassiveorderDetailEntity.setNewsystemnumber(newsystemnumber);
                                ofsPassiveorderDetailEntity.setNewsystemprimary(newsystemprimary);
                            }

                            ofsPassiveorderDetailEntity.setDef1(passiveStorageSonDetailsDto.getCalculateAccountsReceivable());
                            ofsPassiveorderDetailEntity.setDef2(passiveStorageSonDetailsDto.getCalculationFormula());
                            ofsPassiveorderDetailEntity.setDef3(passiveStorageSonDetailsDto.getPlatformDiscounts());
                            ofsPassiveorderDetailEntity.setDef4(passiveStorageSonDetailsDto.getPayDiscounts());
                            ofsPassiveorderDetailEntity.setDef5(passiveStorageSonDetailsDto.getExpertDiscounts());
                            ofsPassiveorderDetailEntity.setDef6(passiveStorageSonDetailsDto.getMerchantDiscounts());

                            ofsPassiveorderDetailEntityArrayList.add(ofsPassiveorderDetailEntity);
                        }

                        //以50行为一个批次，推送到Mysql
                        if (ofsPassiveorderDetailEntityArrayList.size() > 0) {
                            List<List<OfsPassiveorderDetailEntity>> lists = SplitListByCountUtil.splitListByCount(ofsPassiveorderDetailEntityArrayList, 50);
                            for (int i = 0; i < lists.size(); i++) {
                                List<OfsPassiveorderDetailEntity> ofsPassiveorderDetailEntities = lists.get(i);
                                iOfsPassiveorderDetailDao.entityInsertOrUpdateBatchByStock(ofsPassiveorderDetailEntities);
                            }
                        }
                    }
                } catch (Exception e) {
                    logger.error("无源件日志同步，抛出异常", e);
                }
            }
        });
        thread.start();
        try {
            thread.join();
        } catch (Exception e) {
            logger.error("updateSuccessOrFail1方法现场抛出异常", e);
        }
    }

    /**
     * 处理TOC-库存同步的成功、失败错误逻辑
     *
     * @author liuyang
     */
    private void updateSuccessOrFail2(List<PassiveStorageSonDetailsDto> value, String newstate, String newTransmitInfo, String newsystemnumber, String newsystemprimary) {
        if (newTransmitInfo != null && !"".equals(newTransmitInfo.trim()) && newTransmitInfo.length() >= 400) {
            newTransmitInfo = newTransmitInfo.substring(0, 400);
        }

        String finalNewTransmitInfo = newTransmitInfo;
        Thread thread = new Thread(new Runnable() {
            @Override
            public void run() {
                try {
                    String successY = "Y";
                    if (value != null && value.size() > 0) {
                        List<OfsPassiveorderDetailEntity> ofsPassiveorderDetailEntityArrayList = new ArrayList<>();
                        for (int i = 0; i < value.size(); i++) {
                            PassiveStorageSonDetailsDto passiveStorageSonDetailsDto = value.get(i);

                            OfsPassiveorderDetailEntity ofsPassiveorderDetailEntity = new OfsPassiveorderDetailEntity();
                            ofsPassiveorderDetailEntity.setId(passiveStorageSonDetailsDto.getId());
                            ofsPassiveorderDetailEntity.setTransactionDate(passiveStorageSonDetailsDto.getRefundedAt());
                            ofsPassiveorderDetailEntity.setNewpushdate2(getNewDateStr());
                            ofsPassiveorderDetailEntity.setNewtransmitinfo2(finalNewTransmitInfo);
                            ofsPassiveorderDetailEntity.setNewstate2(newstate);
                            if (successY.equals(newstate)) {
                                ofsPassiveorderDetailEntity.setNewsystemnumber2(newsystemnumber);
                                ofsPassiveorderDetailEntity.setNewsystemprimary2(newsystemprimary);
                            }
                            ofsPassiveorderDetailEntity.setDef1(passiveStorageSonDetailsDto.getCalculateAccountsReceivable());
                            ofsPassiveorderDetailEntity.setDef2(passiveStorageSonDetailsDto.getCalculationFormula());
                            ofsPassiveorderDetailEntity.setDef3(passiveStorageSonDetailsDto.getPlatformDiscounts());
                            ofsPassiveorderDetailEntity.setDef4(passiveStorageSonDetailsDto.getPayDiscounts());
                            ofsPassiveorderDetailEntity.setDef5(passiveStorageSonDetailsDto.getExpertDiscounts());
                            ofsPassiveorderDetailEntity.setDef6(passiveStorageSonDetailsDto.getMerchantDiscounts());
                            ofsPassiveorderDetailEntityArrayList.add(ofsPassiveorderDetailEntity);
                        }

                        //以50行为一个批次，推送到Mysql
                        if (ofsPassiveorderDetailEntityArrayList.size() > 0) {
                            List<List<OfsPassiveorderDetailEntity>> lists = SplitListByCountUtil.splitListByCount(ofsPassiveorderDetailEntityArrayList, 50);
                            for (int i = 0; i < lists.size(); i++) {
                                List<OfsPassiveorderDetailEntity> ofsPassiveorderDetailEntities = lists.get(i);
                                iOfsPassiveorderDetailDao.entityInsertOrUpdateBatchByTran(ofsPassiveorderDetailEntities);
                            }
                        }
                    }
                } catch (Exception e) {
                    logger.error("TOC确认收入同步日志，抛出异常", e);
                }
            }
        });
        thread.start();
        try {
            thread.join();
        } catch (Exception e) {
            logger.error("updateSuccessOrFail1方法现场抛出异常", e);
        }
    }

    /**
     * 处理TOC-库存同步的成功、失败错误逻辑
     *
     * @param newstate         推送状态
     * @param newTransmitInfo  推送信息
     * @param newsystemnumber  下游系统单号
     * @param newsystemprimary 下游系统主键
     * @author liuyang
     */
    private void updateSuccessOrFail3(List<PassiveStorageSonDetailsDto2> value, String newstate, String newTransmitInfo, String newsystemnumber, String newsystemprimary) {
        if (newTransmitInfo != null && !"".equals(newTransmitInfo.trim()) && newTransmitInfo.length() >= 400) {
            newTransmitInfo = newTransmitInfo.substring(0, 400);
        }

        String finalNewTransmitInfo = newTransmitInfo;
        Thread thread = new Thread(new Runnable() {
            @Override
            public void run() {
                try {
                    String successY = "Y";
                    if (value != null && value.size() > 0) {
                        List<OnlyAfterSalesBEntity> onlyAfterSalesBEntityArrayList = new ArrayList<>();
                        for (int i = 0; i < value.size(); i++) {
                            PassiveStorageSonDetailsDto2 passiveStorageSonDetailsDto2 = value.get(i);

                            OnlyAfterSalesBEntity ofsPassiveorderDetailEntity = new OnlyAfterSalesBEntity();
                            ofsPassiveorderDetailEntity.setOfsid(passiveStorageSonDetailsDto2.getId());

                            ofsPassiveorderDetailEntity.setNewPushDate(getNewDateStr());
                            ofsPassiveorderDetailEntity.setNewTransmitInfo(finalNewTransmitInfo);
                            ofsPassiveorderDetailEntity.setNewState(newstate);
                            if (successY.equals(newstate) || (newsystemnumber != null && newsystemprimary != null)) {
                                ofsPassiveorderDetailEntity.setNewsystemnumber(newsystemnumber);
                                ofsPassiveorderDetailEntity.setNewsystemprimary(newsystemprimary);
                            }
                            ofsPassiveorderDetailEntity.setDef1(passiveStorageSonDetailsDto2.getCalculateAccountsReceivable());
                            ofsPassiveorderDetailEntity.setDef2(passiveStorageSonDetailsDto2.getCalculationFormula());
                            ofsPassiveorderDetailEntity.setDef3(passiveStorageSonDetailsDto2.getPlatformDiscounts());
                            ofsPassiveorderDetailEntity.setDef4(passiveStorageSonDetailsDto2.getPayDiscounts());
                            ofsPassiveorderDetailEntity.setDef5(passiveStorageSonDetailsDto2.getExpertDiscounts());
                            ofsPassiveorderDetailEntity.setDef6(passiveStorageSonDetailsDto2.getMerchantDiscounts());
                            onlyAfterSalesBEntityArrayList.add(ofsPassiveorderDetailEntity);
                        }

                        //以50行为一个批次，推送到Mysql
                        if (onlyAfterSalesBEntityArrayList.size() > 0) {
                            List<List<OnlyAfterSalesBEntity>> lists = SplitListByCountUtil.splitListByCount(onlyAfterSalesBEntityArrayList, 50);
                            for (int i = 0; i < lists.size(); i++) {
                                List<OnlyAfterSalesBEntity> onlyAfterSalesBEntityList = lists.get(i);
                                iOnlyAfterSalesBDao.entityInsertOrUpdateBatchBySuccessOrFail(onlyAfterSalesBEntityList);
                            }
                        }
                    }
                } catch (Exception e) {
                    logger.error("TOC确认收入同步日志，抛出异常", e);
                }
            }
        });
        thread.start();
        try {
            thread.join();
        } catch (Exception e) {
            logger.error("updateSuccessOrFail1方法现场抛出异常", e);
        }
    }

    /**
     * 过滤库存同步业务，筛选出未推送、或者失败的数据行，使用批处理并且直接在内存中计算这样比较高效
     *
     * @param tocofsReturngoodsDetailedEntityList     无源入库单推送状态信息
     * @param returnGoodHeaderDetailsDataDtoArrayList O 无源入库单对象封装
     * @author liuyang
     */
    private List<PassiveStorageResponse.Data> filterDataRowsAsPushOrFailedStock(List<OfsPassiveorderDetailEntity> tocofsReturngoodsDetailedEntityList, List<PassiveStorageResponse.Data> returnGoodHeaderDetailsDataDtoArrayList) throws Exception {
        List<PassiveStorageResponse.Data> targetHeaderDetailsDtoList = new ArrayList<>();

        if (returnGoodHeaderDetailsDataDtoArrayList != null && returnGoodHeaderDetailsDataDtoArrayList.size() > 0) {
            //如果推送状态为 null，则赋予""，便于 stream 计算
            List<OfsPassiveorderDetailEntity> resultList = tocofsReturngoodsDetailedEntityList.stream().map(obj -> {
                if (obj.getNewstate() == null) {
                    obj.setNewstate("");
                }
                return obj;
            }).collect(Collectors.toList());
            //汇总每个 id 对应的推送状态
            Map<String, String> no2NameMap = resultList.stream().collect(Collectors.toMap(OfsPassiveorderDetailEntity::getId, OfsPassiveorderDetailEntity::getNewstate));

            //字段Y(成功)或者为H(待处理)可以视为成功，完成了小段业务闭环的数据行
            String succeseeY = "Y";
            String succeseeH = "H";
            for (int i = 0; i < returnGoodHeaderDetailsDataDtoArrayList.size(); i++) {
                PassiveStorageResponse.Data data = returnGoodHeaderDetailsDataDtoArrayList.get(i);
                PassiveStorageResponse.Header header = data.getHeader();
                List<PassiveStorageResponse.Details> details = data.getDetails();

                List<PassiveStorageResponse.Details> targetDetails = new ArrayList<>();
                for (int j = 0; j < details.size(); j++) {
                    PassiveStorageResponse.Details details1 = details.get(j);
                    Boolean isSuccess = false;

                    String newstate = no2NameMap.get(details1.getId());
                    if (newstate != null && !"".equals(newstate) && (succeseeY.equals(newstate) || succeseeH.equals(newstate))) {
                        isSuccess = true;
                    }
                    if (!isSuccess) {
                        targetDetails.add(details1);
                    }
                }
                if (targetDetails.size() > 0) {
                    //如果明细行中，还存在未推送或者失败的数据，则需要更新明细行
                    //相当于覆盖对应的对象
                    data.setDetails(targetDetails);
                    targetHeaderDetailsDtoList.add(data);
                }
            }
        }
        return targetHeaderDetailsDtoList;
    }


    /**
     * 过滤掉成功的数据
     *
     * @param onlyAfterSalesBEntityArrayList  售后订单推送记录
     * @param rerturnGoodsOrderSearchDataList 售后订单明细行
     */
    private List<RerturnGoodsOrderSearchData> filterDataRowsAsPushOrFailedStock2(List<OnlyAfterSalesBEntity> onlyAfterSalesBEntityArrayList, List<RerturnGoodsOrderSearchData> rerturnGoodsOrderSearchDataList) throws Exception {
        List<RerturnGoodsOrderSearchData> targetHeaderDetailsDtoList = new ArrayList<>();

        if (rerturnGoodsOrderSearchDataList != null && rerturnGoodsOrderSearchDataList.size() > 0) {
            //如果推送状态为 null，则赋予""，便于 stream 计算
            List<OnlyAfterSalesBEntity> collect = onlyAfterSalesBEntityArrayList.stream().map(obj -> {
                if (obj.getNewState() == null) {
                    obj.setNewState("");
                }
                return obj;
            }).collect(Collectors.toList());
            //汇总每个 id 对应的推送状态
            Map<String, String> no2NameMap = collect.stream().collect(Collectors.toMap(OnlyAfterSalesBEntity::getOfsid, OnlyAfterSalesBEntity::getNewState));

            //字段Y(成功)或者为H(待处理)可以视为成功，完成了小段业务闭环的数据行
            String succeseeY = "Y";
            String succeseeH = "H";
            for (int i = 0; i < rerturnGoodsOrderSearchDataList.size(); i++) {
                RerturnGoodsOrderSearchData rerturnGoodsOrderSearchData = rerturnGoodsOrderSearchDataList.get(i);
                RerturnGoodsOrderSearchHeader header = rerturnGoodsOrderSearchData.getHeader();
                List<RerturnGoodsOrderSearchDetails> details = rerturnGoodsOrderSearchData.getDetails();

                List<RerturnGoodsOrderSearchDetails> targetDetails = new ArrayList<>();
                for (int j = 0; j < details.size(); j++) {
                    RerturnGoodsOrderSearchDetails rerturnGoodsOrderSearchDetails = details.get(j);
                    Boolean isSuccess = false;

                    String newstate = no2NameMap.get(rerturnGoodsOrderSearchDetails.getId());
                    if (newstate != null && !"".equals(newstate) && (succeseeY.equals(newstate) || succeseeH.equals(newstate))) {
                        isSuccess = true;
                    }
                    if (!isSuccess) {
                        targetDetails.add(rerturnGoodsOrderSearchDetails);
                    }
                }
                if (targetDetails.size() > 0) {
                    //如果明细行中，还存在未推送或者失败的数据，则需要更新明细行
                    //相当于覆盖对应的对象
                    rerturnGoodsOrderSearchData.setDetails(targetDetails);
                    targetHeaderDetailsDtoList.add(rerturnGoodsOrderSearchData);
                }
            }
        }
        return targetHeaderDetailsDtoList;
    }

    /**
     * 筛选出未推送、或者失败的数据行，过滤库存同步业务
     *
     * @param ofsPassiveorderDetailEntityList        无源入库单日志行状态
     * @param passiveStorageResponseDataDtoArrayList O无源入库单对象
     * @author liuyang
     */
    private List<PassiveStorageResponse.Data> filterDataRowsAsPushOrFailedTran(List<OfsPassiveorderDetailEntity> ofsPassiveorderDetailEntityList, List<PassiveStorageResponse.Data> passiveStorageResponseDataDtoArrayList) throws Exception {
        Assert.notNull(ofsPassiveorderDetailEntityList, "tocofsReturngoodsDetailedEntityList不能为空");
        Assert.notNull(passiveStorageResponseDataDtoArrayList, "returnGoodHeaderDetailsDataDtoArrayList不能为空");

        List<PassiveStorageResponse.Data> passiveStorageResponseData = new ArrayList<>();
        if (ofsPassiveorderDetailEntityList != null && passiveStorageResponseDataDtoArrayList != null) {
            List<OfsPassiveorderDetailEntity> collect = ofsPassiveorderDetailEntityList.stream().map(obj -> {
                if (obj.getNewstate2() == null) {
                    obj.setNewstate2("");
                }
                return obj;
            }).collect(Collectors.toList());
            Map<String, String> no2NameMap2 = collect.stream().collect(Collectors.toMap(OfsPassiveorderDetailEntity::getId, OfsPassiveorderDetailEntity::getNewstate2));

            //字段Y(成功)或者为H(待处理)可以视为成功，完成了小段业务闭环的数据行
            String succeseeY = "Y";
            String succeseeH = "H";
            for (int i = 0; i < passiveStorageResponseDataDtoArrayList.size(); i++) {
                PassiveStorageResponse.Data data = passiveStorageResponseDataDtoArrayList.get(i);
                PassiveStorageResponse.Header header = data.getHeader();
                List<PassiveStorageResponse.Details> details = data.getDetails();

                List<PassiveStorageResponse.Details> targetDetails = new ArrayList<>();
                for (int j = 0; j < details.size(); j++) {
                    PassiveStorageResponse.Details details1 = details.get(j);
                    Boolean isSuccess = false;
                    String newstate = null;
//                    for (int k = 0; k < tocofsReturngoodsDetailedEntityList.size(); k++) {
//                        TocofsReturngoodsDetailedEntity tocofsReturngoodsDetailedEntity = tocofsReturngoodsDetailedEntityList.get(k);
//                        if (tocofsReturngoodsDetailedEntity.getId().equals(stockinB.getId())) {
//                            newstate = tocofsReturngoodsDetailedEntity.getNewstate4();
//                            if (succeseeY.equals(newstate) || succeseeH.equals(newstate)) {
//                                isSuccess = true;
//                            }
//                        }
//                    }
                    newstate = no2NameMap2.get(details1.getId());
                    if (newstate != null && !"".equals(newstate) && (succeseeY.equals(newstate) || succeseeH.equals(newstate))) {
                        isSuccess = true;
                    }
                    if (!isSuccess) {
                        targetDetails.add(details1);
                    }
                }
                if (targetDetails.size() > 0) {
                    //如果明细行中，还存在未推送或者失败的数据，则需要更新明细行
                    data.setDetails(targetDetails);
                    passiveStorageResponseData.add(data);
                }
            }
        }
        return passiveStorageResponseData;
    }

    /**
     * 计算时间间隔
     *
     * @author liuyang
     */
    public String computingTime(String param) {
        if (param != null && !"".equals(param)) {
            String[] split = param.split("/");
            if (!(split.length == 2)) {
                Assert.state(false, "传递的日期格式不完整 格式参考：2024-04-01/2024-04-30");
            }

            LocalDate startDate = LocalDate.parse(split[0]);
            LocalDate endDate = LocalDate.parse(split[1]);

            List<String> stringArrayList = new ArrayList<>();
            List<String> dateRange = getDateRange(startDate, endDate);
            if (dateRange != null && dateRange.size() > 0) {
                for (int i = 0; i < dateRange.size(); i++) {
                    String dateStr = dateRange.get(i);
                    StringBuffer stringBuffer = new StringBuffer();
                    stringBuffer.append(dateStr);
                    stringBuffer.append(" 00:00:00");
                    stringBuffer.append(",");
                    stringBuffer.append(dateStr);
                    stringBuffer.append(" 23:59:59");
                    stringArrayList.add(stringBuffer.toString());
                }
            }
            String collectDateStr = stringArrayList.stream().collect(Collectors.joining("*"));
            logger.info("类型：time_frame 生成的日期范围：" + collectDateStr);
            return collectDateStr;
        }
        return null;
    }

    /**
     * 分割日期之后，再进行推送
     *
     * @author liuyang
     */
    public void splitDateAndPush(String param, String sceneType) throws Exception {
        try {
            Assert.notNull(param, "param不能为空!");
            Assert.state(!"".equals(param), "param不能为空！");

            Assert.notNull(sceneType, "sceneType不能为空！");
            Assert.state(!"".equals(sceneType), "sceneType不能为空！");

//            Assert.notNull(pushScenarioType, "pushScenarioType不能为空！");
//            Assert.state(!"".equals(pushScenarioType), "pushScenarioType不能为空！");

            if (param.contains("*")) {
                String[] params = param.split("\\*");
                if (params.length > 0) {
                    for (int i = 0; i < params.length; i++) {
                        String indexStr = params[i];
                        String[] split = indexStr.split(",");
                        logger.info("splitDateAndPush方法正在执行主要的逻辑 开始时间：{} 结束时间：{}", split[0], split[1]);
                        if (sceneType.equals(STOCK)) {
                            startImplementStockByTime(split[0], split[1]);
                        } else if (sceneType.equals(TRAN)) {
                            startImplementByTradeTime(split[0], split[1]);
                        }
                    }
                }
            } else {
                String[] split = param.split(",");
                logger.info("splitDateAndPush方法正在执行主要的逻辑 开始时间：{} 结束时间：{}", split[0], split[1]);
                if (sceneType.equals(STOCK)) {
                    startImplementStockByTime(split[0], split[1]);
                } else if (sceneType.equals(TRAN)) {
                    startImplementByTradeTime(split[0], split[1]);
                }
            }
        } catch (Exception e) {
            logger.error("记录splitDateAndPush方法抛出的异常", e);
        }
    }

    /**
     * 计算全天时间段
     *
     * @author liuyang
     */
    public List<StartAndEndVo> calculateCalculateEntireDayPeriod(String dateStr) {
        List<StartAndEndVo> startAndEnd = new ArrayList<>();

        String calculateYesterdayStr = null;
        if (dateStr != null) {
            calculateYesterdayStr = dateStr;
        } else {
            calculateYesterdayStr = calculateYesterdayDate();//拉取'昨天'的日期
        }
        logger.info("OFS销售出库单同步U8C销售订单，目标拉取时间：" + calculateYesterdayStr);

        StartAndEndVo startAndEndVo = new StartAndEndVo();
        startAndEndVo.setStart_time(calculateYesterdayStr + " 00:00:00");
        startAndEndVo.setEnd_time(calculateYesterdayStr + " 23:59:59");
        startAndEnd.add(startAndEndVo);

//        for (int i = 0; i <= 23; i++) {
//            String iStr = null;
//            if (i <= 9) {
//                iStr = "0" + i;
//            } else {
//                iStr = String.valueOf(i);
//            }
//            String startTime = calculateYesterdayStr + " " + iStr + ":00:00";
//            String endTime = calculateYesterdayStr + " " + iStr + ":59:59";
//
//            StartAndEndVo startAndEndVo = new StartAndEndVo();
//            startAndEndVo.setStart_time(startTime);
//            startAndEndVo.setEnd_time(endTime);
//            startAndEnd.add(startAndEndVo);
//        }
        return startAndEnd;
    }

    /**
     * 计算昨天的单据日期，基于定时器在凌晨5分执行的情况下
     *
     * @author liuyang
     */
    public String calculateYesterdayDate() {
        DateTime yesterdayDate = DateUtil.yesterday();
        return DateUtil.format(yesterdayDate, "yyyy-MM-dd");
    }

    /**
     * 计算时间范围对应的字符串集合
     *
     * @author liuyang
     */
    private List<String> getDateRange(LocalDate startDate, LocalDate endDate) {
        List<String> dateRange = new ArrayList<>();
        LocalDate currentDate = startDate;
        while (!currentDate.isAfter(endDate)) {
            dateRange.add(currentDate.format(DateTimeFormatter.ISO_DATE));
            currentDate = currentDate.plusDays(1);
        }
        return dateRange;
    }

    /**
     * 累加平台优惠
     *
     * @param sonDetailsDtoList OFS售后入库单
     * @author liuyang
     */
//    private void accumulationDiscountAmount(List<GoodsRertunSonDetailsDto> sonDetailsDtoList) throws Exception {
//        Assert.notNull(sonDetailsDtoList, "sonDetailsDtoList不能为空");
//
//        if (sonDetailsDtoList.size() > 0) {
//            BigDecimal totalShareTargetPlatformDiscounts = new BigDecimal("0");
//            BigDecimal totalShareTargetMerchantDiscounts = new BigDecimal("0");
//            BigDecimal totalShareTargetExpertDiscounts = new BigDecimal("0");
//            BigDecimal totalShareTargetPayDiscounts = new BigDecimal("0");
//
//            for (int i = 0; i < sonDetailsDtoList.size(); i++) {
//                //OFS售后入库单表体
//                GoodsRertunSonDetailsDto goodsRertunSonDetailsDto = sonDetailsDtoList.get(i);
//                //OFS售后入库单表头
//                StockinOrderSearchResponse.StockinOrder.StockinH header1 = goodsRertunSonDetailsDto.getHeader();
//                Assert.notNull(header1, "OFS售后入库单表头不能为空！");
//                //OFS售后订单
//                RerturnGoodsOrderSearchData rerturnGoodsOrderSearchData = header1.getRerturnGoodsOrderSearchData();
//                Assert.notNull(rerturnGoodsOrderSearchData, "通过OFS售后入库单号无法关联批量到OFS售后订单！ OFS售后入库单编码：{} OFS售后订单号：{}", header1.getCode(), header1.getRefOrderCode());
//                RerturnGoodsOrderSearchHeader header = rerturnGoodsOrderSearchData.getHeader();
//                List<RerturnGoodsOrderSearchDetails> details = rerturnGoodsOrderSearchData.getDetails();
//
//                //四舍五入保留2位
//                RerturnGoodsOrderSearchDetails ofsOrderDetail = findOfsOrderDetail(details, goodsRertunSonDetailsDto);
//                if (ofsOrderDetail.getShareTargetPlatformDiscounts() != null) {
//                    totalShareTargetPlatformDiscounts = totalShareTargetPlatformDiscounts.add(ofsOrderDetail.getShareTargetPlatformDiscounts());
//                }
//                if (ofsOrderDetail.getShareTargetMerchantDiscounts() != null) {
//                    totalShareTargetMerchantDiscounts = totalShareTargetMerchantDiscounts.add(ofsOrderDetail.getShareTargetMerchantDiscounts());
//                }
//                if (ofsOrderDetail.getShareTargetExpertDiscounts() != null) {
//                    totalShareTargetExpertDiscounts = totalShareTargetExpertDiscounts.add(ofsOrderDetail.getShareTargetExpertDiscounts());
//                }
//                if (ofsOrderDetail.getShareTargetPayDiscounts() != null) {
//                    totalShareTargetPayDiscounts = totalShareTargetPayDiscounts.add(ofsOrderDetail.getShareTargetPayDiscounts());
//                }
//                logger.info("对应的售后入库单明细行主键：{}", goodsRertunSonDetailsDto.getId());
//            }
//
//            GoodsRertunSonDetailsDto goodsRertunSonDetailsDto = sonDetailsDtoList.get(0);
//            StockinOrderSearchResponse.StockinOrder.StockinH header = goodsRertunSonDetailsDto.getHeader();
//
//            goodsRertunSonDetailsDto.setVdef4(totalShareTargetPlatformDiscounts.setScale(2, BigDecimal.ROUND_HALF_UP));
//            goodsRertunSonDetailsDto.setVdef5(totalShareTargetMerchantDiscounts.setScale(2, BigDecimal.ROUND_HALF_UP));
//            goodsRertunSonDetailsDto.setVdef6(totalShareTargetExpertDiscounts.setScale(2, BigDecimal.ROUND_HALF_UP));
//            goodsRertunSonDetailsDto.setVdef7(totalShareTargetPayDiscounts.setScale(2, BigDecimal.ROUND_HALF_UP));
//
//            logger.info("售后入库明细主键：{} 售后入库单号：{} 最终汇总好的平台优惠：{}、支付优惠：{}、达人优惠：{}、商家优惠：{}", goodsRertunSonDetailsDto.getId(), header.getCode(), goodsRertunSonDetailsDto.getVdef4(), goodsRertunSonDetailsDto.getVdef5(), goodsRertunSonDetailsDto.getVdef6(), goodsRertunSonDetailsDto.getVdef7());
//        } else {
//            logger.info("accumulationDiscountAmount方法对应的sonDetailsDtoList.size为零！");
//        }
//    }

    /**
     * 根据OFS售后入库单明细行，查找匹配OFS售后订单明细行
     *
     * @param details                  OFS售后订单明细行
     * @param goodsRertunSonDetailsDto OFS售后入库单明细对象
     * @author liuyang
     */
    private RerturnGoodsOrderSearchDetails findOfsOrderDetail(List<RerturnGoodsOrderSearchDetails> details, PassiveStorageSonDetailsDto goodsRertunSonDetailsDto) {
        Assert.notNull(details, "details不能为空");
        Assert.notNull(goodsRertunSonDetailsDto, "goodsRertunSonDetailsDto不能为空");

        for (int i = 0; i < details.size(); i++) {
            RerturnGoodsOrderSearchDetails rerturnGoodsOrderSearchDetails = details.get(i);
            if (goodsRertunSonDetailsDto.getSkuCode() != null && rerturnGoodsOrderSearchDetails.getSkuCode() != null) {
                if (goodsRertunSonDetailsDto.getSkuCode().equals(rerturnGoodsOrderSearchDetails.getSkuCode())) {
                    return rerturnGoodsOrderSearchDetails;
                }
            }
        }
//        Assert.state(false, "根据OFS售后入库单明细行，无法查找OFS售后订单明细行 来源明细行主键：{} 来源单据主键：{}", goodsRertunSonDetailsDto.getRefOrderDetailId(), goodsRertunSonDetailsDto.getRefOrderId());
//        Assert.state(false, "无源入库单明细行存货 sku：{} 名称：{} 无法匹配售后订单明细行 sku", goodsRertunSonDetailsDto.getSkuCode(), goodsRertunSonDetailsDto.getSkuName());
        return null;
    }

    /**
     * 初始化所有存货管理档案对应的结存价、采购价
     *
     * @author liuyang
     */
//    private List<Map> initAllBalancePricePurchasePrice() throws Exception {
//        List<Map> mapList = new ArrayList<>();
//        Map<String, IaPeriodaccountEntity> stringIaPeriodaccountEntityMap = balanceUnitPriceUtil.initBalancePrice();
//        Map<String, PoOrderBEntity> stringPoOrderBEntityMap = balanceUnitPriceUtil.initPurchasePrice();
//        mapList.add(stringIaPeriodaccountEntityMap);
//        mapList.add(stringPoOrderBEntityMap);
//        return mapList;
//    }

    /**
     * 获取结存金额或者采购金额
     *
     * @param isCheckShopChoose true取OFS实付金额、false取结存金额或者采购价
     * @param bdInvmandocEntity 存货基本档案
     * @param header            对应的销售入库单表头
     * @param sonDetailsDto     对应的销售入库单明细行对象
     * @param mapList           索引为0结存价为1采购价
     * @author liuyang
     */
//    private String getFloorPrice(Boolean isCheckShopChoose, BdInvmandocEntity bdInvmandocEntity, StockinOrderSearchResponse.StockinOrder.StockinH header, GoodsRertunSonDetailsDto sonDetailsDto, List<Map> mapList, StringBuffer calculationFormulaStr) throws Exception {
//        Assert.notNull(isCheckShopChoose, "isCheckShopChoose不能为空");
//        Assert.notNull(bdInvmandocEntity, "bdInvmandocEntity不能为空");
//        Assert.notNull(header, "header不能为空");
//        Assert.notNull(sonDetailsDto, "detailsDto不能为空");
//        Assert.notNull(mapList, "mapList不能为空");
//        Assert.notNull(calculationFormulaStr, "calculationFormulaStr不能为空");
//
//        //此处只能为金额
//        String totalPayAmount = null;
//        if (isCheckShopChoose) {
//            IaPeriodaccountEntity iaPeriodaccountEntity1 = null;
//            if (mapList != null && mapList.size() > 0) {
//                Map<String, IaPeriodaccountEntity> stringIaPeriodaccountEntityMap = (Map<String, IaPeriodaccountEntity>) mapList.get(0);
//                iaPeriodaccountEntity1 = stringIaPeriodaccountEntityMap.get(bdInvmandocEntity.getPkInvmandoc());
//            }
//            if (iaPeriodaccountEntity1 != null) {
//                //取结存价
//                logger.info("店铺：{} 取O结存价", header.getStoreCode());
//                calculationFormulaStr.append("取结存价:");
//
//                //结存金额
//                String nabmny = iaPeriodaccountEntity1.getNabmny();
//                if (nabmny == null || "".equals(nabmny)) {
//                    nabmny = "0";
//                }
//                BigDecimal nabmnyBigDecimal = new BigDecimal(nabmny);
//
//                //结存数量
//                String nabnum = iaPeriodaccountEntity1.getNabnum();
//                if (nabnum == null || "".equals(nabnum)) {
//                    nabnum = "0";
//                }
//                BigDecimal nabnumBigDecimal = new BigDecimal(nabnum);
//
//                if (!"0".equals(nabmnyBigDecimal.stripTrailingZeros().toPlainString()) && !"0".equals(nabnumBigDecimal.stripTrailingZeros().toPlainString())) {
//                    String format = StrUtil.format("{}/{}*{}", nabmnyBigDecimal.stripTrailingZeros().toPlainString(), nabnumBigDecimal.stripTrailingZeros().toPlainString(), sonDetailsDto.getReceivedQty());
//                    calculationFormulaStr.append(format);
//                    BigDecimal bigDecimal = nabmnyBigDecimal.divide(nabnumBigDecimal, 20, BigDecimal.ROUND_HALF_UP);
//                    BigDecimal totalPayAmountBigDecimal = bigDecimal.multiply(new BigDecimal(sonDetailsDto.getReceivedQty())).setScale(2, BigDecimal.ROUND_HALF_UP);
//                    totalPayAmount = totalPayAmountBigDecimal.stripTrailingZeros().toPlainString();
//                } else {
//                    //如果结存金额为或者数量为0，则设置为0
//                    calculationFormulaStr.append("0");
//                    totalPayAmount = "0";
//                }
//            } else {
//                //取采购价
//                logger.info("店铺：{} 取O采购价", header.getStoreCode());
//                calculationFormulaStr.append("取采购价:");
//                PoOrderBEntity poOrderBEntity = null;
//                if (mapList != null && mapList.size() > 0) {
//                    Map<String, PoOrderBEntity> poOrderBEntityList = (Map<String, PoOrderBEntity>) mapList.get(1);
//                    if (poOrderBEntityList != null && poOrderBEntityList.size() > 0) {
//                        poOrderBEntity = poOrderBEntityList.get(bdInvmandocEntity.getPkInvmandoc());
//                    }
//                }
//                if (poOrderBEntity != null) {
//                    String norgtaxprice = poOrderBEntity.getNorgtaxprice();
//                    Assert.notNull(norgtaxprice, "U8C采购订单明细行存在「原币含税单价」为空");
//                    if (norgtaxprice != null && !"0".equals(new BigDecimal(norgtaxprice).stripTrailingZeros().toPlainString())) {
//                        String format = StrUtil.format("{}*{}", norgtaxprice, sonDetailsDto.getReceivedQty());
//                        calculationFormulaStr.append(format);
//                        BigDecimal totalPayAmountBigDecimal = new BigDecimal(norgtaxprice).multiply(new BigDecimal(sonDetailsDto.getReceivedQty())).setScale(2, BigDecimal.ROUND_HALF_UP);
//                        totalPayAmount = totalPayAmountBigDecimal.stripTrailingZeros().toPlainString();
//                    } else {
//                        //如果采购单价都为0，那么金额也为0
//                        totalPayAmount = "0";
//                        calculationFormulaStr.append("0");
//                    }
//                } else {
//                    Assert.state(false, "店铺：{} 存货管理档案主键：{} 既没有结存价、也没有采购价！", header.getStoreCode(), bdInvmandocEntity.getPkInvmandoc());
//                }
//            }
//        }
//        return totalPayAmount;
//    }

    /**
     * 累加应收金额=实退金额+达人优惠+支付优惠+平台优惠
     *
     * @param passiveStorageSonDetailsDto O无源入库单
     * @param rerturnGoodsOrderSearchData OFS售后订单
     * @param calculationFormulaStr       计算公式
     * @author liuyang
     */
    private String accumulatedDiscounts(PassiveStorageSonDetailsDto passiveStorageSonDetailsDto, RerturnGoodsOrderSearchData rerturnGoodsOrderSearchData, StringBuffer calculationFormulaStr) throws Exception {
        Assert.notNull(passiveStorageSonDetailsDto, "goodsRertunSonDetailsDto OFS售后入库单明细行不能为空！");
        Assert.notNull(rerturnGoodsOrderSearchData, "rerturnGoodsOrderSearchData OFS售后订单不能为空！");
        Assert.notNull(calculationFormulaStr, "calculationFormulaStr不能为空！");

        //O 无源入库单表头
        PassiveStorageResponse.Header header1 = passiveStorageSonDetailsDto.getHeader();

        //O售后订单表头、明细行
        RerturnGoodsOrderSearchHeader header = rerturnGoodsOrderSearchData.getHeader();
        List<RerturnGoodsOrderSearchDetails> details = rerturnGoodsOrderSearchData.getDetails();

        //根据「入库单明细」匹配「售后订单明细行」
        RerturnGoodsOrderSearchDetails targetDetails = null;
        for (int i = 0; i < details.size(); i++) {
            RerturnGoodsOrderSearchDetails rerturnGoodsOrderSearchDetails = details.get(i);
            if (passiveStorageSonDetailsDto.getSkuCode() != null && rerturnGoodsOrderSearchDetails.getSkuCode() != null) {
                if (passiveStorageSonDetailsDto.getSkuCode().equals(rerturnGoodsOrderSearchDetails.getSkuCode())) {
                    targetDetails = rerturnGoodsOrderSearchDetails;
                }
            }
        }
//        Assert.notNull(targetDetails, "根据OFS无源入库单单细行(sku匹配)无法匹配售后订单明细行", passiveStorageSonDetailsDto.getSkuCode());

        if (targetDetails != null) {
            //售后订单明细行-退货金额
            String totalAmount = targetDetails.getTotalAmount();//实退金额
            Assert.notNull(totalAmount, "售后订单：{} 存货明细行：{} 退货金额不能为空！", header.getCode(), targetDetails.getSkuCode());
            Assert.state(!"".equals(totalAmount), "售后订单：{} 存货明细行：{} 退货金额不能为空！", header.getCode(), targetDetails.getSkuCode());
            //售后订单明细行-请求数量
            //实退数量存在可能为0的情况，如果用退货金额/实退数量可能会抛出异常
            String requestQty = targetDetails.getRequestQty();//请求数量
            Assert.notNull(requestQty, "售后订单：{} 存货明细行：{} 请求数量不能为空！", header.getCode(), targetDetails.getSkuCode());
            Assert.state(!"".equals(requestQty), "售后订单：{} 存货明细行：{} 请求数量不能为空！", header.getCode(), targetDetails.getSkuCode());

            String quantity = passiveStorageSonDetailsDto.getQuantity();
            Assert.notNull(quantity, "无源入库单：{} sku：{} 实退数量不能为空", passiveStorageSonDetailsDto.getQuantity(), passiveStorageSonDetailsDto.getSkuName());
            Assert.state(!"".equals(quantity), "无源入库单：{} sku：{} 实退数量不能为空", passiveStorageSonDetailsDto.getQuantity(), passiveStorageSonDetailsDto.getSkuName());
            if ("0".equals(new BigDecimal(quantity).stripTrailingZeros().toPlainString())) {
                Assert.state(false, "无源入库单：{} sku：{} 实退数量不能为0！", passiveStorageSonDetailsDto.getQuantity(), passiveStorageSonDetailsDto.getSkuName());
            }

            //O含税单价=通过退货金额/请求数量
            BigDecimal unitPriceIncludingTax = new BigDecimal(totalAmount).divide(new BigDecimal(requestQty), 20, BigDecimal.ROUND_HALF_UP);
            //实退金额=O含税单价*（O售后入库单）实退数量
            BigDecimal actualRefundAmount = unitPriceIncludingTax.multiply(new BigDecimal(quantity)).setScale(4, BigDecimal.ROUND_HALF_UP);
            String format = StrUtil.format("{}/{}*{}", totalAmount, requestQty, quantity);
            calculationFormulaStr.append(format);
            return actualRefundAmount.stripTrailingZeros().toPlainString();
        } else {
            //2025年4月18日11:06:04 如果无源入库单明细行无法匹配售后订单明细行，则金额为0即可
            return "0";
        }
    }

    /**
     * 汇总好之后，相同的 sku，累加优惠金额，放在自定义项里最后传给U8C
     *
     * @param sonDetailsDtoList OFS售后入库单明细行List集合(按纬度汇总好的)
     * @author liuyang
     */
    private void accumulatedDiscountAmountDef(List<PassiveStorageSonDetailsDto> sonDetailsDtoList) throws Exception {
        Assert.notNull(sonDetailsDtoList, "sonDetailsDtoList不能为空");

        if (sonDetailsDtoList.size() > 0) {
            BigDecimal platformDiscountsBigDecimal = new BigDecimal("0");//平台
            BigDecimal merchantDiscountsBigDecimal = new BigDecimal("0");//商家
            BigDecimal expertDiscountsBigDecimal = new BigDecimal("0");//达人
            BigDecimal payDiscountsBigDecimal = new BigDecimal("0");//支付

            for (int i = 0; i < sonDetailsDtoList.size(); i++) {
                PassiveStorageSonDetailsDto passiveStorageSonDetailsDto = sonDetailsDtoList.get(i);
                PassiveStorageResponse.Header header = passiveStorageSonDetailsDto.getHeader();//O无源入库单表头
                RerturnGoodsOrderSearchData rerturnGoodsOrderSearchData = header.getRerturnGoodsOrderSearchData();//OFS售后订单
                Assert.notNull(rerturnGoodsOrderSearchData, "O售后订单不能为空！");
                List<RerturnGoodsOrderSearchDetails> details = rerturnGoodsOrderSearchData.getDetails();//OFS售后订单明细行

                if (details != null && details.size() > 0) {
                    for (int j = 0; j < details.size(); j++) {
                        RerturnGoodsOrderSearchDetails rerturnGoodsOrderSearchDetails = details.get(j);
                        if (passiveStorageSonDetailsDto.getSkuCode() != null && rerturnGoodsOrderSearchDetails.getSkuCode() != null) {
                            if (passiveStorageSonDetailsDto.getSkuCode().equals(rerturnGoodsOrderSearchDetails.getSkuCode())) {
                                //累加优惠
                                String platformDiscounts = rerturnGoodsOrderSearchDetails.getPlatformDiscounts();
                                String merchantDiscounts = rerturnGoodsOrderSearchDetails.getMerchantDiscounts();
                                String expertDiscounts = rerturnGoodsOrderSearchDetails.getExpertDiscounts();
                                String payDiscounts = rerturnGoodsOrderSearchDetails.getPayDiscounts();

                                if (platformDiscounts == null || "".equals(platformDiscounts.trim())) {
                                    platformDiscounts = "0";
                                }
                                if (merchantDiscounts == null || "".equals(merchantDiscounts.trim())) {
                                    merchantDiscounts = "0";
                                }
                                if (expertDiscounts == null || "".equals(expertDiscounts.trim())) {
                                    expertDiscounts = "0";
                                }
                                if (payDiscounts == null || "".equals(payDiscounts.trim())) {
                                    payDiscounts = "0";
                                }

                                platformDiscountsBigDecimal = platformDiscountsBigDecimal.add(new BigDecimal(platformDiscounts));
                                merchantDiscountsBigDecimal = merchantDiscountsBigDecimal.add(new BigDecimal(merchantDiscounts));
                                expertDiscountsBigDecimal = expertDiscountsBigDecimal.add(new BigDecimal(expertDiscounts));
                                payDiscountsBigDecimal = payDiscountsBigDecimal.add(new BigDecimal(payDiscounts));
                            }
                        }
                    }
                }
            }
            sonDetailsDtoList.get(0).setVdef4(platformDiscountsBigDecimal);//平台
            sonDetailsDtoList.get(0).setVdef5(payDiscountsBigDecimal);//支付
            sonDetailsDtoList.get(0).setVdef6(expertDiscountsBigDecimal);//达人
            sonDetailsDtoList.get(0).setVdef7(merchantDiscountsBigDecimal);//商家
        }
    }

    private void accumulatedDiscountAmountDef2(List<PassiveStorageSonDetailsDto2> sonDetailsDtoList) throws Exception {
        Assert.notNull(sonDetailsDtoList, "sonDetailsDtoList不能为空");

        if (sonDetailsDtoList.size() > 0) {
            BigDecimal platformDiscountsBigDecimal = new BigDecimal("0");//平台
            BigDecimal merchantDiscountsBigDecimal = new BigDecimal("0");//商家
            BigDecimal expertDiscountsBigDecimal = new BigDecimal("0");//达人
            BigDecimal payDiscountsBigDecimal = new BigDecimal("0");//支付

            for (int i = 0; i < sonDetailsDtoList.size(); i++) {
                PassiveStorageSonDetailsDto2 passiveStorageSonDetailsDto2 = sonDetailsDtoList.get(i);

                //累加优惠
                String platformDiscounts = passiveStorageSonDetailsDto2.getPlatformDiscounts();
                String merchantDiscounts = passiveStorageSonDetailsDto2.getMerchantDiscounts();
                String expertDiscounts = passiveStorageSonDetailsDto2.getExpertDiscounts();
                String payDiscounts = passiveStorageSonDetailsDto2.getPayDiscounts();

                if (platformDiscounts == null || "".equals(platformDiscounts.trim())) {
                    platformDiscounts = "0";
                }
                if (merchantDiscounts == null || "".equals(merchantDiscounts.trim())) {
                    merchantDiscounts = "0";
                }
                if (expertDiscounts == null || "".equals(expertDiscounts.trim())) {
                    expertDiscounts = "0";
                }
                if (payDiscounts == null || "".equals(payDiscounts.trim())) {
                    payDiscounts = "0";
                }

                platformDiscountsBigDecimal = platformDiscountsBigDecimal.add(new BigDecimal(platformDiscounts));
                merchantDiscountsBigDecimal = merchantDiscountsBigDecimal.add(new BigDecimal(merchantDiscounts));
                expertDiscountsBigDecimal = expertDiscountsBigDecimal.add(new BigDecimal(expertDiscounts));
                payDiscountsBigDecimal = payDiscountsBigDecimal.add(new BigDecimal(payDiscounts));
            }
            sonDetailsDtoList.get(0).setVdef4(platformDiscountsBigDecimal);//平台
            sonDetailsDtoList.get(0).setVdef5(payDiscountsBigDecimal);//支付
            sonDetailsDtoList.get(0).setVdef6(expertDiscountsBigDecimal);//达人
            sonDetailsDtoList.get(0).setVdef7(merchantDiscountsBigDecimal);//商家
        }
    }

    /**
     * 获取参考售价，这里算的其实是金额
     *
     * @param bdInvmandocEntity           存货管理档案
     * @param bdInvbasdocEntity           存货基本档案
     * @param calculationFormulaStr       计算公式
     * @param passiveStorageSonDetailsDto O 无源入库单
     * @author liuyang
     */
    private String getRefsaleprice(BdInvmandocEntity bdInvmandocEntity, BdInvbasdocEntity bdInvbasdocEntity, StringBuffer calculationFormulaStr, PassiveStorageSonDetailsDto passiveStorageSonDetailsDto, PassiveStorageSonDetailsDto2 passiveStorageSonDetailsDto2) throws Exception {
        Assert.notNull(bdInvmandocEntity, "bdInvmandocEntity不能为空!");
        Assert.notNull(bdInvbasdocEntity, "bdInvbasdocEntity不能为空!");
        Assert.notNull(calculationFormulaStr, "calculationFormulaStr不能为空！");
//        Assert.notNull(passiveStorageSonDetailsDto, "passiveStorageSonDetailsDto不能为空！");
//        Assert.notNull(header, "header不能为空");

        //U参考售价
        String refsaleprice = bdInvmandocEntity.getRefsaleprice();
        Assert.notNull(refsaleprice, "存货：{} 公司：{} 不存在参考售价，请维护！", bdInvbasdocEntity.getInvname(), bdInvmandocEntity.getPkCorp());

        //O无源入库单实收数量
        String receivedQty = null;
        if (passiveStorageSonDetailsDto != null) {
            receivedQty = passiveStorageSonDetailsDto.getQuantity();
            Assert.notNull(receivedQty, "O实收数量不能为空 O 无源入库单编码：{}", passiveStorageSonDetailsDto.getReceiptCode());
            Assert.state(!"".equals(receivedQty), "O实收数量不能为空 O 无源入库单编码：{}", passiveStorageSonDetailsDto.getReceiptCode());
        } else {
            receivedQty = passiveStorageSonDetailsDto2.getRequestQty();
        }

        BigDecimal amountOfMoney = new BigDecimal(refsaleprice).multiply(new BigDecimal(receivedQty));
        String format = StrUtil.format("取U参考售价：{}*{}", refsaleprice, receivedQty);
        calculationFormulaStr.append(format);
        return amountOfMoney.stripTrailingZeros().toPlainString();
    }

    /**
     * 查询OFS底表的O售后入库单数据
     *
     * @author liuyang
     */
//    public List<StockinOrderSearchResponse.StockinOrder> queryTocofsReturngoodsDetailed(TocofsReturngoodsDetailedEntity tocofsReturngoodsDetailedEntity) throws Exception {
//        Assert.notNull(tocofsReturngoodsDetailedEntity, "tocofsReturngoodsDetailedEntity不能为空");
//
//        //底表O售后入库单表头对象
//        List<TocofsReturngoodsEntity> allTocofsReturngoodsEntityList = new ArrayList<>();
//        //底表O售后入库单明细行
//        List<TocofsReturngoodsDetailedEntity> tocofsReturngoodsDetailedEntityList = iTocofsReturngoodsDetailedDao.query(tocofsReturngoodsDetailedEntity);
//        if (tocofsReturngoodsDetailedEntityList != null && tocofsReturngoodsDetailedEntityList.size() > 0) {
//            Set<String> mainTableIdSet = tocofsReturngoodsDetailedEntityList.stream().map(TocofsReturngoodsDetailedEntity::getMaintableid).collect(Collectors.toSet());
//            List<String> mainTableIdList = Lists.newArrayList(mainTableIdSet);
//
//            List<List<String>> splitListByCount = SplitListByCountUtil.splitListByCount(mainTableIdList, 1000);
////            List<List<TocofsReturngoodsDetailedEntity>> splitListByCount = SplitListByCountUtil.splitListByCount(tocofsReturngoodsDetailedEntityList, 1000);
//            for (int i = 0; i < splitListByCount.size(); i++) {
//                List<String> strings = splitListByCount.get(i);
////                Set<String> mainTableIdSet = tocofsReturngoodsDetailedEntityList1.stream().map(TocofsReturngoodsDetailedEntity::getMaintableid).collect(Collectors.toSet());
//                String mainTableIds = strings.stream().map(id -> "'" + id + "'").collect(Collectors.joining(","));
//                //查询对应的O售后入库单表头
//                TocofsReturngoodsEntity tocofsReturngoodsEntity = new TocofsReturngoodsEntity();
//                tocofsReturngoodsEntity.setIds(mainTableIds);
//                List<TocofsReturngoodsEntity> tocofsReturngoodsEntityList = iTocofsReturngoodsDao.query(tocofsReturngoodsEntity);
//                allTocofsReturngoodsEntityList.addAll(tocofsReturngoodsEntityList);
//            }
//        }
//
//        //通过「O售后入库单表头」匹配「O售后入库单明细」
//        if (allTocofsReturngoodsEntityList.size() > 0) {
//            Map<String, List<TocofsReturngoodsDetailedEntity>> stringListMap = convertToMap(tocofsReturngoodsDetailedEntityList);
//            for (int i = 0; i < allTocofsReturngoodsEntityList.size(); i++) {
//                TocofsReturngoodsEntity tocofsReturngoodsEntity = allTocofsReturngoodsEntityList.get(i);
//                //性能太差了，使用Map搜索
////                List<TocofsReturngoodsDetailedEntity> tocofsReturngoodsDetailedEntityList1 = new ArrayList<>();
////                for (int j = 0; j < tocofsReturngoodsDetailedEntityList.size(); j++) {
////                    TocofsReturngoodsDetailedEntity tocofsReturngoodsDetailedEntity1 = tocofsReturngoodsDetailedEntityList.get(j);
////                    if (tocofsReturngoodsDetailedEntity1.getMaintableid().equals(tocofsReturngoodsEntity.getId())) {
////                        tocofsReturngoodsDetailedEntityList1.add(tocofsReturngoodsDetailedEntity1);
////                    }
////                }
////                tocofsReturngoodsEntity.setTocofsReturngoodsDetailedEntityList(tocofsReturngoodsDetailedEntityList1);
//                List<TocofsReturngoodsDetailedEntity> tocofsReturngoodsDetailedEntities = stringListMap.get(tocofsReturngoodsEntity.getId());
//                tocofsReturngoodsEntity.setTocofsReturngoodsDetailedEntityList(tocofsReturngoodsDetailedEntities);
//            }
//        }
//
//        //转换为OFS售后入库单对象
//        List<StockinOrderSearchResponse.StockinOrder> returnGoodHeaderDetailsDataDtoArrayList = new ArrayList<>();
//        if (allTocofsReturngoodsEntityList.size() > 0) {
//            for (int i = 0; i < allTocofsReturngoodsEntityList.size(); i++) {
//
//                StockinOrderSearchResponse.StockinOrder stockinOrder = new StockinOrderSearchResponse.StockinOrder();
//                returnGoodHeaderDetailsDataDtoArrayList.add(stockinOrder);
//
//                //处理表头
//                TocofsReturngoodsEntity tocofsReturngoodsEntity = allTocofsReturngoodsEntityList.get(i);
//                StockinOrderSearchResponse.StockinOrder.StockinH stockinH = new StockinOrderSearchResponse.StockinOrder.StockinH();
//                stockinH.setId(tocofsReturngoodsEntity.getId());
//                BeanUtil.copyPropertiesV2(tocofsReturngoodsEntity, stockinH);
//                stockinOrder.setHeader(stockinH);
//
//                //处理明细行
//                List<TocofsReturngoodsDetailedEntity> tocofsReturngoodsDetailedEntityList1 = tocofsReturngoodsEntity.getTocofsReturngoodsDetailedEntityList();
//                List<StockinOrderSearchResponse.StockinOrder.StockinB> stockinB = new ArrayList<>();
//                stockinOrder.setDetails(stockinB);
//                for (int j = 0; j < tocofsReturngoodsDetailedEntityList1.size(); j++) {
//                    TocofsReturngoodsDetailedEntity tocofsReturngoodsDetailedEntity1 = tocofsReturngoodsDetailedEntityList1.get(j);
//
//                    StockinOrderSearchResponse.StockinOrder.StockinB stockinB1 = new StockinOrderSearchResponse.StockinOrder.StockinB();
//                    BeanUtil.copyPropertiesV2(tocofsReturngoodsDetailedEntity1, stockinB1);
//                    stockinB1.setId(tocofsReturngoodsDetailedEntity1.getId());
//                    stockinB.add(stockinB1);
//                }
//            }
//        }
//        return returnGoodHeaderDetailsDataDtoArrayList;
//    }

    /**
     * 存在相同Maintableid汇总在一起
     *
     * @author liuyang
     */
//    public static Map<String, List<TocofsReturngoodsDetailedEntity>> convertToMap(List<TocofsReturngoodsDetailedEntity> tocofsReturngoodsDetailedEntityList) {
//        Map<String, List<TocofsReturngoodsDetailedEntity>> map = new HashMap<>();
//        for (TocofsReturngoodsDetailedEntity entity : tocofsReturngoodsDetailedEntityList) {
//            String maintableid = entity.getMaintableid();
//            map.computeIfAbsent(maintableid, k -> new ArrayList<>()).add(entity);
//        }
//        return map;
//    }

    /**
     * 过滤掉没有退款时间的无源件明细行
     *
     * @param passiveStorageResponseDataList O无源件交易成功状态
     * @throws Exception 跑出可能的异常
     */
    private List<PassiveStorageResponse.Data> filterAfterSalesOrder(List<PassiveStorageResponse.Data> passiveStorageResponseDataList) throws Exception {
        List<PassiveStorageResponse.Data> filteredList = null;
        if (passiveStorageResponseDataList != null && passiveStorageResponseDataList.size() > 0) {
            filteredList = passiveStorageResponseDataList.stream().filter(stockinOrder -> {
                PassiveStorageResponse.Header header = stockinOrder.getHeader();
                if (header == null) {
                    return false;
                }
                RerturnGoodsOrderSearchData returnData = header.getRerturnGoodsOrderSearchData();
                if (returnData == null) {
                    return false;
                }
                RerturnGoodsOrderSearchHeader header1 = returnData.getHeader();
                if (header1 == null) {
                    return false;
                }
                if (header1.getRefundedAt() == null) {
                    return false;
                }
                return true;
            }).collect(Collectors.toList());
        }
        return filteredList;
    }

    /**
     * 如果无源入库单对应的售后订单状态为售中节点，则过滤掉不传递
     * 2025年4月11日09:27:22
     * 改为：如果无源件对应的售后订单，售后订单对应的销售订单有交易成功时间，则过滤掉
     *
     * @param passiveStorageResponseDataList 无源入库单
     * @throws Exception 抛出可能的异常
     * @author liuyang
     */
    public List<PassiveStorageResponse.Data> filterForSale(List<PassiveStorageResponse.Data> passiveStorageResponseDataList) throws Exception {
        List<PassiveStorageResponse.Data> filteredList = null;
        if (passiveStorageResponseDataList != null && passiveStorageResponseDataList.size() > 0) {
            filteredList = passiveStorageResponseDataList.stream().filter(stockinOrder -> {
                PassiveStorageResponse.Header header = stockinOrder.getHeader();
                HeaderDetailsDto headerDetailsDto = header.getHeaderDetailsDto();
                if (headerDetailsDto == null) {
                    return false;
                }
                //如果对应的销售订单还没有交易成功时间，则过滤掉
                com.hzya.frame.ttxofs.dto.ofssalesordersearch.HeaderDto header1 = headerDetailsDto.getHeader();
//                header1.setTradeSuccessAt("2025-04-13 16:25:00");
                String tradeSuccessAt = header1.getTradeSuccessAt();
                if (tradeSuccessAt == null) {
                    return false;
                }
                return true;

//                if (header == null) {
//                    // 如果 StockinH 为空，保留该对象
//                    return true;
//                }
//                RerturnGoodsOrderSearchData returnData = header.getRerturnGoodsOrderSearchData();
//                if (returnData == null || returnData.getHeader() == null) {
//                    // 如果 RerturnGoodsOrderSearchData 为空，保留该对象
//                    return true;
//                }
//                if (returnData.getHeader().getReturnNode() == null) {
//                    // 如果 RerturnGoodsOrderSearchData 为空，保留该对象
//                    return true;
//                }
//                // 检查 returnNode 是否不等于 200，若不等于则保留
//                return !"200".equals(returnData.getHeader().getReturnNode().trim());
            }).collect(Collectors.toList());
        }
        return filteredList;
    }


    /**
     * 把售后订单保存到主表
     *
     * @param rerturnGoodsOrderSearchData    需要插入底表的售后订单
     * @param passiveStorageResponseDataList 无源入库单
     * @author liuyang
     */
    private void batchInsertTran(List<RerturnGoodsOrderSearchData> rerturnGoodsOrderSearchData, List<PassiveStorageResponse.Data> passiveStorageResponseDataList, Map<String, HeaderDetailsDto> stringHeaderDetailsDtoMap) throws Exception {
        if (rerturnGoodsOrderSearchData != null && rerturnGoodsOrderSearchData.size() > 0) {
            List<RerturnGoodsOrderSearchHeader> headerDetailsDtoList1 = new ArrayList<>();
            List<RerturnGoodsOrderSearchDetails> headerDetailsDtoList2 = new ArrayList<>();

            for (RerturnGoodsOrderSearchData index : rerturnGoodsOrderSearchData) {
                //主表、明细表
                RerturnGoodsOrderSearchHeader header = index.getHeader();
                List<RerturnGoodsOrderSearchDetails> details = index.getDetails();
                if (details != null && details.size() > 0) {
                    for (RerturnGoodsOrderSearchDetails rerturnGoodsOrderSearchDetails : details) {
                        rerturnGoodsOrderSearchDetails.setRerturnGoodsOrderSearchHeader(header);
                    }
                }
                headerDetailsDtoList1.add(header);
                headerDetailsDtoList2.addAll(details);
            }

            //每100作为一个批次插入主表，根据主键（id）判断是否重复，如果重复的，则不进行插入
            List<List<RerturnGoodsOrderSearchHeader>> lists = SplitListByCountUtil.splitListByCount(headerDetailsDtoList1, 100);
            for (int i = 0; i < lists.size(); i++) {
                List<RerturnGoodsOrderSearchHeader> rerturnGoodsOrderSearchHeaders = lists.get(i);

                final Throwable[] childException = {null};
                long startTime = System.currentTimeMillis();
                Thread thread = new Thread(new Runnable() {
                    @Override
                    public void run() {
                        try {
                            List<OnlyAfterSalesHEntity> onlyAfterSalesHEntities = copyHeaderDtoByTran(rerturnGoodsOrderSearchHeaders);
                            if (onlyAfterSalesHEntities.size() > 0) {
                                logger.info("插入无源入库单-售后订单底表{}个对象（表头）", onlyAfterSalesHEntities.size());
                                iOnlyAfterSalesHDao.insertOrUpdate(onlyAfterSalesHEntities);
                            } else {
                                logger.info("onlyAfterSalesHEntities：没有对象被插入表头底表");
                            }
                        } catch (Exception e) {
                            logger.error("线程保存无源件-售后订单主表抛出异常", e);
                            childException[0] = e;
                        }
                    }
                });
                thread.start();
                try {
                    thread.join();
                } catch (Exception e) {
                    logger.error("线程保存TOC退货主表抛出异常", e);
                    childException[0] = e;
                }
                long endTime = System.currentTimeMillis();
                logger.info("插入或更新无源入库单表-耗时：{}", (endTime - startTime));

                //如果子线程抛出异常，则反馈到主线程方便排查
                if (childException[0] != null) {
                    Assert.state(false, childException[0].getMessage());
                }
            }

            //插入明细表
            List<List<RerturnGoodsOrderSearchDetails>> lists1 = SplitListByCountUtil.splitListByCount(headerDetailsDtoList2, 100);
            for (int i = 0; i < lists1.size(); i++) {
                List<RerturnGoodsOrderSearchDetails> rerturnGoodsOrderSearchDetails = lists1.get(i);
                List<OnlyAfterSalesBEntity> onlyAfterSalesBEntities = copyDetailsDtoTran(rerturnGoodsOrderSearchDetails, passiveStorageResponseDataList, stringHeaderDetailsDtoMap);

                final Throwable[] childException = {null};
                long startTime = System.currentTimeMillis();
                Thread thread = new Thread(new Runnable() {
                    @Override
                    public void run() {
                        try {
                            if (onlyAfterSalesBEntities.size() > 0) {
                                logger.info("插入底表{}个对象（表体）", onlyAfterSalesBEntities.size());
                                iOnlyAfterSalesBDao.entityInsertOrUpdateBatch(onlyAfterSalesBEntities);
                            } else {
                                logger.info("ofsPassiveorderDetailEntities：没有对象被插入表头底表");
                            }
                        } catch (Exception e) {
                            logger.error("线程保存TOC退货明细抛出异常", e);
                            childException[0] = e;
                        }
                    }
                });
                thread.start();
                try {
                    thread.join();
                } catch (Exception e) {
                    logger.error("线程保存无源件明细表抛出异常", e);
                    childException[0] = e;
                }
                long endTime = System.currentTimeMillis();
                logger.info("插入或更新TOC退货入库表体-耗时：{}", (endTime - startTime));
                //如果子线程抛出异常，则反馈到主线程方便排查
                if (childException[0] != null) {
                    Assert.state(false, childException[0].getMessage());
                }
            }
        }
    }

    /**
     * 过滤掉已经推送成功的售后订单
     *
     * @author liuyang
     */
    private List<RerturnGoodsOrderSearchData> filterSuccessAfterSalesOrder(List<RerturnGoodsOrderSearchData> rerturnGoodsOrderSearchDataList) throws Exception {
        Assert.notNull(rerturnGoodsOrderSearchDataList, "rerturnGoodsOrderSearchDataList不能为空");

        List<OnlyAfterSalesBEntity> onlyAfterSalesBEntityArrayList = new ArrayList<>();
        if (rerturnGoodsOrderSearchDataList != null && rerturnGoodsOrderSearchDataList.size() > 0) {
            List<List<RerturnGoodsOrderSearchData>> lists = SplitListByCountUtil.splitListByCount(rerturnGoodsOrderSearchDataList, 100);
            for (int i = 0; i < lists.size(); i++) {
                List<RerturnGoodsOrderSearchData> rerturnGoodsOrderSearchDataList1 = lists.get(i);
                String idStr = commaConcatenatedPrimaryKeyStock2(rerturnGoodsOrderSearchDataList1);
                List<OnlyAfterSalesBEntity> onlyAfterSalesBEntityList = queryStockTocOutLog2(idStr);
                onlyAfterSalesBEntityArrayList.addAll(onlyAfterSalesBEntityList);
            }
        }
        return filterDataRowsAsPushOrFailedStock2(onlyAfterSalesBEntityArrayList, rerturnGoodsOrderSearchDataList);
    }
}